#!/bin/bash
#
# LICENSED MATERIALS - PROPERTY OF IBM
#
# 5725-C25
#
# (C) Copyright IBM Corp. 2014
#
# ALL RIGHTS RESERVED
#
# US Government Users Restricted Rights -c
# Use, duplication or disclosure restricted by
# GSA ADP Schedule Contract with IBM Corp.
#

SECONDARY_GROUP_CONF="/etc/crm/SecondaryGroupSettings.conf"
SP_REDUNDANCY_POLICY="/etc/crm/policies/cml/NetworkDefender/spRedundancy/spRedundancy1_0.xml"

# default parameter values
USE_LOCAL_SETTING="false"
GROUP_NAME_HINT="G Series"
HEARTBEAT_INTERVAL="3600"
EVENT_SERVER_NAME=""
EVENT_SERVER_IPORDNS=""
EVENT_SERVER_PORT="3995"
EVENT_SERVER_AUTH_LEVEL="first-time-trust"
EVENT_SERVER_USERNAME=""
EVENT_SERVER_PASSWORD=""
EVENT_SERVER_ENC_PASSWORD=""
PROXY_IPORDNS=""
PROXY_ENABLED="false"
PROXY_PORT="3128"

AGENT_MANAGERS=()
AGENT_MANAGER_CONFIG="<AgentManager EventServerName='@EventServerName' EventServerIPorDNS='@EventServerIPorDNS' EventServerPort='@EventServerPort' EventServerUsername='@EventServerUsername' EventServerPassword='@EventServerPassword' EventServerEncPassword='@EventServerEncPassword'  EventServerAuthenticationLevel='@EventServerAuthenticationLevel' Ordinal='@Ordinal' ProxyIPorDNS='@ProxyIPorDNS' ProxyEnabled='@ProxyEnabled' ProxyPort='@ProxyPort'/>"

AgentManagerConfigInit()
{
	idx=$1

	if [ ${#AGENT_MANAGERS[@]} -le $idx ]; then
		for (( i=${#AGENT_MANAGERS[@]} ; i<=$idx ; i++ )); do
		   init_config=`echo "$AGENT_MANAGER_CONFIG" | sed -e "s!@Ordinal!$i!g"`
		   AGENT_MANAGERS+=( "$init_config" )
		done
	fi
}

SetAgentManagerParameter()
{
	idx=$1
	param=$2
	value=$3

	if [ "$param" == "EventServerAuthenticationLevel" -a "$value" == "trust-all"  ]; then
		AGENT_MANAGERS[idx]=`echo "${AGENT_MANAGERS[${idx}]}" | sed -e "s!@EventServerAuthenticationLevel!none!g"`
	else
		AGENT_MANAGERS[idx]=`echo "${AGENT_MANAGERS[${idx}]}" | sed -e "s!@$param!$value!g"`
	fi
	
	if [ "$param" == "EventServerEncPassword" -a -z != "$value" ]; then
		AGENT_MANAGERS[idx]=`echo "${AGENT_MANAGERS[${idx}]}" | sed -e "s!@EventServerPassword!****!g"`
	fi
}

SetAgentManagerDefault()
{
	for i in ${!AGENT_MANAGERS[@]}; do
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@EventServerName!$EVENT_SERVER_NAME!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@EventServerIPorDNS!$EVENT_SERVER_IPORDNS!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@EventServerPort!$EVENT_SERVER_PORT!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@EventServerUsername!$EVENT_SERVER_USERNAME!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@EventServerPassword!$EVENT_SERVER_PASSWORD!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@EventServerEncPassword!$EVENT_SERVER_ENC_PASSWORD!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@EventServerAuthenticationLevel!$EVENT_SERVER_AUTH_LEVEL!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@ProxyIPorDNS!$PROXY_IPORDNS!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@ProxyEnabled!$PROXY_ENABLED!g"`
	   AGENT_MANAGERS[i]=`echo "${AGENT_MANAGERS[${i}]}" | sed -e "s!@ProxyPort!$PROXY_PORT!g"`
	done
}

ConfigureAgentManager() 
{
	idx=$1
	param=$2
	value=$3
	
	AgentManagerConfigInit $idx
	SetAgentManagerParameter $idx $param $value
}

SetParameter() 
{
	key=$1
	value=$2
	
	case "$key" in
	"UseLocalSettings")
		USE_LOCAL_SETTING=$value
		;;
	"GroupNameHint")
		GROUP_NAME_HINT=$value
		;;
	"HeartbeatInterval")
		HEARTBEAT_INTERVAL=$value
		;;
	*) 
		IFS='.' read -ra comp <<< "$key"
		if [ ${#comp[@]} -eq 3 ]; then
			[ "${comp[@]:0:1}" == "AgentManager" ] && ConfigureAgentManager "${comp[@]:1:1}" ${comp[@]:2:1} "$value"
		fi
	esac
}

WriteSpRedundancyPolicy() 
{
	rm -rf $SP_REDUNDANCY_POLICY

	echo "<?xml version='1.0' encoding='UTF-8' standalone='no'?>" >> $SP_REDUNDANCY_POLICY
	echo "  <policy schema-version='1.0.0' valid='true' xmlns='http://www.iss.net/cml/NetworkDefender/spRedundancy' xmlns:PolicyBase='http://www.iss.net/cml/PolicyBase' xmlns:cml='http://www.iss.net/cml' xmlns:common='http://www.iss.net/cml/common' xmlns:cpe='http://www.iss.net/cml/cpe' xmlns:xsi='http://www.w3.org/2001/XMLSchema-instance'>" >> $SP_REDUNDANCY_POLICY
	
	if [ ${#AGENT_MANAGERS[@]} -gt 0 ]; then
		echo "    <Config EnableSW='true' GroupNameHint='$GROUP_NAME_HINT' HeartbeatInterval='$HEARTBEAT_INTERVAL' UseLocalSettings='$USE_LOCAL_SETTING'>" >> $SP_REDUNDANCY_POLICY
		for config in "${AGENT_MANAGERS[@]}"; do
			echo "      $config" >> $SP_REDUNDANCY_POLICY
		done
		echo "    </Config>" >> $SP_REDUNDANCY_POLICY
	else
		echo "    <Config EnableSW='true' GroupNameHint='$GROUP_NAME_HINT' HeartbeatInterval='$HEARTBEAT_INTERVAL' UseLocalSettings='$USE_LOCAL_SETTING'/>" >> $SP_REDUNDANCY_POLICY
	fi
	
	echo "  </policy>" >> $SP_REDUNDANCY_POLICY
}

if [ ! -f "$SECONDARY_GROUP_CONF" ]; then
	echo "SiteProtector Split-Writing is disabled"
	exit 0
fi

while read line; do
	# get the leading character
	first_char=${line:0:1}
	
	[ -z "$line" -o "$first_char" == "#" -o "$first_char" == "@" ] && continue
	
	key=`echo ${line} | cut -d = -f 1`
	value=`echo ${line} | cut -d = -f 2-`
	SetParameter "$key" "$value"
	
done < $SECONDARY_GROUP_CONF

SetAgentManagerDefault
WriteSpRedundancyPolicy

exit 0
