<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:responses="http://www.iss.net/cml/GlobalResponses">

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'5.0.0'"/>

<xsl:template match="responses:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/GlobalResponses">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="responses:logEvidence">
    <xsl:element name="logEvidence" namespace="http://www.iss.net/cml/GlobalResponses">
        <!-- TODO - set max files, max file size, and max packets to appropriate defaults -->
        <xsl:attribute name="maximumFiles"> <xsl:value-of select="'1000'"/> </xsl:attribute>
        <xsl:attribute name="maximumFileSize"> <xsl:value-of select="'500'"/> </xsl:attribute>
        <xsl:attribute name="maxNumberOfPackets"> <xsl:value-of select="'100'"/> </xsl:attribute>
        <!-- This is a migrated policy, so retain sniffer format -->
        <xsl:attribute name="captureFormat"> <xsl:value-of select="'sniffer'"/> </xsl:attribute>
    </xsl:element>
</xsl:template>

<xsl:template match="responses:userDefined">
    <xsl:element name="userDefined" namespace="http://www.iss.net/cml/GlobalResponses">
        <xsl:copy-of select="@*[name() != 'command']"/>
        <xsl:call-template name="AddCommand">
            <xsl:with-param name="cmdname" select="@command"/>
        </xsl:call-template>
    </xsl:element>
</xsl:template>

<xsl:template name="AddCommand">
    <xsl:param name="cmdname" select="''"/>
    <xsl:if test="string-length($cmdname) > 0">
        <xsl:choose>
            <xsl:when test="contains($cmdname, '/')">
                <xsl:call-template name="AddCommand">
                    <xsl:with-param name="cmdname" select="substring-after($cmdname, '/')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="command"> <xsl:value-of select="concat('/usr/local/bin/', $cmdname)"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<xsl:template match="responses:quarantine">
    <xsl:element name="quarantine" namespace="http://www.iss.net/cml/GlobalResponses">
        <xsl:copy-of select="@*"/>
        <xsl:attribute name="issueId">false</xsl:attribute>
        <xsl:if test="@name='Quarantine-Worm'">
          <xsl:attribute name="pamInternalName">block_worm</xsl:attribute>
        </xsl:if>
        <xsl:if test="@name='Quarantine-Trojan'">
          <xsl:attribute name="pamInternalName">block_trojan</xsl:attribute>
        </xsl:if>
        <xsl:if test="@name='Quarantine-Intruder'">
          <xsl:attribute name="pamInternalName">block_intruder</xsl:attribute>
        </xsl:if>
    </xsl:element>
    <!-- Insert new Quarantine-DDOS element after Quarantine-Worm element -->
    <xsl:if test="@name='Quarantine-Worm'">
        <xsl:call-template name="AddQuarantineDDOS"/>
    </xsl:if>
</xsl:template>

<xsl:template name="AddQuarantineDDOS">
    <xsl:element name="quarantine" namespace="http://www.iss.net/cml/GlobalResponses">
        <xsl:attribute name="responseId">9FEAEF5A-F77A-4667-8042-1B4B9168B045</xsl:attribute>
        <xsl:attribute name="name">Quarantine-DDOS</xsl:attribute>
        <xsl:attribute name="victimAddress">true</xsl:attribute>
        <xsl:attribute name="victimPort">true</xsl:attribute>
        <xsl:attribute name="intruderAddress">true</xsl:attribute>
        <xsl:attribute name="intruderPort">false</xsl:attribute>
        <xsl:attribute name="icmpCode">false</xsl:attribute>
        <xsl:attribute name="icmpType">false</xsl:attribute>
        <xsl:attribute name="issueId">true</xsl:attribute>
        <xsl:attribute name="noDelete">true</xsl:attribute>
        <xsl:attribute name="noEdit">true</xsl:attribute>
        <xsl:attribute name="pamInternalName">block_ddos</xsl:attribute>
    </xsl:element>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/GlobalResponses">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

