<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ce="http://www.iss.net/cml/NetProtectModule/connectionEvents" xmlns:base="http://www.iss.net/cml/NetProtectModule/base">

  <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
  <xsl:param name="pSchemaVersion" select="'5.0.0'"/>

  <xsl:template match="ce:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:copy-of select="@*[name() != 'schema-version' and name() != 'xsi:schemaLocation']"/>
      <xsl:attribute name="schema-version">
        <xsl:value-of select="$pSchemaVersion"/>
      </xsl:attribute>
      <xsl:apply-templates/>
      <xsl:call-template name="addDefaultIPv6"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="ce:connectionEventElement">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:copy-of select="@*[name() != 'logEvidence']"/>
      <xsl:attribute name="logEvidence">
        <xsl:choose>
          <xsl:when test="@logEvidence = 'true'">
            <xsl:value-of select="'OffendingPacket'"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="'None'"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>

  
  <xsl:template match="base:quarantineResponse">
      <xsl:element name="quarantineResponse" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:copy-of select="@*[name() != 'percentage']"/>
        <xsl:attribute name="rateLimit">
          <xsl:variable name="vAllow" select="1048576 * .01 * (100 - @percentage)"/>
          <xsl:variable name="vAllowInt" select="$vAllow - ($vAllow mod 1)"/>
          <xsl:value-of select="$vAllowInt"/>
        </xsl:attribute>
        <xsl:apply-templates/>
      </xsl:element>
  </xsl:template>

  <xsl:template match="ce:addressPort">
    <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="IPVersion">IPv4</xsl:attribute>
      <xsl:attribute name="SourceIP">
        <xsl:value-of select="substring-before(ce:source/@addressPortControl,':')"/>
      </xsl:attribute>
      <xsl:attribute name="TargetIP">
        <xsl:value-of select="substring-before(ce:destination/@addressPortControl,':')"/>
      </xsl:attribute>
      <xsl:attribute name="SourcePort">
        <xsl:value-of select="substring-after(ce:source/@addressPortControl,':')"/>
      </xsl:attribute>
      <xsl:attribute name="TargetPort">
        <xsl:value-of select="substring-after(ce:destination/@addressPortControl,':')"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>
  
  <xsl:template name="addDefaultIPv6" >
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">FTP</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">21</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Telnet</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">23</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">SMTP</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">25</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Finger</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">79</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">WWW</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">80</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">POP2</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">109</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">POP3</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">110</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">PortMap</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">111</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Ident</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">113</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">NNTP</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">119</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">IMAP2</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">143</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">IMAP3</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">220</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Exec</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">512</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Login</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">513</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">RWatch</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">5556</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">IRC</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">0</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">TCP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">6667</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Echo</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">7</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Echo</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">7</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Ping</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">ICMPv6</xsl:attribute>
      <xsl:attribute name="ICMPTypeAndCode">128:0-128:255</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Ping</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">ICMPv6</xsl:attribute>
      <xsl:attribute name="ICMPTypeAndCode">129:0-129:255</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Chargen</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">19</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Chargen</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">19</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">TFTP</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">69</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">TFTP</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">69</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Portmap</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">111</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Portmap</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">111</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Who</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">513</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Who</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">513</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Talk</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">517</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Talk</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">517</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Ntalk</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">518</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Ntalk</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">518</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Kerberos</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">ANY</xsl:attribute>
        <xsl:attribute name="TargetPort">750</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
    <xsl:text>
    </xsl:text>
    <xsl:element name="connectionEventElement" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
      <xsl:attribute name="Enabled">false</xsl:attribute>
      <xsl:attribute name="Event">Kerberos</xsl:attribute>
      <xsl:attribute name="Comment"></xsl:attribute>
      <xsl:attribute name="risk">low</xsl:attribute>
      <xsl:attribute name="eventThrottling">300</xsl:attribute>
      <xsl:attribute name="ProtocolSimple">UDP</xsl:attribute>
      <xsl:attribute name="display">WithoutRaw</xsl:attribute>
      <xsl:attribute name="block">false</xsl:attribute>
      <xsl:attribute name="logEvidence">None</xsl:attribute>
      <xsl:element name="addressPort" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents">
        <xsl:attribute name="IPVersion">IPv6</xsl:attribute>
        <xsl:attribute name="SourceIP">ANY</xsl:attribute>
        <xsl:attribute name="TargetIP">ANY</xsl:attribute>
        <xsl:attribute name="SourcePort">750</xsl:attribute>
        <xsl:attribute name="TargetPort">ANY</xsl:attribute>
      </xsl:element>
      <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/connectionEvents"/>
    </xsl:element>
  </xsl:template>
</xsl:stylesheet>

