<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
						xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
						xmlns:ca="http://www.iss.net/cml/NetProtectModule/contentAnalyzer" 
						xmlns:ipm="http://www.iss.net/cml/NetProtectModule/ipm" 
						xmlns:tp="http://www.iss.net/cml/NetProtectModule/tuningParameters" 
						xmlns:base="http://www.iss.net/cml/NetProtectModule/base">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>
Example: /usr/bin/Xalan -p pTuningParamXml "'tuningParameters1_0.xml'" -p pIpmParamXml "'ipm2_1.xml'" contentAnalyzer1_0.xml contentAnalyzer100.xslt
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'1.0.0'"/>
<xsl:param name="pTuningParamXml" select="'tuningParameters1_0.xml'"/>  <!-- policy must conform to tuningParameters schema v1 -->
<xsl:param name="pIpmParamXml" select="'ipm3_0.xml'"/>                  <!-- policy must conform to ipm schema v2_1 or v3_0 -->

<xsl:variable name="vTP" select="document($pTuningParamXml)/tp:policy"/>
<xsl:variable name="vIPM" select="document($pIpmParamXml)/ipm:policy"/>

<xsl:template match="ca:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="ca:ContentAnalyzerEvents">
    <xsl:element name="ContentAnalyzerEvents" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.enabled' and @Enabled='true' and
                           (@Value='true' or @Value='True')]">
                <xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="ca:PredefinedEvent">
    <xsl:variable name="vName" select="@Name"/>
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*[name() != '@Enabled' and name() != '@MinMatch']"/>
        <!-- Enabled attribute -->
        <xsl:choose>
            <xsl:when test="@Enabled='true' or count($vIPM/ipm:securityEventsList[@Enabled='true' and @checkName=$vName]) > 0">
                <xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <!-- MinMatch attribute -->
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_Credit_Card_Num'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.credit_card_num.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.credit_card_num.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_Postal_Addr'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.postal_addr.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.postal_addr.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_Social_Security_Num'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.social_security_num.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.social_security_num.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_Dollar_Amount'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.dollar_amount.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.dollar_amount.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_Date'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.date.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.date.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_US_Phone_Num'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.us_phone_num.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.us_phone_num.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_Email_Addr'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.email_addr.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.email_addr.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
        <xsl:choose>
			<xsl:when test="@Name='Content_Analyzer_Person_Name'">
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.person_name.minmatch' and @Enabled='true']">
						<xsl:attribute name="MinMatch"><xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.person_name.minmatch' and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="MinMatch"> <xsl:value-of select="@MinMatch"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
		
        <xsl:choose>
            <xsl:when test="count($vIPM/ipm:securityEventsList[@Enabled='true' and @checkName=$vName]) > 0">
                <!-- Migrate the user's VirtualSensor(s) -->
                <xsl:apply-templates select="$vIPM/ipm:securityEventsList[@Enabled='true' and @checkName=$vName]" mode="AddVirtualSensor"/>
            </xsl:when>
            <xsl:otherwise>
                <!-- Copy the original VirtualSensor -->
                <xsl:apply-templates/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template match="/ipm:policy/ipm:securityEventsList" mode="AddVirtualSensor">
    <xsl:call-template name="AddVirtualSensor"/>
</xsl:template>

<xsl:template match="ca:UserCombinedEvents">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
        <xsl:apply-templates select="$vIPM/ipm:securityEventsList[starts-with(@checkName,'Content_Analyzer_User_Combined_')]" mode="AddUserCombinedEvent"/>
    </xsl:element>
</xsl:template>

<xsl:template match="/ipm:policy/ipm:securityEventsList" mode="AddUserCombinedEvent">
    <xsl:variable name="vUCIndex" select="substring-after(@checkName, 'Content_Analyzer_User_Combined_')"/>
    <xsl:variable name="vTPReportstr" select="concat('pam.ca.user_comb_', $vUCIndex, '.reportstr')"/>
    <xsl:variable name="vTPEvents" select="concat('pam.ca.user_comb_', $vUCIndex, '.events')"/>
	<xsl:choose>
		<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPEvents]/@Enabled = 'true'">
			<xsl:element name="UserCombinedEvent" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
				<xsl:choose>
					<xsl:when test="@Enabled = 'true' and $vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPEvents]/@Enabled = 'true'">
						<xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr and @Enabled='true']">
						<xsl:attribute name="Name">
							<xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr]/@Value"/>
						</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="Name"> <xsl:value-of select="@checkName"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="AddEvents">
					<xsl:with-param name="paramEvents" select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPEvents]/@Value"/>
				</xsl:call-template>
				<xsl:call-template name="AddVirtualSensor"/>
			</xsl:element>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="AddEvents">
    <xsl:param name="paramEvents" select="''"/>
    <xsl:if test="string-length($paramEvents) > 0">
        <xsl:choose>
            <xsl:when test="contains($paramEvents, ' ')">
                <xsl:variable name="vEvent" select="substring-before($paramEvents, ' ')"/>
                <xsl:if test="string-length($vEvent) > 0">
                    <xsl:call-template name="AddEvent">
                        <xsl:with-param name="paramEvent" select="$vEvent"/>
                    </xsl:call-template>
                </xsl:if>
                <xsl:call-template name="AddEvents">
                    <xsl:with-param name="paramEvents" select="substring-after($paramEvents, ' ')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:when test="string-length($paramEvents) > 0">
                <xsl:call-template name="AddEvent">
                    <xsl:with-param name="paramEvent" select="$paramEvents"/>
                </xsl:call-template>
            </xsl:when>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<xsl:template name="AddEvent">
    <xsl:param name="paramEvent" select="''"/>
    <xsl:element name="PredefinedEvent" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="starts-with($paramEvent, '!')">
                <xsl:attribute name="exclude"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="exclude"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:attribute name="value"> <xsl:value-of select="$paramEvent"/> </xsl:attribute>
    </xsl:element>
</xsl:template>

<xsl:template match="ca:UserDefinedEvents">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
        <xsl:apply-templates select="$vIPM/ipm:securityEventsList[starts-with(@checkName,'Content_Analyzer_User_Defined_')]" mode="AddUserDefinedEvent"/>
    </xsl:element>
</xsl:template>

<xsl:template match="/ipm:policy/ipm:securityEventsList" mode="AddUserDefinedEvent">
    <xsl:variable name="vUDIndex" select="substring-after(@checkName, 'Content_Analyzer_User_Defined_')"/>
    <xsl:variable name="vTPRegex" select="concat('pam.ca.user_def_', $vUDIndex, '.regex')"/>
    <xsl:variable name="vTPReportstr" select="concat('pam.ca.user_def_', $vUDIndex, '.reportstr')"/>
    <xsl:variable name="vTPMinmatch" select="concat('pam.ca.user_def_', $vUDIndex, '.minmatch')"/>
    <xsl:choose>
		<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPRegex]">
			<xsl:element name="UserDefinedEvent" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
				<xsl:choose>
					<xsl:when test="@Enabled = 'true' and $vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPRegex]/@Enabled = 'true'">
						<xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr and @Enabled='true']">
						<xsl:attribute name="Name">
							<xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr]/@Value"/>
						</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="Name"> <xsl:value-of select="@checkName"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:attribute name="Expression">
					<xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPRegex]/@Value"/>
				</xsl:attribute>
				<xsl:choose>
					<xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPMinmatch and @Enabled='true']">
						<xsl:attribute name="MinMatch"> <xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPMinmatch and @Enabled='true']/@Value"/> </xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<!-- verify default value -->
						<xsl:attribute name="MinMatch"> <xsl:value-of select="'1'"/> </xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="AddVirtualSensor"/>
			</xsl:element>
		</xsl:when>
	</xsl:choose>

</xsl:template>

<xsl:template name="AddVirtualSensor">
    <xsl:element name="VirtualSensor" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:attribute name="value"> <xsl:value-of select="@virtualSensor"/> </xsl:attribute>
        <xsl:attribute name="ignore"> <xsl:value-of select="@ignore"/> </xsl:attribute>
        <xsl:attribute name="display"> <xsl:value-of select="@display"/> </xsl:attribute>
        <xsl:attribute name="block"> <xsl:value-of select="@block"/> </xsl:attribute>
        <xsl:attribute name="logEvidence">
            <xsl:choose>
                <xsl:when test="@logEvidence = 'true'">
                    <xsl:value-of select="'OffendingPacket'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'None'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:quarantineResponse">
    <xsl:element name="quarantineResponse" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*[name() != 'percentage']"/>
        <xsl:attribute name="rateLimit">
            <xsl:variable name="vAllow" select="1048576 * .01 * (100 - @percentage)"/>
            <xsl:variable name="vAllowInt" select="$vAllow - ($vAllow mod 1)"/>
            <xsl:value-of select="$vAllowInt"/>
        </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="ca:Tuning">
    <xsl:variable name="vName" select="@tuningName"/>
    <xsl:element name="Tuning" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*[name() != 'enabled']"/>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vName and @Enabled='true' and (@Value='true' or @Value='True')]">
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vName and @Enabled='true' and (@Value='false' or @Value='False')]">
                <xsl:attribute name="enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template match="ca:Protocol">
    <xsl:variable name="vName" select="@tuningName"/>
    <xsl:element name="Protocol" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*[name() != 'enabled']"/>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vName and @Enabled='true' and (@Value='true' or @Value='True')]">
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vName and @Enabled='true' and (@Value='false' or @Value='False')]">
                <xsl:attribute name="enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>
