<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ipm="http://www.iss.net/cml/NetProtectModule/ipm" xmlns:tp="http://www.iss.net/cml/NetProtectModule/tuningParameters" xmlns:base="http://www.iss.net/cml/NetProtectModule/base">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'1.0.0'"/>
<xsl:param name="pTuningParamXml" select="'tuningParameters1_0.xml'"/>  <!-- policy must conform to tuningParameters schema v1 -->

<xsl:variable name="vTP" select="document($pTuningParamXml)/tp:policy"/>

<xsl:template match="ipm:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:call-template name="AddContentAnalyzerEvents"/>
        <xsl:call-template name="AddContentAnalyzerConfig"/>
    </xsl:element>
</xsl:template>

<xsl:template name="AddContentAnalyzerEvents">
    <xsl:element name="ContentAnalyzerEvents" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.enabled' and @Enabled='true' and
                           (@Value='true' or @Value='True')]">
                <xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="AddPredefinedEvents"/>
        <xsl:call-template name="AddUserCombinedEvents"/>
        <xsl:call-template name="AddUserDefinedEvents"/>
    </xsl:element>
</xsl:template>

<xsl:template name="AddContentAnalyzerConfig">
    <xsl:element name="ContentAnalyzerConfig" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.report.packetinfo' and @Enabled='true' and
                           (@Value='false' or @Value='False')]">
                <xsl:attribute name="ReportPacketInfo"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="ReportPacketInfo"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.zip.uncompress.enabled' and @Enabled='true' and
                           (@Value='false' or @Value='False')]">
                <xsl:attribute name="InspectZip"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="InspectZip"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.credit_card_num.validate' and @Enabled='true' and
                           (@Value='false' or @Value='False')]">
                <xsl:attribute name="ValidateCreditCard"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="ValidateCreditCard"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:element name="Protocols" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.aim.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="aim"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="aim"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.msmsgr.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="msmsgr"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="msmsgr"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.aolimft.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="aolimft"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="aolimft"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.msmsgrft.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="msmsgrft"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="msmsgrft"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.ftp.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="ftp"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="ftp"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.pop.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="pop"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="pop"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.http.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="http"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="http"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.smb.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="smb"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="smb"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.imap4.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="imap4"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="imap4"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.smtp.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="smtp"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="smtp"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.irc.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="irc"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="irc"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.yahoo.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="yahoo"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="yahoo"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.ircft.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="ircft"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="ircft"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name='pam.ca.yahooft.enabled' and @Enabled='true' and
                               (@Value='false' or @Value='False')]">
                    <xsl:attribute name="yahooft"> <xsl:value-of select="'false'"/> </xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="yahooft"> <xsl:value-of select="'true'"/> </xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:element>
    </xsl:element>
</xsl:template>

<xsl:template name="AddPredefinedEvents">
    <xsl:element name="PredefinedEvents" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:apply-templates select="ipm:securityEventsList[starts-with(@checkName,'Content_Analyzer_') and starts-with(@checkName,'Content_Analyzer_User_')=false]" mode="AddPredefinedEvent"/>
    </xsl:element>
</xsl:template>

<xsl:template match="ipm:securityEventsList" mode="AddPredefinedEvent">
    <xsl:variable name="vPName" select="translate(substring-after(@checkName,'Content_Analyzer_'),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>
    <xsl:variable name="vPRegex" select="concat('pam.ca', $vPName, '.regex')"/>
    <xsl:variable name="vPMinmatch" select="concat('pam.ca.', $vPName, '.minmatch')"/>

    <xsl:element name="PredefinedEvent" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="@Enabled = 'true' and $vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vPRegex]/@Enabled = 'true'">
                <xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:attribute name="Name"> <xsl:value-of select="@checkName"/> </xsl:attribute>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vPMinmatch and @Enabled='true']">
                <xsl:attribute name="MinMatch"> <xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vPMinmatch and @Enabled='true']/@Value"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="$vPMinmatch='pam.ca.credit_card_num.minmatch' or $vPMinmatch='pam.ca.social_security_num.minmatch'">
                        <xsl:attribute name="MinMatch"> <xsl:value-of select="'10'"/> </xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:attribute name="MinMatch"> <xsl:value-of select="'100'"/> </xsl:attribute>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:attribute name="noDelete"> <xsl:value-of select="'false'"/> </xsl:attribute>
        <xsl:attribute name="noEdit"> <xsl:value-of select="'false'"/> </xsl:attribute>
        <xsl:call-template name="AddVirtualSensor"/>
    </xsl:element>
</xsl:template>

<xsl:template name="AddUserCombinedEvents">
    <xsl:element name="UserCombinedEvents" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:apply-templates select="ipm:securityEventsList[starts-with(@checkName,'Content_Analyzer_User_Combined_')]" mode="AddUserCombinedEvent"/>
    </xsl:element>
</xsl:template>

<xsl:template match="ipm:securityEventsList" mode="AddUserCombinedEvent">
    <xsl:variable name="vUCIndex" select="substring-after(@checkName, 'Content_Analyzer_User_Combined_')"/>
    <xsl:variable name="vTPReportstr" select="concat('pam.ca.user_comb_', $vUCIndex, '.reportstr')"/>
    <xsl:variable name="vTPEvents" select="concat('pam.ca.user_comb_', $vUCIndex, '.events')"/>

    <xsl:element name="UserCombinedEvent" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="@Enabled = 'true' and $vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPEvents]/@Enabled = 'true'">
                <xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr and @Enabled='true']">
                <xsl:attribute name="Name">
                    <xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr]/@Value"/>
                </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Name"> <xsl:value-of select="@checkName"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="AddEvents">
            <xsl:with-param name="paramEvents" select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPEvents]/@Value"/>
        </xsl:call-template>
        <xsl:call-template name="AddVirtualSensor"/>
    </xsl:element>
</xsl:template>

<xsl:template name="AddEvents">
    <xsl:param name="paramEvents" select="''"/>
    <xsl:if test="string-length($paramEvents) > 0">
        <xsl:choose>
            <xsl:when test="contains($paramEvents, ' ')">
                <xsl:variable name="vEvent" select="substring-before($paramEvents, ' ')"/>
                <xsl:if test="string-length($vEvent) > 0">
                    <xsl:call-template name="AddEvent">
                        <xsl:with-param name="paramEvent" select="$vEvent"/>
                    </xsl:call-template>
                </xsl:if>
                <xsl:call-template name="AddEvents">
                    <xsl:with-param name="paramEvents" select="substring-after($paramEvents, ' ')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:when test="string-length($paramEvents) > 0">
                <xsl:call-template name="AddEvent">
                    <xsl:with-param name="paramEvent" select="$paramEvents"/>
                </xsl:call-template>
            </xsl:when>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<xsl:template name="AddEvent">
    <xsl:param name="paramEvent" select="''"/>
    <xsl:variable name="vEventName" select="substring-after($paramEvent, 'Content_Analyzer_')"/>
    <xsl:element name="PredefinedEvent" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="starts-with($paramEvent, '!')">
                <xsl:attribute name="exclude"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="exclude"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="$vEventName = 'Credit_Card_Num'">
                <xsl:attribute name="value"> <xsl:value-of select="'Credit_Card_Numbers'"/> </xsl:attribute>
            </xsl:when>
            <xsl:when test="$vEventName = 'Postal_Addr'">
                <xsl:attribute name="value"> <xsl:value-of select="'Postal_Address'"/> </xsl:attribute>
            </xsl:when>
            <xsl:when test="$vEventName = 'Social_Security_Num'">
                <xsl:attribute name="value"> <xsl:value-of select="'Social_Security_Number'"/> </xsl:attribute>
            </xsl:when>
            <xsl:when test="$vEventName = 'US_Phone_Num'">
                <xsl:attribute name="value"> <xsl:value-of select="'US_Phone_Number'"/> </xsl:attribute>
            </xsl:when>
            <xsl:when test="$vEventName = 'Email_Addr'">
                <xsl:attribute name="value"> <xsl:value-of select="'Email_Address'"/> </xsl:attribute>
            </xsl:when>
            <xsl:when test="$vEventName = 'Person_Name'">
                <xsl:attribute name="value"> <xsl:value-of select="'Persons_Name'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="value"> <xsl:value-of select="$vEventName"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template name="AddUserDefinedEvents">
    <xsl:element name="UserDefinedEvents" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:apply-templates select="ipm:securityEventsList[starts-with(@checkName,'Content_Analyzer_User_Defined_')]" mode="AddUserDefinedEvent"/>
    </xsl:element>
</xsl:template>

<xsl:template match="ipm:securityEventsList" mode="AddUserDefinedEvent">
    <xsl:variable name="vUDIndex" select="substring-after(@checkName, 'Content_Analyzer_User_Defined_')"/>
    <xsl:variable name="vTPRegex" select="concat('pam.ca.user_def_', $vUDIndex, '.regex')"/>
    <xsl:variable name="vTPReportstr" select="concat('pam.ca.user_def_', $vUDIndex, '.reportstr')"/>
    <xsl:variable name="vTPMinmatch" select="concat('pam.ca.user_def_', $vUDIndex, '.minmatch')"/>
    <xsl:element name="UserDefinedEvent" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:choose>
            <xsl:when test="@Enabled = 'true' and $vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPRegex]/@Enabled = 'true'">
                <xsl:attribute name="Enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr and @Enabled='true']">
                <xsl:attribute name="Name">
                    <xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPReportstr]/@Value"/>
                </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="Name"> <xsl:value-of select="@checkName"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:attribute name="Expression">
            <xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPRegex]/@Value"/>
        </xsl:attribute>
        <xsl:choose>
            <xsl:when test="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPMinmatch and @Enabled='true']">
                <xsl:attribute name="MinMatch"> <xsl:value-of select="$vTP/tp:tuningParametersList/tp:tuningParametersList[@Name=$vTPMinmatch and @Enabled='true']/@Value"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <!-- verify default value -->
                <xsl:attribute name="MinMatch"> <xsl:value-of select="'100'"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="AddVirtualSensor"/>
    </xsl:element>
</xsl:template>

<xsl:template name="AddVirtualSensor">
    <xsl:element name="VirtualSensor" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:attribute name="value"> <xsl:value-of select="@virtualSensor"/> </xsl:attribute>
        <xsl:attribute name="ignore"> <xsl:value-of select="@ignore"/> </xsl:attribute>
        <xsl:attribute name="display"> <xsl:value-of select="@display"/> </xsl:attribute>
        <xsl:attribute name="block"> <xsl:value-of select="@block"/> </xsl:attribute>
        <xsl:attribute name="logEvidence">
            <xsl:choose>
                <xsl:when test="@logEvidence = 'true'">
                    <xsl:value-of select="'OffendingPacket'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'None'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:quarantineResponse">
    <xsl:element name="quarantineResponse" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*[name() != 'percentage']"/>
        <xsl:attribute name="rateLimit">
            <xsl:variable name="vAllow" select="1048576 * .01 * (100 - @percentage)"/>
            <xsl:variable name="vAllowInt" select="$vAllow - ($vAllow mod 1)"/>
            <xsl:value-of select="$vAllowInt"/>
        </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/contentAnalyzer">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

