<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ipm="http://www.iss.net/cml/NetProtectModule/ipm" xmlns:ef="http://www.iss.net/cml/NetProtectModule/eventFilters" xmlns:base="http://www.iss.net/cml/NetProtectModule/base">

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'5.0.0'"/>

<xsl:template match="ipm:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates select="ipm:EventFiltersList"/>
    </xsl:element>
</xsl:template>

<xsl:template match="EventFiltersList">
    <xsl:apply-templates/>
</xsl:template>

<xsl:template match="ef:eventFiltersRuleElement">
    <xsl:element name="eventFiltersRuleElement" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:copy-of select="@*[name() != 'Adapter' and name() != 'logEvidence']"/>
        <xsl:attribute name="Interface"> <xsl:value-of select="@Adapter"/> </xsl:attribute>
        <xsl:attribute name="logEvidence">
            <xsl:choose>
                <xsl:when test="@logEvidence = 'true'">
                    <xsl:value-of select="'OffendingPacket'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'None'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="ef:responses">
    <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:quarantineResponse">
    <xsl:element name="quarantineResponse" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:copy-of select="@*[name() != 'percentage']"/>
        <xsl:attribute name="rateLimit">
            <xsl:variable name="vAllow" select="1048576 * .01 * (100 - @percentage)"/>
            <xsl:variable name="vAllowInt" select="$vAllow - ($vAllow mod 1)"/>
            <xsl:value-of select="$vAllowInt"/>
        </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:snmpResponse">
    <xsl:element name="snmpResponse" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:copy-of select="@*"/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:emailResponse">
    <xsl:element name="emailResponse" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:copy-of select="@*"/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:userDefinedResponse">
    <xsl:element name="userDefinedResponse" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:copy-of select="@*"/>
    </xsl:element>
</xsl:template>

<xsl:template match="ef:addressPort">
    <xsl:element name="AddressAndPort" namespace="http://www.iss.net/cml/NetProtectModule/eventFilters">
        <xsl:attribute name="IPVersion">IPv4</xsl:attribute>
        <xsl:attribute name="SourceIP"> <xsl:value-of select="substring-before(base:source/@addressPortControl,':')"/> </xsl:attribute>
        <xsl:attribute name="SourcePort"> <xsl:value-of select="substring-after(base:source/@addressPortControl,':')"/> </xsl:attribute>
        <xsl:attribute name="TargetIP"> <xsl:value-of select="substring-before(base:destination/@addressPortControl,':')"/> </xsl:attribute>
        <xsl:attribute name="TargetPort"> <xsl:value-of select="substring-after(base:destination/@addressPortControl,':')"/> </xsl:attribute>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

