<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ipm="http://www.iss.net/cml/NetProtectModule/ipm" xmlns:se="http://www.iss.net/cml/NetProtectModule/securityEvents" xmlns:base="http://www.iss.net/cml/NetProtectModule/base">

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'5.0.0'"/>

<xsl:template match="ipm:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetProtectModule/securityEvents">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates select="ipm:securityEventsList"/>
    </xsl:element>
</xsl:template>

<xsl:template match="ipm:securityEventsList">
    <xsl:if test="starts-with(@checkName,'Content_Analyzer_')=false  and  starts-with(@virtualSensor,'WebApplicationSecurity')=false">
        <xsl:element name="securityEventsList" namespace="http://www.iss.net/cml/NetProtectModule/securityEvents">
            <xsl:copy-of select="@*[name() != 'isUserOverride' and name() != 'logEvidence']"/>
            <!-- always set isUserOverride to true to fix an existing problem in some policies -->
            <xsl:attribute name="isUserOverride"> <xsl:value-of select="'true'"/> </xsl:attribute>
            <xsl:attribute name="logEvidence">
                <xsl:choose>
                    <xsl:when test="@logEvidence = 'true'">
                        <xsl:value-of select="'OffendingPacket'"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="'None'"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:if>
</xsl:template>

<xsl:template match="se:responses">
    <xsl:element name="responses" namespace="http://www.iss.net/cml/NetProtectModule/securityEvents">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:quarantineResponse">
    <xsl:element name="quarantineResponse" namespace="http://www.iss.net/cml/NetProtectModule/securityEvents">
        <xsl:copy-of select="@*[name() != 'percentage']"/>
        <xsl:attribute name="rateLimit">
            <xsl:variable name="vAllow" select="1048576 * .01 * (100 - @percentage)"/>
            <xsl:variable name="vAllowInt" select="$vAllow - ($vAllow mod 1)"/>
            <xsl:value-of select="$vAllowInt"/>
        </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:snmpResponse">
    <xsl:element name="snmpResponse" namespace="http://www.iss.net/cml/NetProtectModule/securityEvents">
        <xsl:copy-of select="@*"/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:emailResponse">
    <xsl:element name="emailResponse" namespace="http://www.iss.net/cml/NetProtectModule/securityEvents">
        <xsl:copy-of select="@*"/>
    </xsl:element>
</xsl:template>

<xsl:template match="base:userDefinedResponse">
    <xsl:element name="userDefinedResponse" namespace="http://www.iss.net/cml/NetProtectModule/securityEvents">
        <xsl:copy-of select="@*"/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

