<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tp="http://www.iss.net/cml/NetProtectModule/tuningParameters">

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'5.0.0'"/>

<xsl:template match="tp:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetProtectModule/tuningParameters">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates select="tp:tuningParametersList"/>
    </xsl:element>
</xsl:template>

<xsl:template match="tp:tuningParametersList">
    <xsl:apply-templates select="tp:tuningParametersList" mode="leaf"/>
</xsl:template>

<xsl:template match="tp:tuningParametersList" mode="leaf">
    <!-- remove tuning parameters that are no longer supported or no longer needed or with name value length longer than allowed --> 
    <xsl:variable name="lcaseParam" select="translate(@Name,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>
    <xsl:if test="@Name != 'np.firewall.log.prefix' and @Name != 'np.firewall.log.suffix' and @Name != 'np.log.prefix' and @Name != 'np.log.suffix' and
                  @Name != 'engine.packetlog.enabled' and @Name != 'engine.packetlog.fileprefix' and @Name != 'engine.packetlog.filesuffix' and
                  @Name != 'engine.packetlog.maxfiles' and @Name != 'engine.packetlog.maxkbytes' and @Name != 'engine.packetlog.flush' and
                  starts-with($lcaseParam,'pam.ca.')=false and string-length(@Name) &lt; 51 and string-length(@Value) &lt; 2049">
        <xsl:choose>
            <xsl:when test="@Name = 'np.firewall.log.size'">
                <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/tuningParameters">
                    <xsl:copy-of select="@*[name() != 'Description' and name() != 'Value']"/>
                    <xsl:attribute name="Description"> <xsl:value-of select="'Maximum size of a firewall log file in megabytes.'"/> </xsl:attribute>
                    <xsl:attribute name="Value">  <!-- convert bytes to megabytes -->
                        <xsl:choose>
                            <xsl:when test="@Value &lt; 16777216">  <!-- increase size -->
                                <xsl:value-of select="'16'"/>
                            </xsl:when>
                            <xsl:when test="(@Value mod 1048576) = 0">
                                <xsl:value-of select="@Value div 1048576"/>
                            </xsl:when>
                            <xsl:otherwise>  <!-- round the value up -->
                                <xsl:value-of select="((@Value - (@Value mod 1048576)) div 1048576) + 1"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="@Name = 'np.log.size'">
                <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/tuningParameters">
                    <xsl:copy-of select="@*[name() != 'Description' and name() != 'Value']"/>
                    <xsl:attribute name="Description"> <xsl:value-of select="'Maximum size of event log file in megabytes.'"/> </xsl:attribute>
                    <xsl:attribute name="Value">  <!-- convert bytes to megabytes -->
                        <xsl:choose>
                            <xsl:when test="@Value &lt; 16777216">  <!-- increase size -->
                                <xsl:value-of select="'16'"/>
                            </xsl:when>
                            <xsl:when test="(@Value mod 1048576) = 0">
                                <xsl:value-of select="@Value div 1048576"/>
                            </xsl:when>
                            <xsl:otherwise>  <!-- round the value up -->
                                <xsl:value-of select="((@Value - (@Value mod 1048576)) div 1048576) + 1"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="contains(@Name, '.quarantine.rule')"> <!-- migrate OpenSignature quarantine responses -->
                <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/tuningParameters">
                    <xsl:copy-of select="@*[name() != 'Value' and name() != 'Description']"/>
                    <xsl:attribute name="Description"> <xsl:value-of select="substring(@Description, 1, 300)"/> </xsl:attribute>
                    <xsl:attribute name="Value"> <!-- convert percentage to ratelimit -->
                        <xsl:choose>
                            <xsl:when test="contains(@Value, 'percentage:')">
                                <xsl:variable name="percBefore" select="substring-before(@Value, 'percentage:')"/>
                                <xsl:variable name="percTemp" select="substring-after(@Value, 'percentage:')"/>
                                <xsl:variable name="perc">
                                    <xsl:choose>
                                        <xsl:when test="contains($percTemp, ',')">
                                            <xsl:value-of select="substring-before($percTemp, ',')"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="$percTemp"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:variable>
                                <xsl:variable name="percAfter">
                                    <xsl:if test="contains($percTemp, ',')">
                                        <xsl:value-of select="concat(',', substring-after($percTemp, ','))"/>
                                    </xsl:if>
                                </xsl:variable>
                                <xsl:variable name="rateLimit">
                                    <xsl:choose>
                                        <xsl:when test="$perc &lt; 100">
                                            <xsl:variable name="vAllow" select="1048576 * .01 * (100 - $perc)"/>
                                            <xsl:value-of select="$vAllow - ($vAllow mod 1)"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="0"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:variable>
                                <xsl:value-of select="concat($percBefore, 'ratelimit:', $rateLimit, $percAfter)"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@Value"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:when test="contains(@Name, '.user.response')"> <!-- migrate OpenSignature LogEvidence responses -->
                <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/tuningParameters">
                    <xsl:copy-of select="@*[name() != 'Value' and name() != 'Description']"/>
                    <xsl:attribute name="Description"> <xsl:value-of select="substring(@Description, 1, 300)"/> </xsl:attribute>
                    <xsl:attribute name="Value"> <!-- convert LOGEVIDENCE:Default to LOGEVIDENCE:OffendingPacket -->
                        <xsl:choose>
                            <xsl:when test="contains(@Value, 'LOGEVIDENCE:')">
                                <xsl:variable name="respBefore" select="substring-before(@Value, 'LOGEVIDENCE:')"/>
                                <xsl:variable name="respTemp" select="substring-after(@Value, 'LOGEVIDENCE:')"/>
                                <xsl:variable name="respAfter">
                                    <xsl:if test="contains($respTemp, ',')">
                                        <xsl:value-of select="concat(',', substring-after($respTemp, ','))"/>
                                    </xsl:if>
                                </xsl:variable>
                                <xsl:value-of select="concat($respBefore, 'LOGEVIDENCE:OffendingPacket', $respAfter)"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@Value"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetProtectModule/tuningParameters">
                    <xsl:copy-of select="@*[name() != 'Description']"/>
                    <xsl:attribute name="Description"> <xsl:value-of select="substring(@Description, 1, 300)"/> </xsl:attribute>
                </xsl:element>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

</xsl:stylesheet>

