<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tp="http://www.iss.net/cml/NetProtectModule/tuningParameters">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'1.0.0'"/>

<xsl:template match="tp:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/rollPktCap">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:call-template name="AddRPC"/>
    </xsl:element>
</xsl:template>

<xsl:template name="AddRPC">
    <xsl:element name="RPC" namespace="http://www.iss.net/cml/NetworkDefender/rollPktCap">
    <xsl:choose>
        <xsl:when test="/tp:policy/tp:tuningParametersList/tp:tuningParametersList[@Name='engine.packetlog.enabled' and @Enabled='true' and
                       (@Value='on' or @Value='enabled' or @Value='enable' or @Value='true' or @Value='True' or @Value='yes' or @Value='1')]">
            <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            <xsl:element name="RPCElement" namespace="http://www.iss.net/cml/NetworkDefender/rollPktCap">
                <xsl:attribute name="captureFormat"> <xsl:value-of select="'sniffer'"/> </xsl:attribute>
                <xsl:attribute name="adapter"> <xsl:value-of select="'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P'"/> </xsl:attribute>
                <xsl:choose>
                    <xsl:when test="/tp:policy/tp:tuningParametersList/tp:tuningParametersList[@Name='engine.packetlog.maxfiles' and @Enabled='true']">
                        <xsl:attribute name="maximumFiles">
                            <xsl:variable name="vMaxFiles" select="/tp:policy/tp:tuningParametersList/tp:tuningParametersList[@Name='engine.packetlog.maxfiles' and @Enabled='true']/@Value"/>
                            <xsl:choose>
                                <xsl:when test="string($vMaxFiles) = 'NaN'">    <!-- invalid value -->
                                    <xsl:value-of select="@maximumFiles"/>
                                </xsl:when>
                                <xsl:when test="$vMaxFiles &lt; 1">     <!-- minimum size -->
                                    <xsl:value-of select="'1'"/>
                                </xsl:when>
                                <xsl:when test="$vMaxFiles &gt; 100">   <!-- maximum size -->
                                    <xsl:value-of select="'100'"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$vMaxFiles"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:attribute name="maximumFiles"> <xsl:value-of select="'10'"/> </xsl:attribute>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="/tp:policy/tp:tuningParametersList/tp:tuningParametersList[@Name='engine.packetlog.maxkbytes' and @Enabled='true']">
                        <xsl:attribute name="maximumFileSize">
                            <xsl:variable name="vMaxG" select="round(/tp:policy/tp:tuningParametersList/tp:tuningParametersList[@Name='engine.packetlog.maxkbytes' and @Enabled='true']/@Value div 1024)"/>
                            <xsl:choose>
                                <xsl:when test="string($vMaxG) = 'NaN'">    <!-- invalid value -->
                                    <xsl:value-of select="@maximumFileSize"/>
                                </xsl:when>
                                <xsl:when test="$vMaxG &lt; 1">     <!-- minimum size -->
                                    <xsl:value-of select="'1'"/>
                                </xsl:when>
                                <xsl:when test="$vMaxG &gt; 10">    <!-- maximum size -->
                                    <xsl:value-of select="'10'"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$vMaxG"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:attribute name="maximumFileSize"> <xsl:value-of select="'1'"/> </xsl:attribute>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:element>
        </xsl:when>
        <xsl:otherwise>
            <xsl:attribute name="enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            <xsl:element name="RPCElement" namespace="http://www.iss.net/cml/NetworkDefender/rollPktCap">
                <xsl:attribute name="adapter"> <xsl:value-of select="'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P'"/> </xsl:attribute>
                <xsl:attribute name="maximumFiles"> <xsl:value-of select="'10'"/> </xsl:attribute>
                <xsl:attribute name="maximumFileSize"> <xsl:value-of select="'1'"/> </xsl:attribute>
                <xsl:attribute name="captureFormat"> <xsl:value-of select="'pcap'"/> </xsl:attribute>
            </xsl:element>
        </xsl:otherwise>
    </xsl:choose>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

