<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:adapter="http://www.iss.net/cml/NetworkDefender/adapter"  >

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>

valid values for vSpeedDuplexSettings1 and vSpeedDuplexSettings2 are:
  Auto
  10 Mb Half Duplex
  10 Mb Full Duplex
  100 Mb Half Duplex
  100 Mb Full Duplex
  1000 Mb Full Duplex
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

<xsl:param name="vCardID" select="''"/>
<xsl:param name="vCardName" select="''"/>
<xsl:param name="vPort1" select="''"/>
<xsl:param name="vPort1KillDestination" select="'thisPort'"/>
<xsl:param name="vSpeedDuplexSettings1" select="''"/>
<xsl:param name="vPort2" select="''"/>
<xsl:param name="vPort2KillDestination" select="'thisPort'"/>
<xsl:param name="vSpeedDuplexSettings2" select="''"/>
<xsl:param name="vUnanalyzedPolicy" select="'Forward'"/>
<xsl:param name="vPropagateLink" select="'Auto'"/>
<xsl:param name="vAdapterMode" select="''"/>
<xsl:param name="vFailMode" select="'Auto'"/>
<xsl:param name="vHAPartnerCard" select="''"/>

<xsl:template match="adapter:policy">
    <xsl:element name="policy" use-attribute-sets="policyAttributes" namespace="http://www.iss.net/cml/NetworkDefender/adapter">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="adapter:CardManagementList">
    <xsl:element name="CardManagementList" namespace="http://www.iss.net/cml/NetworkDefender/adapter">
        <!-- If element exists, apply-templates to update,
             otherwise copy each card, then insert new element before hamode, and finally copy hamode -->
        <xsl:choose>
            <xsl:when  test="./adapter:CardManagementParameters[@CardID = $vCardID]">
                <xsl:apply-templates/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="AddCard"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template match="adapter:sensorHAMode">
    <xsl:element name="sensorHAMode" namespace="http://www.iss.net/cml/NetworkDefender/adapter">
        <xsl:copy-of select="@*"/>
    </xsl:element>
</xsl:template>

<xsl:template match="adapter:CardManagementParameters">
    <xsl:element name="CardManagementParameters" namespace="http://www.iss.net/cml/NetworkDefender/adapter">
        <xsl:choose>
            <xsl:when test="@CardID != $vCardID">
                <xsl:copy-of select="@*"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="CardID"> <xsl:value-of select="$vCardID"/> </xsl:attribute>
                <xsl:attribute name="CardName"> <xsl:value-of select="$vCardName"/> </xsl:attribute>
                <xsl:attribute name="Port1"> <xsl:value-of select="$vPort1"/> </xsl:attribute>
                <xsl:attribute name="Port1KillDestination"> <xsl:value-of select="$vPort1KillDestination"/> </xsl:attribute>
                <xsl:attribute name="SpeedDuplexSettings1"> <xsl:value-of select="$vSpeedDuplexSettings1"/> </xsl:attribute>
                <xsl:attribute name="Port2"> <xsl:value-of select="$vPort2"/> </xsl:attribute>
                <xsl:attribute name="Port2KillDestination"> <xsl:value-of select="$vPort2KillDestination"/> </xsl:attribute>
                <xsl:attribute name="SpeedDuplexSettings2"> <xsl:value-of select="$vSpeedDuplexSettings2"/> </xsl:attribute>
                <xsl:attribute name="UnanalyzedPolicy"> <xsl:value-of select="$vUnanalyzedPolicy"/> </xsl:attribute>
                <xsl:attribute name="PropagateLink"> <xsl:value-of select="$vPropagateLink"/> </xsl:attribute>
                <xsl:attribute name="AdapterMode"> <xsl:value-of select="$vAdapterMode"/> </xsl:attribute>
                <xsl:attribute name="FailMode"> <xsl:value-of select="$vFailMode"/> </xsl:attribute>
                <xsl:attribute name="HAPartnerCard"> <xsl:value-of select="$vHAPartnerCard"/> </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template name="AddCard">
    <xsl:for-each select="./adapter:CardManagementParameters">
        <xsl:copy-of select="current()"/>
    </xsl:for-each>
    <xsl:call-template name="AddCardElement"/>
    <xsl:copy-of select="./adapter:sensorHAMode" />
</xsl:template>

<xsl:template name="AddCardElement">
    <xsl:element name="CardManagementParameters" namespace="http://www.iss.net/cml/NetworkDefender/adapter">
        <xsl:attribute name="CardID"> <xsl:value-of select="$vCardID"/> </xsl:attribute>
        <xsl:attribute name="CardName"> <xsl:value-of select="$vCardName"/> </xsl:attribute>
        <xsl:attribute name="Port1"> <xsl:value-of select="$vPort1"/> </xsl:attribute>
        <xsl:attribute name="Port1KillDestination"> <xsl:value-of select="$vPort1KillDestination"/> </xsl:attribute>
        <xsl:attribute name="SpeedDuplexSettings1"> <xsl:value-of select="$vSpeedDuplexSettings1"/> </xsl:attribute>
        <xsl:attribute name="Port2"> <xsl:value-of select="$vPort2"/> </xsl:attribute>
        <xsl:attribute name="Port2KillDestination"> <xsl:value-of select="$vPort2KillDestination"/> </xsl:attribute>
        <xsl:attribute name="SpeedDuplexSettings2"> <xsl:value-of select="$vSpeedDuplexSettings2"/> </xsl:attribute>
        <xsl:attribute name="UnanalyzedPolicy"> <xsl:value-of select="$vUnanalyzedPolicy"/> </xsl:attribute>
        <xsl:attribute name="PropagateLink"> <xsl:value-of select="$vPropagateLink"/> </xsl:attribute>
        <xsl:attribute name="AdapterMode"> <xsl:value-of select="$vAdapterMode"/> </xsl:attribute>
        <xsl:attribute name="FailMode"> <xsl:value-of select="$vFailMode"/> </xsl:attribute>
        <xsl:attribute name="HAPartnerCard"> <xsl:value-of select="$vHAPartnerCard"/> </xsl:attribute>
    </xsl:element>
</xsl:template>

<xsl:attribute-set name="policyAttributes">
    <xsl:attribute name="xmlns:cml">http://www.iss.net/cml</xsl:attribute>
    <xsl:attribute name="xmlns:common">http://www.iss.net/cml/common</xsl:attribute>
    <xsl:attribute name="xmlns:cpe">http://www.iss.net/cml/cpe</xsl:attribute>
    <xsl:attribute name="xmlns:xsi">http://www.w3.org/2001/XMLSchema-instance</xsl:attribute>
</xsl:attribute-set>

</xsl:stylesheet>

