<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:mgmt="http://www.iss.net/cml/NetworkDefender/mgmt">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>

Example: /usr/bin/Xalan -i 4 -o /tmp/npmgmt5_0.xml -p pSchemaVersion "'5.0.0'" -p pRegister "'true'" -p pUseLocalSettings "'true'" -p pGroupName "'Test Group'" -p pHeartbeatInterval "'600'" -p pSpaLogLevel "'verbose'" -p pAgentManagers "'first-time-trust#sp-server-name#server.iss.net#4000#userid#encrypted+password=#true#proxy.iss.net#5000|first-time-trust#sp-server-name2#server.iss.net#4000###false##'" npmgmt5_0.xml mgmt500.xslt
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="''"/>
<xsl:param name="pRegister" select="''"/>           <!-- true/false -->
<xsl:param name="pUseLocalSettings" select="''"/>   <!-- true/false -->
<xsl:param name="pGroupName" select="''"/>
<xsl:param name="pHeartbeatInterval" select="''"/>  <!-- value in seconds -->
<xsl:param name="pCryptoLevel" select="''"/>        <!-- compatible, strict -->
<xsl:param name="pSpaLogLevel" select="''"/>        <!-- normal, debug, verbose -->
<xsl:param name="pAgentManagers" select="''"/>      <!-- am1param1#am1param2#...#am1paramN|am2param1#...#am2paramN -->

<xsl:template match="mgmt:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/mgmt">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:choose>
          <xsl:when test="string-length($pSchemaVersion) > 0">
            <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@schema-version"/>
          </xsl:otherwise>
        </xsl:choose>  
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="mgmt:Config">
    <xsl:element name="Config" namespace="http://www.iss.net/cml/NetworkDefender/mgmt">
        <xsl:choose>
          <xsl:when test="string-length($pRegister) > 0">
            <xsl:attribute name="Enabled"> <xsl:value-of select="$pRegister"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@Enabled"/>
          </xsl:otherwise>
        </xsl:choose>  
        <xsl:choose>
          <xsl:when test="string-length($pGroupName) > 0">
            <xsl:attribute name="GroupNameHint"> <xsl:value-of select="$pGroupName"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@GroupNameHint"/>
          </xsl:otherwise>
        </xsl:choose>  
        <xsl:choose>
          <xsl:when test="string-length($pHeartbeatInterval) > 0">
            <xsl:attribute name="HeartbeatInterval"> <xsl:value-of select="$pHeartbeatInterval"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@HeartbeatInterval"/>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="string-length($pCryptoLevel) > 0">
            <xsl:attribute name="CryptoLevel"> <xsl:value-of select="$pCryptoLevel"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@CryptoLevel"/>
          </xsl:otherwise>
        </xsl:choose>	
        <xsl:choose>
          <xsl:when test="string-length($pSpaLogLevel) > 0">
            <xsl:attribute name="SpaLogLevel"> <xsl:value-of select="$pSpaLogLevel"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@SpaLogLevel"/>
          </xsl:otherwise>
        </xsl:choose>  
        <xsl:choose>
          <xsl:when test="string-length($pUseLocalSettings) > 0">
            <xsl:attribute name="UseLocalSettings"> <xsl:value-of select="$pUseLocalSettings"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@UseLocalSettings"/>
          </xsl:otherwise>
        </xsl:choose>  
        <xsl:call-template name="AddAgentManagers">
            <xsl:with-param name="amList" select="$pAgentManagers"/>
        </xsl:call-template>
    </xsl:element>
</xsl:template>

<xsl:template name="AddAgentManagers">
    <xsl:param name="amList" select="''"/>
    <xsl:param name="ordinal" select="'0'"/>
    <xsl:if test="string-length($amList) > 0">
        <xsl:choose>
            <xsl:when test="contains($amList, '|')">
                <xsl:call-template name="AddAMElement">
                    <xsl:with-param name="amElement" select="substring-before($amList, '|')"/>
                    <xsl:with-param name="ordinal" select="$ordinal"/>
                </xsl:call-template>
                <xsl:call-template name="AddAgentManagers">
                    <xsl:with-param name="amList" select="substring-after($amList, '|')"/>
                    <xsl:with-param name="ordinal" select="$ordinal + 1"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="AddAMElement">
                    <xsl:with-param name="amElement" select="$amList"/>
                    <xsl:with-param name="ordinal" select="$ordinal"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<xsl:template name="AddAMElement">
    <xsl:param name="amElement" select="''"/>
    <xsl:param name="ordinal" select="''"/>
    <xsl:if test="contains($amElement, '#')">
        <xsl:variable name="vAuthLevel" select="substring-before($amElement, '#')"/>
        <xsl:variable name="vTemp1" select="substring-after($amElement, '#')"/>
        <xsl:if test="contains($vTemp1, '#')">
            <xsl:variable name="vName" select="substring-before($vTemp1, '#')"/>
            <xsl:variable name="vTemp2" select="substring-after($vTemp1, '#')"/>
            <xsl:if test="contains($vTemp2, '#')">
                <xsl:variable name="vAddr" select="substring-before($vTemp2, '#')"/>
                <xsl:variable name="vTemp3" select="substring-after($vTemp2, '#')"/>
                <xsl:if test="contains($vTemp3, '#')">
                    <xsl:variable name="vPort" select="substring-before($vTemp3, '#')"/>
                    <xsl:variable name="vTemp4" select="substring-after($vTemp3, '#')"/>
                    <xsl:if test="contains($vTemp4, '#')">
                        <xsl:variable name="vUsername" select="substring-before($vTemp4, '#')"/>
                        <xsl:variable name="vTemp5" select="substring-after($vTemp4, '#')"/>
                        <xsl:if test="contains($vTemp5, '#')">
                            <xsl:variable name="vPassword" select="substring-before($vTemp5, '#')"/>
                            <xsl:variable name="vTemp6" select="substring-after($vTemp5, '#')"/>
                            <xsl:if test="contains($vTemp6, '#')">
                                <xsl:variable name="vUseProxy" select="substring-before($vTemp6, '#')"/>
                                <xsl:variable name="vTemp7" select="substring-after($vTemp6, '#')"/>
                                <xsl:if test="contains($vTemp7, '#')">
                                    <xsl:variable name="vProxyAddr" select="substring-before($vTemp7, '#')"/>
                                    <xsl:variable name="vProxyPort" select="substring-after($vTemp7, '#')"/>
                                    <xsl:element name="AgentManager" namespace="http://www.iss.net/cml/NetworkDefender/mgmt">
                                        <xsl:attribute name="EventServerAuthenticationLevel"> <xsl:value-of select="$vAuthLevel"/> </xsl:attribute>
                                        <xsl:attribute name="EventServerName"> <xsl:value-of select="$vName"/> </xsl:attribute>
                                        <xsl:attribute name="EventServerIPorDNS"> <xsl:value-of select="$vAddr"/> </xsl:attribute>
                                        <xsl:attribute name="EventServerPort"> <xsl:value-of select="$vPort"/> </xsl:attribute>
                                        <xsl:attribute name="EventServerPassword"> <xsl:value-of select="'****'"/> </xsl:attribute>
                                        <xsl:attribute name="EventServerUsername"> <xsl:value-of select="$vUsername"/> </xsl:attribute>
                                        <xsl:attribute name="EventServerEncPassword"> <xsl:value-of select="$vPassword"/> </xsl:attribute>
                                        <xsl:attribute name="Ordinal"> <xsl:value-of select="$ordinal"/> </xsl:attribute>
                                        <xsl:attribute name="ProxyEnabled"> <xsl:value-of select="$vUseProxy"/> </xsl:attribute>
                                        <xsl:attribute name="ProxyIPorDNS"> <xsl:value-of select="$vProxyAddr"/> </xsl:attribute>
                                        <xsl:attribute name="ProxyPort"> <xsl:value-of select="$vProxyPort"/> </xsl:attribute>
                                    </xsl:element>
                                </xsl:if>
                            </xsl:if>
                        </xsl:if>
                    </xsl:if>
                </xsl:if>
            </xsl:if>
        </xsl:if>
    </xsl:if>
</xsl:template>

</xsl:stylesheet>

