<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:net="http://www.iss.net/cml/NetworkDefender/network">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>

Example: /usr/bin/Xalan -i 4 -o /tmp/ndnetwork1_0.xml -p pSchemaVersion "'1.0.0'" -p pHostName "'wrath.iss.net'" -p pEnableMDns "'true'" -p pDnsIpType "'IPv4'" -p pDnsPrimary "'209.134.1.1'" -p pDnsSecondary "'209.134.1.2'" -p pDnsTertiary "'209.134.1.3'" -p pDnsList "'iss.net|iss.com||ibm.com'" -p pMgmtSpeed "'1000MbFull'" -p pMgmtIpv4Type "'Static'" -p pMgmtIpv4Addr "'172.16.249.81'" -p pMgmtIpv4Mask "'255.255.255.0'" -p pMgmtIpv4Gateway "'172.16.249.1'" -p pMgmtIpv6Type "'Static'" -p pMgmtIpv6Addr "'1::1'" -p pMgmtIpv6Prefix "'1::'" -p pMgmtIpv6Gateway "'1::2'" -p pKillSpeed "'100MbFull'" ndnetwork1_0.xml network100.xslt

valid values for pMgmtSpeed and pKillSpeed are:
  Auto
  10 Mb Half Duplex
  10 Mb Full Duplex
  100 Mb Half Duplex
  100 Mb Full Duplex
  1000 Mb Full Duplex

You must pass pDnsIpType="IPv4OrIPv6Address" along with pDnsPrimary, pDnsSecondary or pDnsTertiary values
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="''"/>
<xsl:param name="pHostName" select="''"/>
<xsl:param name="pEnableMDns" select="''"/>
<xsl:param name="pDnsIpType" select="''"/>       <!-- AutoAssigned|IPv4OrIPv6Address -->
<xsl:param name="pDnsPrimary" select="''"/>
<xsl:param name="pDnsSecondary" select="''"/>
<xsl:param name="pDnsTertiary" select="''"/>
<xsl:param name="pDnsList" select="'_empty_list_'"/>    <!-- 'name|name|name' -->
<xsl:param name="pMgmtSpeed" select="''"/>
<xsl:param name="pMgmtIpv4Type" select="''"/>    <!-- DHCP|Static -->
<xsl:param name="pMgmtIpv4Addr" select="''"/>
<xsl:param name="pMgmtIpv4Mask" select="''"/>
<xsl:param name="pMgmtIpv4Gateway" select="''"/>
<xsl:param name="pMgmtIpv6Type" select="''"/>    <!-- Auto|Static -->
<xsl:param name="pMgmtIpv6Addr" select="''"/>
<xsl:param name="pMgmtIpv6Prefix" select="''"/>
<xsl:param name="pMgmtIpv6Gateway" select="''"/>
<xsl:param name="pKillSpeed" select="''"/>

<xsl:template match="net:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>

        <xsl:choose>
          <xsl:when test="string-length($pSchemaVersion) > 0">
            <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@schema-version"/>
          </xsl:otherwise>
        </xsl:choose>  

        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="net:Config">
    <xsl:element name="Config" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:copy-of select="@*[name() != 'HostName']"/>

        <xsl:choose>
          <xsl:when test="string-length($pHostName) > 0">
            <xsl:attribute name="HostName"> <xsl:value-of select="$pHostName"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@HostName"/>
          </xsl:otherwise>
        </xsl:choose>  

        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="net:DNS">
    <xsl:element name="DNS" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:copy-of select="@*[name() != 'mDNSResponder']"/>

        <xsl:choose>
          <xsl:when test="string-length($pEnableMDns) > 0">
            <xsl:attribute name="mDNSResponder"> <xsl:value-of select="$pEnableMDns"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@mDNSResponder"/>
          </xsl:otherwise>
        </xsl:choose>  

        <xsl:choose>
          <xsl:when test="string-length($pDnsIpType) > 0">
            <xsl:choose>
                <xsl:when test="$pDnsIpType = 'AutoAssigned'">
                    <xsl:element name="AutoAssigned" namespace="http://www.iss.net/cml/NetworkDefender/network"/>
                </xsl:when>

                <xsl:otherwise>
                    <xsl:element name="IPv4OrIPv6Address" namespace="http://www.iss.net/cml/NetworkDefender/network">
    
                        <xsl:choose>
                          <xsl:when test="string-length($pDnsPrimary) > 0">
                            <xsl:attribute name="PrimaryDNS"> <xsl:value-of select="$pDnsPrimary"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@PrimaryDNS"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                        <xsl:choose>
                          <xsl:when test="string-length($pDnsSecondary) > 0">
                            <xsl:attribute name="SecondaryDNS"> <xsl:value-of select="$pDnsSecondary"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@SecondaryDNS"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                        <xsl:choose>
                          <xsl:when test="string-length($pDnsTertiary) > 0">
                            <xsl:attribute name="TertiaryDNS"> <xsl:value-of select="$pDnsTertiary"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@TertiaryDNS"/>
                          </xsl:otherwise>
                        </xsl:choose>  
                    </xsl:element>
                </xsl:otherwise>
            </xsl:choose>
          </xsl:when>

          <!-- copy-in existing IPv4OrIPv6Address or AutoAssigned elements -->
          <xsl:otherwise>
            <xsl:choose>
              <xsl:when test="./net:AutoAssigned">
                <xsl:element name="AutoAssigned" namespace="http://www.iss.net/cml/NetworkDefender/network"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:for-each select="./net:IPv4OrIPv6Address">			   
                  <xsl:element name="IPv4OrIPv6Address" namespace="http://www.iss.net/cml/NetworkDefender/network">
                  <xsl:copy-of select="@*"/>
                  </xsl:element>
                </xsl:for-each>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:otherwise>
        </xsl:choose>  

        <xsl:choose>
          <xsl:when test="string-length($pDnsList) > 0 and $pDnsList != '_empty_list_'">
            <xsl:call-template name="AddDnsSearchPathList">
              <xsl:with-param name="dnsList" select="$pDnsList"/>
            </xsl:call-template>
          </xsl:when>

          <xsl:otherwise>
            <xsl:choose>
              <xsl:when test="$pDnsList = '_empty_list_'">
                <xsl:for-each select="./net:DNSSearchPathList">			   
                  <xsl:element name="DNSSearchPathList" namespace="http://www.iss.net/cml/NetworkDefender/network">
                    <xsl:copy-of select="@*"/>
                  </xsl:element>
                </xsl:for-each>
              </xsl:when>
            </xsl:choose>
          </xsl:otherwise>

        </xsl:choose>  

    </xsl:element>
</xsl:template>

<xsl:template match="net:MgmtInterface">
    <xsl:element name="MgmtInterface" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:copy-of select="@*[name() != 'SpeedDuplex']"/>

          <xsl:choose>
            <xsl:when test="string-length($pMgmtSpeed) > 0">
              <xsl:attribute name="SpeedDuplex"> <xsl:value-of select="$pMgmtSpeed"/> </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:copy-of select="@SpeedDuplex"/>
            </xsl:otherwise>
          </xsl:choose>  

        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="net:IPv4">
    <xsl:element name="IPv4" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:choose>

            <!-- user modifies IPv4 settings... -->
            <xsl:when test="string-length($pMgmtIpv4Type) > 0">
              <xsl:choose>

                <xsl:when test="$pMgmtIpv4Type = 'Static'">
                    <xsl:element name="Static" namespace="http://www.iss.net/cml/NetworkDefender/network">
    
                        <xsl:choose>
                          <xsl:when test="string-length($pMgmtIpv4Addr) > 0">
                            <xsl:attribute name="IpAddr"> <xsl:value-of select="$pMgmtIpv4Addr"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@IpAddr"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                        <xsl:choose>
                          <xsl:when test="string-length($pMgmtIpv4Mask) > 0">
                            <xsl:attribute name="SubnetMask"> <xsl:value-of select="$pMgmtIpv4Mask"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@SubnetMask"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                        <xsl:choose>
                          <xsl:when test="string-length($pMgmtIpv4Gateway) > 0">
                            <xsl:attribute name="GatewayIpAddr"> <xsl:value-of select="$pMgmtIpv4Gateway"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@GatewayIpAddr"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                    </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:element name="DHCP" namespace="http://www.iss.net/cml/NetworkDefender/network"/>
                </xsl:otherwise>

              </xsl:choose>
            </xsl:when>

            <!-- user doesn't modify IPv4 settings... -->
            <xsl:otherwise>
              <xsl:choose>

                <!-- write DHCP element -->
                <xsl:when test="./net:DHCP">
                  <xsl:element name="DHCP" namespace="http://www.iss.net/cml/NetworkDefender/network"/>
                </xsl:when>
                <xsl:otherwise>
                  <!-- copy all existing Static IPv4 settings -->
                  <xsl:for-each select="./net:Static">			   
                    <xsl:element name="Static" namespace="http://www.iss.net/cml/NetworkDefender/network">
                    <xsl:copy-of select="@*"/>
                    </xsl:element>
                  </xsl:for-each>
                </xsl:otherwise>

              </xsl:choose>
            </xsl:otherwise>

          </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template match="net:IPv6">
    <xsl:element name="IPv6" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:choose>

            <!-- user modifies IPv6 settings... -->
            <xsl:when test="string-length($pMgmtIpv6Type) > 0">
              <xsl:choose>

                <xsl:when test="$pMgmtIpv6Type = 'Static'">
                    <xsl:element name="Static" namespace="http://www.iss.net/cml/NetworkDefender/network">

                        <xsl:choose>
                          <xsl:when test="string-length($pMgmtIpv6Addr) > 0">
                            <xsl:attribute name="IpAddr"> <xsl:value-of select="$pMgmtIpv6Addr"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@IpAddr"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                        <xsl:choose>
                          <xsl:when test="string-length($pMgmtIpv6Prefix) > 0">
                            <xsl:attribute name="Prefix"> <xsl:value-of select="$pMgmtIpv6Prefix"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@Prefix"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                        <xsl:choose>
                          <xsl:when test="string-length($pMgmtIpv6Gateway) > 0">
                             <xsl:attribute name="GatewayIpAddr"> <xsl:value-of select="$pMgmtIpv6Gateway"/> </xsl:attribute>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:copy-of select="@GatewayIpAddr"/>
                          </xsl:otherwise>
                        </xsl:choose>  

                    </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:element name="Auto" namespace="http://www.iss.net/cml/NetworkDefender/network"/>
                </xsl:otherwise>

              </xsl:choose>
            </xsl:when>

            <!-- user doesn't modify IPv6 settings... -->
            <xsl:otherwise>
              <xsl:choose>

                <!-- write Auto element -->
                <xsl:when test="./net:Auto">
                  <xsl:element name="Auto" namespace="http://www.iss.net/cml/NetworkDefender/network"/>
                </xsl:when>
                <xsl:otherwise>
                  <!-- copy all existing Static IPv6 settings -->
                  <xsl:for-each select="./net:Static">			   
                    <xsl:element name="Static" namespace="http://www.iss.net/cml/NetworkDefender/network">
                    <xsl:copy-of select="@*"/>
                    </xsl:element>
                  </xsl:for-each>
                </xsl:otherwise>

              </xsl:choose>
            </xsl:otherwise>

          </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template match="net:KillInterface">
    <xsl:element name="KillInterface" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:copy-of select="@*[name() != 'SpeedDuplex']"/>

        <xsl:choose>
          <xsl:when test="string-length($pKillSpeed) > 0">
             <xsl:attribute name="SpeedDuplex"> <xsl:value-of select="$pKillSpeed"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@SpeedDuplex"/>
          </xsl:otherwise>
        </xsl:choose>  

        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template name="AddDnsSearchPathList">
    <xsl:param name="dnsList" select="''"/>
    <xsl:param name="ordinal" select="'0'"/>

    <xsl:choose>
        <xsl:when test="contains($dnsList, '|')">
            <xsl:variable name="dns" select="substring-before($dnsList, '|')"/>
            <xsl:choose>
                <xsl:when test="string-length($dns) > 0">
                    <xsl:element name="DNSSearchPathList" namespace="http://www.iss.net/cml/NetworkDefender/network">
                        <xsl:attribute name="Id"> <xsl:value-of select="$ordinal"/> </xsl:attribute>
                        <xsl:attribute name="DomainName"> <xsl:value-of select="$dns"/> </xsl:attribute>
                    </xsl:element>
                    <xsl:call-template name="AddDnsSearchPathList">
                        <xsl:with-param name="dnsList" select="substring-after($dnsList, '|')"/>
                        <xsl:with-param name="ordinal" select="$ordinal + 1"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="AddDnsSearchPathList">
                        <xsl:with-param name="dnsList" select="substring-after($dnsList, '|')"/>
                        <xsl:with-param name="ordinal" select="$ordinal"/>
                    </xsl:call-template>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        <xsl:when test="string-length($dnsList) > 0">
            <xsl:element name="DNSSearchPathList" namespace="http://www.iss.net/cml/NetworkDefender/network">
                <xsl:attribute name="Id"> <xsl:value-of select="$ordinal"/> </xsl:attribute>
                <xsl:attribute name="DomainName"> <xsl:value-of select="$dnsList"/> </xsl:attribute>
            </xsl:element>
        </xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/network">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

