<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ntp="http://www.iss.net/cml/NetworkDefender/ntp">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>
Example: Xalan -p pNtpServers "'server1|server2|server3'" -p pNtpInterval "'15'" -o output.xml ndntp1_0.xml ntp100.xsl
NTP Version: NTPv1|NTPv2|NTPv3|NTPv4

NTP Server options:
  if you pass a value for -p pAddNtpServers, it will ADD your NTP server to the existing list
  if you pass a value for -p pDeleteAllNtpServers, it will remove all NTP servers from the list
  if you pass a value for -p pDeleteNtpServer, it will remove all matching NTP servers from the list
  if you pass a value for -p pNtpServers, it will add ONLY the NTP servers you pass,
     NO existing NTP servers will be preserved
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="''"/>
<xsl:param name="pNtpVersion" select="''"/>
<xsl:param name="pNtpInterval" select="''"/>
<xsl:param name="pNtpServers" select="'_empty_list_'"/>
<xsl:param name="pDeleteAllNtpServers" select="''"/>
<xsl:param name="pDeleteNtpServer" select="''"/>
<xsl:param name="pAddNtpServers" select="''"/>

<xsl:template match="ntp:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>

        <xsl:choose>
          <xsl:when test="string-length($pSchemaVersion) > 0">
            <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@schema-version"/>
          </xsl:otherwise>
        </xsl:choose>  

        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="ntp:ntpConfig">
    <xsl:element name="ntpConfig" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
        <xsl:copy-of select="@*[name() != 'synchIntervalMinutes']"/>

        <!-- synchIntervalMinutes -->
        <xsl:choose>
          <!-- synchIntervalMinutes passed, replace -->
          <xsl:when test="string-length($pNtpInterval) > 0">
            <xsl:attribute name="synchIntervalMinutes"> <xsl:value-of select="$pNtpInterval"/> </xsl:attribute>
          </xsl:when>
          <!-- synchIntervalMinutes not passed, keep old value -->
          <xsl:otherwise>
            <xsl:copy-of select="@synchIntervalMinutes"/>
          </xsl:otherwise>
        </xsl:choose>  

        <!-- add NTP servers to serverList -->
        <xsl:choose>
          <xsl:when test="string-length($pDeleteAllNtpServers) = 0 and $pNtpServers != ''">

            <xsl:choose>
              <xsl:when test="string-length($pDeleteNtpServer) > 0">
                <!-- copy all NTP servers except the one we want to delete -->
                <xsl:for-each select="./ntp:NtpServer[@server != $pDeleteNtpServer]">			   
                    <xsl:copy-of select="."/>
                </xsl:for-each>
              </xsl:when>

              <xsl:when test="string-length($pNtpServers) > 0 and $pNtpServers != '_empty_list_'">
                <xsl:call-template name="AddNtpServers">
                  <xsl:with-param name="serverList" select="$pNtpServers"/>
                </xsl:call-template>

                <xsl:choose>
                  <xsl:when test="count(./ntp:NtpServer) = 0">
                    <xsl:apply-templates/>
                  </xsl:when>
                </xsl:choose>
              </xsl:when>

              <xsl:otherwise>
                <xsl:call-template name="AddNtpServers">
                    <xsl:with-param name="serverList" select="$pAddNtpServers"/>
                </xsl:call-template>
                <xsl:apply-templates/>
              </xsl:otherwise>
            </xsl:choose>  

          </xsl:when>
        </xsl:choose>  

    </xsl:element>
</xsl:template>

<xsl:template name="AddNtpServers">
    <xsl:param name="serverList" select="''"/>
    <xsl:choose>
        <xsl:when test="contains($serverList, '|')">
            <xsl:call-template name="AddNtpServers">
                <xsl:with-param name="serverList" select="substring-before($serverList, '|')"/>
            </xsl:call-template>            
            <xsl:call-template name="AddNtpServers">
                <xsl:with-param name="serverList" select="substring-after($serverList, '|')"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:when test="string-length($serverList) > 0">
            <xsl:element name="NtpServer" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
                <xsl:attribute name="server"> <xsl:value-of select="$serverList"/> </xsl:attribute>
                <xsl:attribute name="enabled">true</xsl:attribute>
                <xsl:element name="version" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
                <xsl:choose>
                    <xsl:when test="string-length($pNtpVersion) > 0">
                        <xsl:element name="{$pNtpVersion}" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
                            <xsl:if test="$pNtpVersion = 'NTPv3' or $pNtpVersion = 'NTPv4'">
                                <xsl:element name="NtpAuthNone" namespace="http://www.iss.net/cml/NetworkDefender/ntp"/>
                            </xsl:if>
                        </xsl:element>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:element name="NTPv3" namespace="http://www.iss.net/cml/NetworkDefender/ntp">		
                            <xsl:element name="NtpAuthNone" namespace="http://www.iss.net/cml/NetworkDefender/ntp"/>
                        </xsl:element>
                    </xsl:otherwise>
                </xsl:choose>
                </xsl:element>
            </xsl:element>
        </xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>
