<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ntp="http://www.iss.net/cml/NetworkDefender/ntp">
<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

<xsl:param name="pSchemaVersion" select="'1.1.0'"/>

<xsl:template match="ntp:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- Disable NTP if user choose unsupported cipher suites or hash functions for autokey authentication -->
<xsl:template match="ntp:NtpServer">
	<xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
		<xsl:copy-of select="@*[name() != 'enabled']"/>
		<xsl:attribute name="enabled">
		<xsl:choose>
			<xsl:when test="@enabled='true' and ntp:version/ntp:NTPv4/ntp:NtpAuthAutokey and 
							(//ntp:ntpAutokeyConfig/@cryptoDigest = 'MD2' or
							 //ntp:ntpAutokeyConfig/@cryptoDigest = 'MDC2' or
							 //ntp:ntpAutokeyConfig/@cryptoDigest = 'SHA' or
							 //ntp:NtpKeygenOptions/@encryptScheme = 'RSA-MD2' or 
			                 //ntp:NtpKeygenOptions/@encryptScheme = 'RSA-MDC2' or 
							 //ntp:NtpKeygenOptions/@encryptScheme = 'RSA-SHA' or 
							 //ntp:NtpKeygenOptions/@encryptScheme = 'DSA-SHA')" >
				<xsl:value-of select="'false'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="@enabled"/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:attribute>
		<xsl:apply-templates/>
	</xsl:element>
</xsl:template>

<!-- Reset cryptoDigest to default if user choose unsupported hash function for autokey message digest -->
<xsl:template match="ntp:ntpAutokeyConfig">
	<xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
		<xsl:copy-of select="@*[name() != 'cryptoDigest']"/>
		<xsl:attribute name="cryptoDigest">
		<xsl:choose>
			<xsl:when test="@cryptoDigest='MD2' or 
			                @cryptoDigest='MDC2' or 
							@cryptoDigest='SHA'">
				<xsl:value-of select="'MD5'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="@cryptoDigest"/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:attribute>
		<xsl:apply-templates/>
	</xsl:element>
</xsl:template>

<!-- Reset encryption scheme to default if user choose unsupported cipher suites for autokey authentication -->
<xsl:template match="ntp:NtpKeygenOptions">
	<xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
		<xsl:copy-of select="@*[name() != 'encryptScheme']"/>
		<xsl:attribute name="encryptScheme">
		<xsl:choose>
			<xsl:when test="@encryptScheme='RSA-MD2' or 
			                @encryptScheme='RSA-MDC2' or 
			                @encryptScheme='RSA-SHA' or 
			                @encryptScheme='DSA-SHA'">
				<xsl:value-of select="'RSA-MD5'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="@encryptScheme"/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:attribute>
		<xsl:apply-templates/>
	</xsl:element>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/ntp">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>
