<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sc="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
    <xsl:output method="text"/>

    <xsl:param name="pQuery" select="''"/>
    <xsl:param name="pSeparator" select="','"/>

    <xsl:template match="sc:policy">
        <xsl:call-template name="query"/>
    </xsl:template>

    <xsl:template name="query">
        <xsl:param name="pQuery" select="$pQuery"/>
        <xsl:choose>
            <xsl:when test="contains($pQuery, ',')">
                <xsl:call-template name="query">
                    <xsl:with-param name="pQuery" select="substring-before($pQuery, ',')"/>
                </xsl:call-template>
                <xsl:value-of select="$pSeparator"/>
                <xsl:call-template name="query">
                    <xsl:with-param name="pQuery" select="substring-after($pQuery, ',')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="query1">
                    <xsl:with-param name="pQuery" select="$pQuery"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="query1">
        <xsl:param name="pQuery" select="''"/>
        <xsl:choose>
            <xsl:when test="$pQuery = 'version'">
                <xsl:value-of select="./@version"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'schemaVersion'">
                <xsl:value-of select="./@schema-version"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'model'">
                <xsl:value-of select="./sc:sensorIdentity/@model"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'captureBufferSize'">
                <xsl:value-of select="./sc:sensorIdentity/@captureBufferSize"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'portCount' or $pQuery = 'numberOfPorts'">
                <xsl:value-of select="./sc:sensorIdentity/@numberOfPorts"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'cpuCount'">
                <xsl:value-of select="./sc:sensorIdentity/@cpuCount"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'mgmtPortCount'">
                <xsl:value-of select="./sc:sensorIdentity/@mgmtPortCount"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'mgmtPortDriver'">
                <xsl:value-of select="./sc:sensorIdentity/@mgmtPortDriver"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'supportsHA'">
                <xsl:value-of select="./sc:sensorIdentity/@supportsHA"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'driverName'">
                <xsl:value-of select="./sc:sensorIdentity/@driverName"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'driverTaskletModeEnabled'">
                <xsl:value-of select="./sc:sensorIdentity/@driverTaskletModeEnabled"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'hasNPU'">
                <xsl:value-of select="./sc:sensorIdentity/@hasNPU"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'hasCluster' or $pQuery = 'clusterMode'">
                <xsl:value-of select="./sc:sensorIdentity/@clusterMode"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'isVM'">
                <xsl:value-of select="./sc:sensorIdentity/@isVM"/>
            </xsl:when>
            <xsl:when test="$pQuery = 'NPUInterface'">
                <xsl:value-of select="./sc:sensorIdentity/@NPUInterface"/>
            </xsl:when>
            <xsl:when test="starts-with($pQuery, 'avp:')">
                <xsl:call-template name="queryAvp">
                    <xsl:with-param name="avpName" select="substring-after($pQuery, ':')"/>
                </xsl:call-template>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="queryAvp">
        <xsl:param name="avpName"/>
        <xsl:if test="./sc:avps/sc:avp[@avpName = $avpName]">
            <xsl:value-of select="./sc:avps/sc:avp[@avpName = $avpName]/@avpValue"/>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
