<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sc="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

    <!--
    Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>
    Example: Xalan -p pSlot2Part "'NMC-1004'" -p pSlot2Bypass "'1'" -p pSlot2Speed "'Auto|1Gf|10Gf'" -p pSlot2PortCount "'2'" -o output.xml sensorCapabilities5_1.xml sensorCapabilities510_SetNMC.xslt

    Parameters:
                        # can be 1, 2, or 3, indicating the NMC slot index.
        pSlot#Part      Specify part name of NMC #. For example, 'NMC-1004',
                        'NMC-0108', or 'NMC-0803'.
        pSlot#Bypass    Indicate if NMC # support bypass unit.
                        '0' for no, and '1' for yes.
        pSlot#Speed     Specify the speed and duplex modes supported by NMC #,
                        speprated by pipe (|).
        pSlot#PortCount Specify the number of ports in NMC #.
    -->

    <!-- External parameters declaration -->
    <xsl:param name="pSlot1Part" select="''"/>
    <xsl:param name="pSlot1Bypass" select="'0'"/>
    <xsl:param name="pSlot1Speed" select="'Auto'"/>
    <xsl:param name="pSlot1PortCount" select="'0'"/>
    <xsl:param name="pSlot2Part" select="''"/>
    <xsl:param name="pSlot2Bypass" select="'0'"/>
    <xsl:param name="pSlot2Speed" select="'Auto'"/>
    <xsl:param name="pSlot2PortCount" select="'0'"/>
    <xsl:param name="pSlot3Part" select="''"/>
    <xsl:param name="pSlot3Bypass" select="'0'"/>
    <xsl:param name="pSlot3Speed" select="'Auto'"/>
    <xsl:param name="pSlot3PortCount" select="'0'"/>

    <!-- Concate parameters as a comma separated list -->
    <xsl:variable name="pPartList" select="concat($pSlot1Part, ',', $pSlot2Part, ',', $pSlot3Part)"/>
    <xsl:variable name="pBypassList" select="concat($pSlot1Bypass, ',', $pSlot2Bypass, ',', $pSlot3Bypass)"/>
    <xsl:variable name="pSpeedList" select="concat($pSlot1Speed, ',', $pSlot2Speed, ',', $pSlot3Speed)"/>
    <xsl:variable name="pPortCountList" select="concat($pSlot1PortCount, ',', $pSlot2PortCount, ',', $pSlot3PortCount)"/>

    <!-- Information of previous state -->
    <xsl:variable name="vSlot1Part" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.1.part']/@avpValue"/>
    <xsl:variable name="vSlot1Bypass" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.1.bypass']/@avpValue"/>
    <xsl:variable name="vSlot1Speed" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.1.speed']/@avpValue"/>
    <xsl:variable name="vSlot1PortCount" select="number(concat('0', /sc:policy/sc:avps/sc:avp[@avpName='nmc.1.ports']/@avpValue))"/>
    <xsl:variable name="vSlot2Part" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.2.part']/@avpValue"/>
    <xsl:variable name="vSlot2Bypass" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.2.bypass']/@avpValue"/>
    <xsl:variable name="vSlot2Speed" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.2.speed']/@avpValue"/>
    <xsl:variable name="vSlot2PortCount" select="number(concat('0', /sc:policy/sc:avps/sc:avp[@avpName='nmc.2.ports']/@avpValue))"/>
    <xsl:variable name="vSlot3Part" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.3.part']/@avpValue"/>
    <xsl:variable name="vSlot3Bypass" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.3.bypass']/@avpValue"/>
    <xsl:variable name="vSlot3Speed" select="/sc:policy/sc:avps/sc:avp[@avpName='nmc.3.speed']/@avpValue"/>
    <xsl:variable name="vSlot3PortCount" select="number(concat('0', /sc:policy/sc:avps/sc:avp[@avpName='nmc.3.ports']/@avpValue))"/>

    <xsl:variable name="vNumberOfFixedPorts" select="number(/sc:policy/sc:sensorIdentity/@numberOfPorts) - number($vSlot1PortCount) - number($vSlot2PortCount) - number($vSlot3PortCount)"/>

    <!-- Root node -->
    <xsl:template match="sc:policy">
        <xsl:copy>
            <xsl:copy-of select="@*"/>
            <xsl:apply-templates/>
        </xsl:copy>
    </xsl:template>

    <!-- <sensorIdentity>: Correct numberOfPorts attribute and copy all others. -->
    <xsl:template match="sc:sensorIdentity">
        <xsl:element name="sensorIdentity" namespace="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
            <!-- Copy anything other than numberOfPorts attribute -->
            <xsl:copy-of select="*|comment()|@*[name() != 'numberOfPorts']"/>
            <!-- Calculate new numberOfPorts -->
            <xsl:attribute name="numberOfPorts">
                <xsl:value-of select="number($vNumberOfFixedPorts) + number($pSlot1PortCount) + number($pSlot2PortCount) + number($pSlot3PortCount)"/>
            </xsl:attribute>
        </xsl:element>
    </xsl:template>

    <!-- <duplexesCard*>: For those are for built-in ports, just copy them. For NMC ports, skip them. -->
    <xsl:template match="*[starts-with(local-name(), 'duplexesCard')]">
        <xsl:if test="number(substring-after(local-name(), 'duplexesCard')) &lt;= number($vNumberOfFixedPorts) div 2">
            <xsl:copy-of select="."/>
        </xsl:if>
    </xsl:template>

    <!-- <avps>: Child <avp> other than nmc.* is intact. nmc.* are regenerated. -->
    <xsl:template match="sc:avps">
        <xsl:element name="avps" namespace="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
            <!-- Copy anything other than nmc.* <avp>'s -->
            <xsl:copy-of select="@*|comment()|*[not(local-name() = 'avp') or not(starts-with(@avpName, 'nmc.'))]"/>

            <!-- Regenerate nmc.* -->
            <xsl:call-template name="generate-nmc-avp"/>
        </xsl:element>
    </xsl:template>

    <!-- Generate <duplexesCard*> for NMCs right after a magic comment -->
    <xsl:template match="comment()[string(.) = 'NMC Ports']">
        <xsl:copy/>
        <xsl:call-template name="generate-nmc-duplexesCards"/>
    </xsl:template>

    <!-- Anything else, keep it intact. -->
    <xsl:template match="*|comment()">
        <xsl:copy-of select="."/>
    </xsl:template>
    <!-- Pretty format -->
    <xsl:template match="text()"/>


    <!-- helper templates -->
    <!-- To generate nmc.* <avp> from parameter list -->
    <xsl:template name="generate-nmc-avp">
        <!-- These parameters are used for recursive call. Initial values are given -->
        <xsl:param name="pIndex" select="1"/>
        <xsl:param name="pSlotPart" select="$pPartList"/>
        <xsl:param name="pSlotBypass" select="$pBypassList"/>
        <xsl:param name="pSlotSpeed" select="$pSpeedList"/>
        <xsl:param name="pSlotPortCount" select="$pPortCountList"/>

        <xsl:choose>
            <!-- recursive call -->
            <xsl:when test="contains($pSlotPart, ',') and contains($pSlotBypass, ',') and contains($pSlotSpeed, ',') and contains($pSlotPortCount, ',')">
                <xsl:call-template name="generate-nmc-avp">
                    <xsl:with-param name="pIndex" select="$pIndex"/>
                    <xsl:with-param name="pSlotPart" select="substring-before($pSlotPart, ',')"/>
                    <xsl:with-param name="pSlotBypass" select="substring-before($pSlotBypass, ',')"/>
                    <xsl:with-param name="pSlotSpeed" select="substring-before($pSlotSpeed, ',')"/>
                    <xsl:with-param name="pSlotPortCount" select="substring-before($pSlotPortCount, ',')"/>
                </xsl:call-template>
                <xsl:call-template name="generate-nmc-avp">
                    <xsl:with-param name="pIndex" select="number($pIndex) + 1"/>
                    <xsl:with-param name="pSlotPart" select="substring-after($pSlotPart, ',')"/>
                    <xsl:with-param name="pSlotBypass" select="substring-after($pSlotBypass, ',')"/>
                    <xsl:with-param name="pSlotSpeed" select="substring-after($pSlotSpeed, ',')"/>
                    <xsl:with-param name="pSlotPortCount" select="substring-after($pSlotPortCount, ',')"/>
                </xsl:call-template>
            </xsl:when>

            <!-- generate nmc.x.part, nmc.x.bypass, nmc.x.speed, nmc.x.ports -->
            <xsl:otherwise>
                <xsl:element name="avp" namespace="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
                    <xsl:attribute name="avpName"> <xsl:value-of select="concat('nmc.', $pIndex, '.part')"/> </xsl:attribute>
                    <xsl:attribute name="avpValue"> <xsl:value-of select="$pSlotPart"/> </xsl:attribute>
                </xsl:element>
                <xsl:element name="avp" namespace="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
                    <xsl:attribute name="avpName"> <xsl:value-of select="concat('nmc.', $pIndex, '.bypass')"/> </xsl:attribute>
                    <xsl:attribute name="avpValue"> <xsl:value-of select="$pSlotBypass"/> </xsl:attribute>
                </xsl:element>
                <xsl:element name="avp" namespace="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
                    <xsl:attribute name="avpName"> <xsl:value-of select="concat('nmc.', $pIndex, '.speed')"/> </xsl:attribute>
                    <xsl:attribute name="avpValue"> <xsl:value-of select="$pSlotSpeed"/> </xsl:attribute>
                </xsl:element>
                <xsl:element name="avp" namespace="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
                    <xsl:attribute name="avpName"> <xsl:value-of select="concat('nmc.', $pIndex, '.ports')"/> </xsl:attribute>
                    <xsl:attribute name="avpValue"> <xsl:value-of select="$pSlotPortCount"/> </xsl:attribute>
                </xsl:element>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- To generate <duplexesCard*> for all NMCs -->
    <xsl:template name="generate-nmc-duplexesCards">
        <!-- These parameters are used for recursive call. Initial values are given -->
        <xsl:param name="pCardIndex" select="number($vNumberOfFixedPorts) div 2 + 1"/>
        <xsl:param name="pSlotPart" select="$pPartList"/>
        <xsl:param name="pSlotBypass" select="$pBypassList"/>
        <xsl:param name="pSlotSpeed" select="$pSpeedList"/>
        <xsl:param name="pSlotPortCount" select="$pPortCountList"/>

        <xsl:choose>
            <!-- recursive call walking through NMC -->
            <xsl:when test="contains($pSlotPart, ',') and contains($pSlotBypass, ',') and contains($pSlotSpeed, ',') and contains($pSlotPortCount, ',')">
                <xsl:call-template name="generate-nmc-duplexesCards">
                    <xsl:with-param name="pCardIndex" select="$pCardIndex"/>
                    <xsl:with-param name="pSlotPart" select="substring-before($pSlotPart, ',')"/>
                    <xsl:with-param name="pSlotBypass" select="substring-before($pSlotBypass, ',')"/>
                    <xsl:with-param name="pSlotSpeed" select="substring-before($pSlotSpeed, ',')"/>
                    <xsl:with-param name="pSlotPortCount" select="substring-before($pSlotPortCount, ',')"/>
                </xsl:call-template>
                <xsl:call-template name="generate-nmc-duplexesCards">
                    <xsl:with-param name="pCardIndex" select="number($pCardIndex) + number(substring-before($pSlotPortCount, ',')) div 2"/>
                    <xsl:with-param name="pSlotPart" select="substring-after($pSlotPart, ',')"/>
                    <xsl:with-param name="pSlotBypass" select="substring-after($pSlotBypass, ',')"/>
                    <xsl:with-param name="pSlotSpeed" select="substring-after($pSlotSpeed, ',')"/>
                    <xsl:with-param name="pSlotPortCount" select="substring-after($pSlotPortCount, ',')"/>
                </xsl:call-template>
            </xsl:when>

            <!-- generate all <duplexesCard*> for one NMC -->
            <xsl:otherwise>
                <xsl:if test="$pSlotPortCount &gt; 0">
                    <!-- generate <duplexesCard*> with all support speed for a single index -->
                    <xsl:call-template name="generate-nmc-duplexesCard">
                        <xsl:with-param name="pCardIndex" select="$pCardIndex"/>
                        <xsl:with-param name="pSlotSpeed" select="$pSlotSpeed"/>
                    </xsl:call-template>
                    <!-- recursive call for next indexed <duplexesCard*> -->
                    <xsl:call-template name="generate-nmc-duplexesCards">
                        <xsl:with-param name="pCardIndex" select="number($pCardIndex) + 1"/>
                        <xsl:with-param name="pSlotPart" select="$pSlotPart"/>
                        <xsl:with-param name="pSlotBypass" select="$pSlotBypass"/>
                        <xsl:with-param name="pSlotSpeed" select="$pSlotSpeed"/>
                        <xsl:with-param name="pSlotPortCount" select="number($pSlotPortCount) - 2"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- To generate <duplexesCard*>'s with a single index -->
    <xsl:template name="generate-nmc-duplexesCard">
        <!-- These parameter must be given. -->
        <xsl:param name="pCardIndex"/>
        <xsl:param name="pSlotSpeed"/>

        <xsl:choose>
            <!-- $pSlotSpeed could be a list. Recursive call to apply each -->
            <xsl:when test="contains($pSlotSpeed, '|')">
                <xsl:call-template name="generate-nmc-duplexesCard">
                    <xsl:with-param name="pCardIndex" select="$pCardIndex"/>
                    <xsl:with-param name="pSlotSpeed" select="substring-before($pSlotSpeed, '|')"/>
                </xsl:call-template>
                <xsl:call-template name="generate-nmc-duplexesCard">
                    <xsl:with-param name="pCardIndex" select="$pCardIndex"/>
                    <xsl:with-param name="pSlotSpeed" select="substring-after($pSlotSpeed, '|')"/>
                </xsl:call-template>
            </xsl:when>

            <!-- generate one single <duplexesCard*> -->
            <xsl:otherwise>
                <xsl:element name="{concat('duplexesCard', $pCardIndex)}" namespace="http://www.iss.net/cml/NetworkDefender/sensorCapabilities">
                    <xsl:attribute name="speedDuplexMode">
                        <xsl:call-template name="generate-speedDuplexMode">
                            <xsl:with-param name="pSlotSpeed" select="$pSlotSpeed"/>
                        </xsl:call-template>
                    </xsl:attribute>
                </xsl:element>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- To create full-term speed/duplex text from given short-term -->
    <!-- Available short-term format is nnnsd:
         nnn - Any length of number indicating the speed.
         s - Speed unit. 'M' for Mb, 'G' for Gb.
         d - Duplex mode. 'h' for Half Duplex, 'f' for Full Duplex.
         Giving non-number nnn, input is directly used. e.g., 'Auto'. -->
    <xsl:template name="generate-speedDuplexMode">
        <xsl:param name="pSlotSpeed" select="'Auto'"/>

        <xsl:variable name="vSpeed" select="number(substring($pSlotSpeed, 1, string-length($pSlotSpeed) - 2))"/>
        <xsl:variable name="vUnit" select="substring($pSlotSpeed, string-length($pSlotSpeed) - 1, 1)"/>
        <xsl:variable name="vDuplex" select="substring($pSlotSpeed, string-length($pSlotSpeed), 1)"/>

        <xsl:choose>
            <!-- Non-digit -->
            <xsl:when test="string($vSpeed) = 'NaN'">
                <xsl:value-of select="$pSlotSpeed"/>
            </xsl:when>

            <xsl:otherwise>
                <!-- Speed -->
                <xsl:value-of select="$vSpeed"/>
                <!-- Speed unit -->
                <xsl:choose>
                    <xsl:when test="$vUnit = 'M'">
                        <xsl:value-of select="' Mb'"/>
                    </xsl:when>
                    <xsl:when test="$vUnit = 'G'">
                        <xsl:value-of select="' Gb'"/>
                    </xsl:when>
                </xsl:choose>
                <!-- Duplex mode -->
                <xsl:choose>
                    <xsl:when test="$vDuplex = 'h'">
                        <xsl:value-of select="' Half Duplex'"/>
                    </xsl:when>
                    <xsl:when test="$vDuplex = 'f'">
                        <xsl:value-of select="' Full Duplex'"/>
                    </xsl:when>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
