<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:snmp="http://www.iss.net/cml/NetworkDefender/snmp">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>
Example: Xalan -p snmpEnabled "'true'" -p snmpGetList "'comm1+host1|comm2+host2'" -o output.xml ndsnmp1_0.xml snmp100.xsl
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'1.0.0'"/>
<xsl:param name="pSnmpDaemonEnabled" select="'false'"/> <!-- DEPRECATED: DO NOT USE -->
<xsl:param name="pSnmpEnabled" select="'false'"/>       <!-- DEPRECATED: DO NOT USE-->
<xsl:param name="pSnmpSystemLocation" select="'Unknown'"/>
<xsl:param name="pSnmpContactInfo" select="'Unknown'"/>
<xsl:param name="pSnmpSystemName" select="'Unknown'"/>
<xsl:param name="pSnmpTrapsEnabled" select="'false'"/>
<xsl:param name="pSnmpTrapsList" select="''"/>
<xsl:param name="pSnmpGetEnabled" select="'false'"/>
<xsl:param name="pSnmpGetList" select="''"/>

<xsl:template match="snmp:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/snmp">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="snmp:Config">
    <xsl:element name="Config" namespace="http://www.iss.net/cml/NetworkDefender/snmp">
        <xsl:attribute name="SystemLocation"> <xsl:value-of select="$pSnmpSystemLocation"/> </xsl:attribute>
        <xsl:attribute name="SystemContact"> <xsl:value-of select="$pSnmpContactInfo"/> </xsl:attribute>
        <xsl:attribute name="SystemName"> <xsl:value-of select="$pSnmpSystemName"/> </xsl:attribute>
        <xsl:attribute name="TrapsEnabled"> <xsl:value-of select="$pSnmpTrapsEnabled"/> </xsl:attribute>
        <xsl:attribute name="GetEnabled"> <xsl:value-of select="$pSnmpGetEnabled"/> </xsl:attribute>
        <xsl:call-template name="AddTraps">
            <xsl:with-param name="trapList" select="$pSnmpTrapsList"/>
        </xsl:call-template>
        <xsl:call-template name="AddGets">
            <xsl:with-param name="getList" select="$pSnmpGetList"/>
        </xsl:call-template>
    </xsl:element>
</xsl:template>

<xsl:template name="AddTraps">
    <xsl:param name="trapList" select="''"/>
    <xsl:if test="string-length($trapList) > 0">
        <xsl:choose>
            <xsl:when test="contains($trapList, '|')">
                <xsl:call-template name="AddTrapElement">
                    <xsl:with-param name="trapElement" select="substring-before($trapList, '|')"/>
                </xsl:call-template>
                <xsl:call-template name="AddTraps">
                    <xsl:with-param name="trapList" select="substring-after($trapList, '|')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="AddTrapElement">
                    <xsl:with-param name="trapElement" select="$trapList"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<xsl:template name="AddTrapElement">
    <xsl:param name="trapElement" select="''"/>
    <xsl:if test="contains($trapElement, '+')">
        <xsl:variable name="trapAddress" select="substring-before($trapElement, '+')"/>
        <xsl:variable name="temp1" select="substring-after($trapElement, '+')"/>
        <xsl:if test="contains($temp1, '+')">
            <xsl:variable name="trapPort" select="substring-before($temp1, '+')"/>
            <xsl:variable name="temp2" select="substring-after($temp1, '+')"/>
            <xsl:if test="contains($temp2, '+')">
                <xsl:variable name="trapComm" select="substring-before($temp2, '+')"/>
                <xsl:variable name="trapVer" select="substring-after($temp2, '+')"/>
                <xsl:element name="SnmpTraps" namespace="http://www.iss.net/cml/NetworkDefender/snmp">
                    <xsl:attribute name="TrapAddress"> <xsl:value-of select="$trapAddress"/> </xsl:attribute>
                    <xsl:attribute name="TrapPort"> <xsl:value-of select="$trapPort"/> </xsl:attribute>
                    <xsl:attribute name="TrapCommunity"> <xsl:value-of select="$trapComm"/> </xsl:attribute>
                    <xsl:attribute name="TrapVersion"> <xsl:value-of select="$trapVer"/> </xsl:attribute>
                </xsl:element>
            </xsl:if>
        </xsl:if>
    </xsl:if>
</xsl:template>

<xsl:template name="AddGets">
    <xsl:param name="getList" select="''"/>
    <xsl:if test="string-length($getList) > 0">
        <xsl:choose>
            <xsl:when test="contains($getList, '|')">
                <xsl:call-template name="AddGetElement">
                    <xsl:with-param name="getElement" select="substring-before($getList, '|')"/>
                </xsl:call-template>
                <xsl:call-template name="AddGets">
                    <xsl:with-param name="getList" select="substring-after($getList, '|')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="AddGetElement">
                    <xsl:with-param name="getElement" select="$getList"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<xsl:template name="AddGetElement">
    <xsl:param name="getElement" select="''"/>
    <xsl:if test="contains($getElement, '+')">
        <xsl:element name="SnmpGet" namespace="http://www.iss.net/cml/NetworkDefender/snmp">
            <xsl:attribute name="GetCommunity"> <xsl:value-of select="substring-before($getElement, '+')"/> </xsl:attribute>
            <xsl:attribute name="GetAddress"> <xsl:value-of select="substring-after($getElement, '+')"/> </xsl:attribute>
        </xsl:element>
    </xsl:if>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/snmp">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

