<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:time="http://www.iss.net/cml/NetworkDefender/time">

<!--
Usage: Xalan [-p paramName paramValue] [-o outfile] <infile> <xformfile>
Example: Xalan -p pNtpEnable "'true'" -p pNtpServers "'server1|server2|server3'" -p pNtpInterval "'15'" -o output.xml ndtime1_0.xml time100.xsl
Date Format: YYYY-MM-DD
Time Format: HH:MM:SS
NTP Version: one|two|three

if you pass a value for -p pDeleteDateTime, it will remove the dateTime element (set by pDate/pTime)

NTP Server options:
  if you pass a value for -p pAddNtpServers, it will ADD your NTP server to the existing list
  if you pass a value for -p pDeleteAllNtpServers, it will remove all NTP servers from the list
  if you pass a value for -p pDeleteNtpServer, it will remove all matching NTP servers from the list
  if you pass a value for -p pNtpServers, it will add ONLY the NTP servers you pass,
     NO existing NTP servers will be preserved
-->

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="''"/>
<xsl:param name="pDate" select="''"/>
<xsl:param name="pTime" select="''"/>
<xsl:param name="pDeleteDateTime" select="''"/>
<xsl:param name="pTimeZone" select="''"/>
<xsl:param name="pNtpEnable" select="''"/>
<xsl:param name="pNtpVersion" select="''"/>
<xsl:param name="pNtpInterval" select="''"/>
<xsl:param name="pNtpServers" select="'_empty_list_'"/>
<xsl:param name="pDeleteAllNtpServers" select="''"/>
<xsl:param name="pDeleteNtpServer" select="''"/>
<xsl:param name="pAddNtpServers" select="''"/>

<xsl:template match="time:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/time">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>

        <xsl:choose>
          <xsl:when test="string-length($pSchemaVersion) > 0">
            <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="@schema-version"/>
          </xsl:otherwise>
        </xsl:choose>  

        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="time:Config">

    <!-- get dateTime="Date'T'Time" -->
    <xsl:param name="origDate" select="substring-before(@dateTime,'T')"/>
    <xsl:param name="origTime" select="substring-after(@dateTime,'T')"/>

    <xsl:element name="Config" namespace="http://www.iss.net/cml/NetworkDefender/time">
        <xsl:copy-of select="@*[name() != 'dateTime' and name() != 'timeZone']"/>

            <xsl:choose>
              <!-- user passed pDeleteDateTime - remove dateTime element -->
              <xsl:when test="string-length($pDeleteDateTime) > 0">
              </xsl:when>

              <xsl:otherwise>
                <xsl:choose>
                  <!-- user passed Date & Time - replace both -->
                  <xsl:when test="string-length($pDate) > 0 and string-length($pTime) > 0">
                    <xsl:attribute name="dateTime"> <xsl:value-of select="concat($pDate,'T',$pTime)"/> </xsl:attribute>
                  </xsl:when>

                  <!-- user passed Date - replace Date, use old Time -->
                  <xsl:when test="string-length($pDate) > 0">
                    <xsl:attribute name="dateTime"> <xsl:value-of select="concat($pDate,'T',$origTime)"/> </xsl:attribute>
                  </xsl:when>
  
                  <!-- user passed Time - replace Time, use old Date -->
                  <xsl:when test="string-length($pTime) > 0">
                    <xsl:attribute name="dateTime"> <xsl:value-of select="concat($origDate,'T',$pTime)"/> </xsl:attribute>
                  </xsl:when>

                  <!-- user passed neither Date nor Time, keep old values -->
                  <xsl:otherwise>
                    <xsl:copy-of select="@dateTime"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:otherwise>

            </xsl:choose>

            <xsl:choose>
              <!-- TimeZone passed, replace -->
              <xsl:when test="string-length($pTimeZone) > 0">
                <xsl:attribute name="timeZone"><xsl:value-of select='$pTimeZone'/></xsl:attribute>
              </xsl:when>
              <!-- TimeZone not passed, keep old value -->
              <xsl:otherwise>
                <xsl:copy-of select="@timeZone"/>
              </xsl:otherwise>
            </xsl:choose>  

        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="time:ntpConfig">
    <xsl:element name="ntpConfig" namespace="http://www.iss.net/cml/NetworkDefender/time">
        <xsl:copy-of select="@*[name() != 'enableNtp' and name() != 'ntpVersion' and name() != 'synchIntervalMinutes']"/>

        <!-- enableNtp -->
        <xsl:choose>
          <!-- enableNtp passed, replace -->
          <xsl:when test="string-length($pNtpEnable) > 0">
            <xsl:attribute name="enableNtp"> <xsl:value-of select="$pNtpEnable"/> </xsl:attribute>
          </xsl:when>
          <!-- enableNtp not passed, keep old value -->
          <xsl:otherwise>
            <xsl:copy-of select="@enableNtp"/>
          </xsl:otherwise>
        </xsl:choose>  

        <!-- ntpVersion -->
        <xsl:choose>
          <!-- ntpVersion passed, replace -->
          <xsl:when test="string-length($pNtpVersion) > 0">
            <xsl:attribute name="ntpVersion"> <xsl:value-of select="$pNtpVersion"/> </xsl:attribute>
          </xsl:when>
          <!-- enableNtp not passed, keep old value -->
          <xsl:otherwise>
            <xsl:copy-of select="@ntpVersion"/>
          </xsl:otherwise>
        </xsl:choose>  

        <!-- synchIntervalMinutes -->
        <xsl:choose>
          <!-- synchIntervalMinutes passed, replace -->
          <xsl:when test="string-length($pNtpInterval) > 0">
            <xsl:attribute name="synchIntervalMinutes"> <xsl:value-of select="$pNtpInterval"/> </xsl:attribute>
          </xsl:when>
          <!-- synchIntervalMinutes not passed, keep old value -->
          <xsl:otherwise>
            <xsl:copy-of select="@synchIntervalMinutes"/>
          </xsl:otherwise>
        </xsl:choose>  

        <!-- add NTP servers to serverList -->
        <xsl:choose>
          <xsl:when test="string-length($pDeleteAllNtpServers) = 0 and $pNtpServers != ''">

            <xsl:choose>
              <xsl:when test="string-length($pDeleteNtpServer) > 0">
                <!-- copy all NTP servers except the one we want to delete -->
                <xsl:for-each select="./time:ntpServers[@ntpServer != $pDeleteNtpServer]">			   
                  <xsl:element name="ntpServers" namespace="http://www.iss.net/cml/NetworkDefender/time">
                  <xsl:copy-of select="@*"/>
                  </xsl:element>
                </xsl:for-each>
              </xsl:when>

              <xsl:when test="string-length($pNtpServers) > 0 and $pNtpServers != '_empty_list_'">
                <xsl:call-template name="AddNtpServers">
                  <xsl:with-param name="serverList" select="$pNtpServers"/>
                </xsl:call-template>

                <xsl:choose>
                  <xsl:when test="count(./time:ntpServers) = 0">
                    <xsl:apply-templates/>
                  </xsl:when>
                </xsl:choose>
              </xsl:when>

              <xsl:otherwise>
                <xsl:call-template name="AddNtpServers">
                    <xsl:with-param name="serverList" select="$pAddNtpServers"/>
                </xsl:call-template>
                <xsl:apply-templates/>
              </xsl:otherwise>
            </xsl:choose>  

          </xsl:when>
        </xsl:choose>  

    </xsl:element>
</xsl:template>

<xsl:template name="AddNtpServers">
    <xsl:param name="serverList" select="''"/>
    <xsl:choose>
        <xsl:when test="contains($serverList, '|')">
            <xsl:variable name="server" select="substring-before($serverList, '|')"/>
            <xsl:if test="string-length($server) > 0">
                <xsl:element name="ntpServers" namespace="http://www.iss.net/cml/NetworkDefender/time">
                    <xsl:attribute name="ntpServer"> <xsl:value-of select="$server"/> </xsl:attribute>
                </xsl:element>
            </xsl:if>
            <xsl:call-template name="AddNtpServers">
                <xsl:with-param name="serverList" select="substring-after($serverList, '|')"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:when test="string-length($serverList) > 0">
            <xsl:element name="ntpServers" namespace="http://www.iss.net/cml/NetworkDefender/time">
                <xsl:attribute name="ntpServer"> <xsl:value-of select="$serverList"/> </xsl:attribute>
            </xsl:element>
        </xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/time">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

