<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:time="http://www.iss.net/cml/NetworkDefender/time" xmlns:ntp="http://www.iss.net/cml/NetworkDefender/ntp">

    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    <xsl:param name="pSchemaVersion" select="'1.0.0'"/>
    <xsl:param name="pPolicyName" select="'ndntp1_0'"/>
    <xsl:param name="pPolicyVersion" select="'1.0.0'"/>

    <!-- NTP policy namespace. Define here to avoid typo later. -->
    <xsl:variable name="PolicyNS" select="'http://www.iss.net/cml/NetworkDefender/ntp'"/>
    <!-- Converted XML for each version -->
    <xsl:variable name="V1XML">
        <xsl:element name="NTPv1" namespace="{$PolicyNS}"/>
    </xsl:variable>
    <xsl:variable name="V2XML">
        <xsl:element name="NTPv2" namespace="{$PolicyNS}"/>
    </xsl:variable>
    <xsl:variable name="V3XML">
        <xsl:element name="NTPv3" namespace="{$PolicyNS}">
            <xsl:element name="NtpAuthNone" namespace="{$PolicyNS}"/>
        </xsl:element>
    </xsl:variable>

    <xsl:template match="time:policy">
        <xsl:element name="policy" namespace="{$PolicyNS}">
            <!-- Give default attributes to root <ntp:policy> element -->
            <xsl:attribute name="name"><xsl:value-of select="$pPolicyName"/></xsl:attribute>
            <xsl:attribute name="version"><xsl:value-of select="$pPolicyVersion"/></xsl:attribute>
            <xsl:attribute name="schema-version"><xsl:value-of select="$pSchemaVersion"/></xsl:attribute>
            <xsl:attribute name="valid">true</xsl:attribute>
            <xsl:attribute name="overwrite">true</xsl:attribute>

            <!-- <ntp:ntpConfig> is always generated. It's content is coming from <time:Config><time:ntpConfig>
                 and may not be emit -->
            <xsl:element name="ntpConfig" namespace="{$PolicyNS}">
                <xsl:apply-templates select="time:Config/time:ntpConfig"/>
            </xsl:element>

            <!-- The following elements are newly in ndntp1_0.xml. Give a default value here -->
            <xsl:element name="ntpSymmAuthKeys" namespace="{$PolicyNS}">
                <xsl:element name="SymmKeysData" namespace="{$PolicyNS}">
                    <!--xsl:attribute name="data"/-->
                </xsl:element>
            </xsl:element>
            <xsl:element name="ntpAutokeyConfig" namespace="{$PolicyNS}">
                <xsl:attribute name="cryptoDigest">MD5</xsl:attribute>
                <xsl:element name="NtpKeygenOptions" namespace="{$PolicyNS}">
                    <xsl:attribute name="useClientPwd">false</xsl:attribute>
                    <!--xsl:attribute name="clientPwd"/-->
                    <xsl:attribute name="encryptScheme">RSA-MD5</xsl:attribute>
                </xsl:element>
                <xsl:element name="NtpIdentityOptions" namespace="{$PolicyNS}">
                    <xsl:attribute name="enabled">false</xsl:attribute>
                </xsl:element>
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <xsl:template match="time:ntpConfig">
        <!--xsl:copy-of select="@enableNtp"/-->
        <xsl:copy-of select="@synchIntervalMinutes"/>
        <xsl:apply-templates select="time:ntpServers">
            <xsl:with-param name="ntpVersion" select="@ntpVersion"/>
        </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="time:ntpServers">
        <xsl:param name="ntpVersion" select="'three'"/>
        <xsl:element name="NtpServer" namespace="{$PolicyNS}">
            <xsl:attribute name="server"><xsl:value-of select="@ntpServer"/></xsl:attribute>
            <!-- @enabled attribute is newly in ndntp1_0.xml, enable it by default -->
            <xsl:attribute name="enabled">true</xsl:attribute>
            <!-- Set all version to the same according to global setting from ndtime1_0.xml -->
            <xsl:element name="version" namespace="{$PolicyNS}">
                <xsl:choose>
                    <xsl:when test="$ntpVersion = 'one'">
                        <xsl:copy-of select="$V1XML"/>
                    </xsl:when>
                    <xsl:when test="$ntpVersion = 'two'">
                        <xsl:copy-of select="$V2XML"/>
                    </xsl:when>
                    <xsl:when test="$ntpVersion = 'three'">
                        <xsl:copy-of select="$V3XML"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <!-- fail-safe, treated as V3 if version not recognized -->
                        <xsl:copy-of select="$V3XML"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:element>
        </xsl:element>
    </xsl:template>
</xsl:stylesheet>
