<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:upds="http://www.iss.net/cml/NetworkDefender/upds" xmlns:common="http://www.iss.net/cml/NetworkDefender/common">

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
<xsl:param name="pSchemaVersion" select="'5.0.0'"/>
<xsl:param name="pEncryptedProxyPassword" select="''"/>

<xsl:template match="upds:policy">
    <xsl:element name="policy" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:copy-of select="@*[name() != 'schema-version']"/>
        <xsl:attribute name="schema-version"> <xsl:value-of select="$pSchemaVersion"/> </xsl:attribute>
        <xsl:apply-templates select="upds:UpdateSettings"/>
        <xsl:variable name="sourceUrlUpr" select="upds:TuningSetting[@name='Update.source.url']/common:string/@value"/>
        <xsl:variable name="sourceUrlLwr" select="upds:TuningSetting[@name='update.source.url']/common:string/@value"/>
        <xsl:choose>
            <xsl:when test="string-length($sourceUrlUpr) = 0 and string-length($sourceUrlLwr) = 0">
                <xsl:call-template name="ModifyLUServer"/>
            </xsl:when>
            <xsl:when test="contains($sourceUrlUpr, 'www.iss.net') or contains($sourceUrlUpr, 'xpu.iss.net') or contains($sourceUrlLwr, 'www.iss.net') or contains($sourceUrlLwr, 'xpu.iss.net')">
                <xsl:call-template name="ModifyLUServer"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="AddLUServer"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="scheduled-installs"/>
        <xsl:call-template name="NotificationConfig"/>
        <xsl:apply-templates select="upds:TuningSetting"/>
    </xsl:element>
</xsl:template>

<xsl:template match="upds:UpdateSettings">
    <xsl:element name="UpdateSettings" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates select="upds:AutoCheckSchedule"/>
        <xsl:apply-templates select="upds:SecurityUpdateSettings"/>
        <xsl:element name="WFASDBUpdateSettings" namespace="http://www.iss.net/cml/NetworkDefender/upds">
            <xsl:attribute name="EnableAutoUpdate"> <xsl:value-of select="'false'"/> </xsl:attribute>
        </xsl:element>
        <xsl:apply-templates select="upds:FirmwareUpdateSettings"/>
    </xsl:element>
</xsl:template>

<xsl:template match="upds:AutoCheckSchedule">
    <xsl:element name="AutoCheckSchedule" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<xsl:template match="upds:SecurityUpdateSettings">
    <xsl:element name="SecurityUpdateSettings" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:choose>
            <xsl:when test="@EnableAutoDownload = 'true' and @EnableAutoInstall = 'true'">
                <xsl:element name="AutoDownloadAndInstall" namespace="http://www.iss.net/cml/NetworkDefender/upds"/>
            </xsl:when>
            <xsl:when test="@EnableAutoDownload = 'true'">
                <xsl:element name="AutoDownloadOnly" namespace="http://www.iss.net/cml/NetworkDefender/upds"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:element name="NoDownloadOrInstall" namespace="http://www.iss.net/cml/NetworkDefender/upds"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>

<xsl:template match="upds:FirmwareUpdateSettings">
    <xsl:variable name="VersionElement" select="upds:FirmwareInstallOptions/upds:FirmwareInstallMethod/upds:EnableOneTimeInstall/upds:VersionToInstall/upds:SpecificVersion"/>
    <xsl:element name="FirmwareUpdateSettings" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:attribute name="StayInSeries"> <xsl:value-of select="'true'"/> </xsl:attribute>
        <xsl:choose>
            <xsl:when test="$VersionElement">
                <xsl:attribute name="LimitVersion">
                    <xsl:value-of select="'true'"/>
                </xsl:attribute>
                <xsl:attribute name="SpecificVersion">
                    <xsl:value-of select="$VersionElement/@Version"/>
                </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="LimitVersion">
                    <xsl:value-of select="'false'"/>
                </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:attribute name="EnableBackup">
            <xsl:choose>
                <xsl:when test="upds:FirmwareInstallOptions/@EnableBackup = 'true'">
                    <xsl:value-of select="'true'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'false'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
        <xsl:choose>
            <xsl:when test="@EnableAutoDownload = 'false'">
                <xsl:element name="NoDownloadOrInstall" namespace="http://www.iss.net/cml/NetworkDefender/upds"/>
            </xsl:when>
            <xsl:when test="@EnableAutoDownload = 'true' and count(upds:FirmwareInstallOptions/upds:FirmwareInstallMethod/upds:DisableInstall) > 0">
                <xsl:element name="AutoDownloadOnly" namespace="http://www.iss.net/cml/NetworkDefender/upds"/>
            </xsl:when>
            <xsl:when test="@EnableAutoDownload = 'true' and count(upds:FirmwareInstallOptions/upds:FirmwareInstallMethod/upds:EnableAutoInstall/upds:AutoInstallScheduleOptions/upds:Immediate) > 0">
                <xsl:element name="AutoDownloadAndInstall" namespace="http://www.iss.net/cml/NetworkDefender/upds"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:element name="NoDownloadOrInstall" namespace="http://www.iss.net/cml/NetworkDefender/upds"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:element>
</xsl:template>


<xsl:template name="ModifyLUServer">
    <xsl:element name="LUServers" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:element name="server-info" namespace="http://www.iss.net/cml/NetworkDefender/upds">
            <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            <xsl:attribute name="name"> <xsl:value-of select="'IBM ISS Default License and Update Server'"/> </xsl:attribute>
            <xsl:attribute name="host-name"> <xsl:value-of select="'xpu.iss.net'"/> </xsl:attribute>
            <xsl:attribute name="port"> <xsl:value-of select="'443'"/> </xsl:attribute>
            <xsl:attribute name="trust-level"> <xsl:value-of select="'explicit-trust'"/> </xsl:attribute>
            <xsl:call-template name="SetCustomLUServerAttributes"/>
            <xsl:attribute name="ordinal"> <xsl:value-of select="'0'"/> </xsl:attribute>
            <xsl:attribute name="noDelete"> <xsl:value-of select="'true'"/> </xsl:attribute>
            <xsl:attribute name="noEdit"> <xsl:value-of select="'false'"/> </xsl:attribute>
        </xsl:element>
    </xsl:element>
</xsl:template>

<xsl:template name="SetCustomLUServer">
    <xsl:variable name="updateUrl">
        <xsl:choose>
            <xsl:when test="upds:TuningSetting[@name = 'Update.source.url']">
                <xsl:value-of select="upds:TuningSetting[@name='Update.source.url']/common:string/@value"/>
            </xsl:when>
            <xsl:when test="upds:TuningSetting[@name = 'update.source.url']">
                <xsl:value-of select="upds:TuningSetting[@name='update.source.url']/common:string/@value"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="'xpu.iss.net'"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="serverNoProtocol">
        <xsl:choose>
            <xsl:when test="contains($updateUrl, '://')">
                <xsl:value-of select="substring-after($updateUrl, '://')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$updateUrl"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="serverNoPath">
        <xsl:choose>
            <xsl:when test="contains($serverNoProtocol, '/')">
                <xsl:value-of select="substring-before($serverNoProtocol, '/')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$serverNoProtocol"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="serverNoPort">
        <xsl:choose>
            <xsl:when test="contains($serverNoPath, ':')">
                <xsl:value-of select="substring-before($serverNoPath, ':')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$serverNoPath"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="updateServerPort">
        <xsl:choose>
            <xsl:when test="contains($serverNoPath, ':')">
                <xsl:value-of select="substring-after($serverNoPath, ':')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="'443'"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:attribute name="host-name"> <xsl:value-of select="$serverNoPort"/> </xsl:attribute>
    <xsl:attribute name="port"> <xsl:value-of select="$updateServerPort"/> </xsl:attribute>
    <xsl:choose>
        <xsl:when test="upds:TuningSetting[@name = 'Update.trust.level'] and upds:TuningSetting/common:string">
            <xsl:attribute name="trust-level"> <xsl:value-of select="upds:TuningSetting[@name='Update.trust.level']/common:string/@value"/> </xsl:attribute>
        </xsl:when>
        <xsl:when test="upds:TuningSetting[@name = 'update.trust.level'] and upds:TuningSetting/common:string">
            <xsl:attribute name="trust-level"> <xsl:value-of select="upds:TuningSetting[@name='update.trust.level']/common:string/@value"/> </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
            <xsl:attribute name="trust-level"> <xsl:value-of select="'first-time-trust'"/> </xsl:attribute>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="SetCustomLUServerAttributes">
    <xsl:choose>
        <!-- NOTE - string is not handled -->
        <xsl:when test="upds:TuningSetting[@name = 'Update.proxy.enable'] and upds:TuningSetting/common:boolean[@value = 'true']">
            <xsl:attribute name="useProxy"> <xsl:text>true</xsl:text> </xsl:attribute>
        </xsl:when>
        <xsl:when test="upds:TuningSetting[@name = 'update.proxy.enable'] and upds:TuningSetting/common:boolean[@value = 'true']">
            <xsl:attribute name="useProxy"> <xsl:text>true</xsl:text> </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
            <xsl:attribute name="useProxy"> <xsl:text>false</xsl:text> </xsl:attribute>
        </xsl:otherwise>
    </xsl:choose>
    <xsl:choose>
        <xsl:when test="upds:TuningSetting[@name='Update.proxy.url']/common:string">
            <xsl:attribute name="proxy-host"> <xsl:value-of select="upds:TuningSetting[@name='Update.proxy.url']/common:string/@value"/> </xsl:attribute>
        </xsl:when>
        <xsl:when test="upds:TuningSetting[@name='update.proxy.url']/common:string">
            <xsl:attribute name="proxy-host"> <xsl:value-of select="upds:TuningSetting[@name='update.proxy.url']/common:string/@value"/> </xsl:attribute>
        </xsl:when>
    </xsl:choose>
    <xsl:choose>
        <xsl:when test="upds:TuningSetting[@name='Update.proxy.port']/common:string">
            <xsl:attribute name="proxy-port"> <xsl:value-of select="upds:TuningSetting[@name='Update.proxy.port']/common:string/@value"/> </xsl:attribute>
        </xsl:when>
        <xsl:when test="upds:TuningSetting[@name='Update.proxy.port']/common:number">
            <xsl:attribute name="proxy-port"> <xsl:value-of select="upds:TuningSetting[@name='Update.proxy.port']/common:number/@value"/> </xsl:attribute>
        </xsl:when>
        <xsl:when test="upds:TuningSetting[@name='update.proxy.port']/common:string">
            <xsl:attribute name="proxy-port"> <xsl:value-of select="upds:TuningSetting[@name='update.proxy.port']/common:string/@value"/> </xsl:attribute>
        </xsl:when>
        <xsl:when test="upds:TuningSetting[@name='update.proxy.port']/common:number">
            <xsl:attribute name="proxy-port"> <xsl:value-of select="upds:TuningSetting[@name='update.proxy.port']/common:number/@value"/> </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
            <xsl:attribute name="proxy-port"> <xsl:value-of select="'443'"/> </xsl:attribute>
        </xsl:otherwise>
    </xsl:choose>
    <!-- set proxy auth to false, and proxy user and password to blank unless these are encrypted using input parameters.
         Ignore the legacy Update.proxy.password parameter. -->
    <xsl:choose>
        <xsl:when test="$pEncryptedProxyPassword != '' and (upds:TuningSetting[@name='Update.proxy.user']/common:string/@value != '' or upds:TuningSetting[@name='update.proxy.user']/common:string/@value != '') and (upds:TuningSetting[@name='Update.proxy.auth']/common:string/@value = 'true' or upds:TuningSetting[@name='update.proxy.auth']/common:string/@value = 'true' or upds:TuningSetting[@name='Update.proxy.auth']/common:number/@value = '1' or upds:TuningSetting[@name='update.proxy.auth']/common:number/@value = '1')">
            <xsl:attribute name="use-proxy-auth"> <xsl:value-of select="'true'"/> </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
            <xsl:attribute name="use-proxy-auth"> <xsl:value-of select="'false'"/> </xsl:attribute>
        </xsl:otherwise>
    </xsl:choose>
    <xsl:choose>
        <xsl:when test="upds:TuningSetting[@name='Update.proxy.user']/common:string">
            <xsl:attribute name="proxy-user"> <xsl:value-of select="upds:TuningSetting[@name='Update.proxy.user']/common:string/@value"/></xsl:attribute>
        </xsl:when>
        <xsl:when test="upds:TuningSetting[@name='update.proxy.user']/common:string">
            <xsl:attribute name="proxy-user"> <xsl:value-of select="upds:TuningSetting[@name='update.proxy.user']/common:string/@value"/></xsl:attribute>
        </xsl:when>
    </xsl:choose>
    <xsl:choose>
        <xsl:when test="$pEncryptedProxyPassword != ''">
            <xsl:attribute name="proxy-pwd"> <xsl:value-of select="$pEncryptedProxyPassword"/> </xsl:attribute>
        </xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template name="AddLUServer">
    <xsl:element name="LUServers" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:element name="server-info" namespace="http://www.iss.net/cml/NetworkDefender/upds">
            <xsl:attribute name="enabled"> <xsl:value-of select="'false'"/> </xsl:attribute>
            <xsl:attribute name="name"> <xsl:value-of select="'IBM ISS Default License and Update Server'"/> </xsl:attribute>
            <xsl:attribute name="host-name"> <xsl:value-of select="'xpu.iss.net'"/> </xsl:attribute>
            <xsl:attribute name="port"> <xsl:value-of select="'443'"/> </xsl:attribute>
            <xsl:attribute name="trust-level"> <xsl:value-of select="'explicit-trust'"/> </xsl:attribute>
            <xsl:attribute name="useProxy"> <xsl:value-of select="'false'"/> </xsl:attribute>
            <xsl:attribute name="proxy-port"> <xsl:value-of select="'443'"/> </xsl:attribute>
            <xsl:attribute name="ordinal"> <xsl:value-of select="'0'"/> </xsl:attribute>
            <xsl:attribute name="noDelete"> <xsl:value-of select="'true'"/> </xsl:attribute>
            <xsl:attribute name="noEdit"> <xsl:value-of select="'false'"/> </xsl:attribute>
        </xsl:element>
        <xsl:element name="server-info" namespace="http://www.iss.net/cml/NetworkDefender/upds">
            <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
            <xsl:attribute name="name"> <xsl:value-of select="'Custom License and Update Server'"/> </xsl:attribute>
            <xsl:call-template name="SetCustomLUServer"/>
            <xsl:call-template name="SetCustomLUServerAttributes"/>
            <xsl:attribute name="ordinal"> <xsl:value-of select="'1'"/> </xsl:attribute>
            <xsl:attribute name="noDelete"> <xsl:value-of select="'false'"/> </xsl:attribute>
            <xsl:attribute name="noEdit"> <xsl:value-of select="'false'"/> </xsl:attribute>
        </xsl:element>
    </xsl:element>
</xsl:template>

<xsl:template name="scheduled-installs">
    <xsl:element name="scheduled-installs" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:variable name="InstallElement" select="/upds:policy/upds:UpdateSettings/upds:FirmwareUpdateSettings/upds:FirmwareInstallOptions/upds:FirmwareInstallMethod/upds:EnableOneTimeInstall"/>
        <xsl:variable name="VersionElement" select="/upds:policy/upds:UpdateSettings/upds:FirmwareUpdateSettings/upds:FirmwareInstallOptions/upds:FirmwareInstallMethod/upds:EnableOneTimeInstall/upds:VersionToInstall/upds:SpecificVersion"/>

        <xsl:if test="count($InstallElement) > 0">
            <xsl:element name="scheduled-install" namespace="http://www.iss.net/cml/NetworkDefender/upds">
                <xsl:attribute name="type"> <xsl:value-of select="'firmware'"/> </xsl:attribute>
                <xsl:attribute name="time"> <xsl:value-of select="concat($InstallElement/@Date, 'T', $InstallElement/@Time, ':00')"/> </xsl:attribute>
                <xsl:attribute name="enablebackup">
                    <xsl:value-of select="/upds:policy/upds:UpdateSettings/upds:FirmwareUpdateSettings/upds:FirmwareInstallOptions/@EnableBackup"/>
                </xsl:attribute>
                <xsl:attribute name="version"> <xsl:value-of select="$VersionElement/@Version"/> </xsl:attribute>
                <xsl:attribute name="id"> <xsl:value-of select="'0'"/> </xsl:attribute>
                <xsl:attribute name="comment"> <xsl:value-of select="'Scheduled firmware installation'"/> </xsl:attribute>
            </xsl:element>
        </xsl:if>
    </xsl:element>
</xsl:template>

<xsl:template name="NotificationConfig">
    <xsl:element name="NotificationConfig" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:element name="LUMAlerts" namespace="http://www.iss.net/cml/NetworkDefender/upds">
            <xsl:element name="AvailableResponse" namespace="http://www.iss.net/cml/NetworkDefender/upds">
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="priority"> <xsl:value-of select="'High'"/> </xsl:attribute>
                <xsl:attribute name="notifyConsole"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="sendEmail"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="sendSnmp"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="doPost"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:element>
            <xsl:element name="InstallResponse" namespace="http://www.iss.net/cml/NetworkDefender/upds">
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="priority"> <xsl:value-of select="'High'"/> </xsl:attribute>
                <xsl:attribute name="notifyConsole"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="sendEmail"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="sendSnmp"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="doPost"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:element>
            <xsl:element name="ErrorResponse" namespace="http://www.iss.net/cml/NetworkDefender/upds">
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="priority"> <xsl:value-of select="'High'"/> </xsl:attribute>
                <xsl:attribute name="notifyConsole"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="sendEmail"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="sendSnmp"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="doPost"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:element>
            <xsl:element name="LicenseResponse" namespace="http://www.iss.net/cml/NetworkDefender/upds">
                <xsl:attribute name="enabled"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="priority"> <xsl:value-of select="'High'"/> </xsl:attribute>
                <xsl:attribute name="notifyConsole"> <xsl:value-of select="'true'"/> </xsl:attribute>
                <xsl:attribute name="sendEmail"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="sendSnmp"> <xsl:value-of select="'false'"/> </xsl:attribute>
                <xsl:attribute name="doPost"> <xsl:value-of select="'false'"/> </xsl:attribute>
            </xsl:element>
        </xsl:element>
    </xsl:element>
</xsl:template>

<xsl:template match="upds:TuningSetting">
    <xsl:choose>
        <!-- do not preserve legacy default update.preserve.update.files -->
        <xsl:when test="@name = 'Update.preserve.update.files' and common:boolean/@value = 'false'"/>
        <xsl:when test="@name = 'update.preserve.update.files' and common:boolean/@value = 'false'"/>
        <!-- do not preserve legacy default update.disable.remote.discovery -->
        <xsl:when test="@name = 'Update.disable.remote.discovery' and common:boolean/@value = 'false'"/>
        <xsl:when test="@name = 'update.disable.remote.discovery' and common:boolean/@value = 'false'"/>
        <!-- update.source.url migrated to server section -->
        <xsl:when test="@name = 'Update.source.url'"/>
        <xsl:when test="@name = 'update.source.url'"/>
        <!-- update.trust.level migrated to server section -->
        <xsl:when test="@name = 'Update.trust.level'"/>
        <xsl:when test="@name = 'update.trust.level'"/>
        <!-- update.catalog.file no longer supported -->
        <xsl:when test="@name = 'Update.catalog.file'"/>
        <xsl:when test="@name = 'update.catalog.file'"/>
        <!-- do not preserve update.type.names.file because directory location has changed -->
        <xsl:when test="@name = 'Update.type.names.file'"/>
        <xsl:when test="@name = 'update.type.names.file'"/>
        <!-- update.certificate.file no longer supported -->
        <xsl:when test="@name = 'Update.certificate.file'"/>
        <xsl:when test="@name = 'update.certificate.file'"/>
        <!-- update.download.request.file no longer supported -->
        <xsl:when test="@name = 'Update.download.request.file'"/>
        <xsl:when test="@name = 'update.download.request.file'"/>
        <!-- update.timeout no longer supported -->
        <xsl:when test="@name = 'Update.timeout'"/>
        <xsl:when test="@name = 'update.timeout'"/>
        <!-- remove all proxy settings -->
        <xsl:when test="contains(@name,'pdate.proxy')"/>
        <xsl:otherwise> <!-- output the param -->
            <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/upds">
                <xsl:copy-of select="@*|node()"/>
            </xsl:element>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="*">
    <xsl:element name="{name(.)}" namespace="http://www.iss.net/cml/NetworkDefender/upds">
        <xsl:copy-of select="@*"/>
        <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>

