#!/usr/bin/env ruby

require 'rexml/document'
require 'sqlite3'
include REXML

def modify_rrd_output(ablob)
  arr = ablob.split("\n")
  arr.delete_at(1)
  arr.each_with_index do |line, index|
    if ( line =~ /nan/ )
      arr.delete_at(index)
    else
      line.gsub!(/:/, "")
      arr[index] = line.split(" ")
    end
  end
  labels = arr.shift
  hh = Hash.new
  labels.each_index { |index|
    h = Hash.new
    arr.each_index { |i|
      temp = (Time.now.utc_offset + arr[i][0].to_i) * 1000
      h[temp] = arr[i][index+1]
    }
    hh[get_label(labels[index].to_sym)] = h
  }
  hh
end

def do_serial(root)
  e = Element.new("serial_number")
  e.add_text $serial
  root.add_element e
end

def get_label(param)
  case param
    when :medium : return 'medium'
    when :high : return 'high'
    when :notblocked : return 'not_blocked'
    when :blocked : return 'blocked'
    when :whitelisted : return 'white_listed'
    when :root : return 'Root (/)'
    when :boot : return 'Boot (/boot)'
    when :restore : return 'Restore (/restore)'
    when :rboot : return 'Rboot (/rboot)'
    when :cache : return 'Cache (/cache)'
    when :low : return 'low'
    when :adapterpacketsre : return 'packets_in'
    when :adapterpacketstr : return 'packets_out'
    when :adapterpacketsfo : return 'packets_forwarded'
    when :adapterpacketsdr : return 'packets_blocked'
    when :adapterpacketsin : return 'packets_injected'
    when :adapterpacketsun : return 'packets_unanalyzed'
    when :adapterbytesre : return 'mbits_in'
    when :adapterbytestr : return 'mbits_out'
    when :memoryused : return 'Memory used'
  end
end

detailed_health = "1"

if ARGV[0]
  detailed_health = ARGV.shift
end

errlog = File.open("/tmp/sphealth.log", 'w+')

begin
  db = SQLite3::Database.new( "/var/iss-db/crm.db" )
  db.execute("select Value from SystemInfoView where Param='Serial Number'") do |row|
    $serial = row[0]
  end
rescue Exception => ex
  errlog.puts "ERROR: Unable to access database. Exception: #{ex.class.to_s}  #{ex.message.to_s}"
  exit 1
end

begin_time = Time.now.to_i / 3600 * 3600

if detailed_health == "1"
  begin
    cmd = "/usr/bin/rrdtool fetch /var/iss-db/memory.rrd AVERAGE -r 3600 -e #{begin_time} -s e-24h"
    result = `#{cmd}`
    hh = modify_rrd_output(result)
    time = :time
    percent = :percent
    File.open("/var/iss/statistics_memory.xml", 'w') { |f|
      doc = Document.new
      doc << XMLDecl.new(1.0, "UTF-8")
      root = doc.add_element("memory")
      do_serial root
      hh.each {|key, value|
        value.keys.sort.each {|key|
          root.add_element "used", { :time.to_s=>key, :percent.to_s=>value[key] }
        }
      }
      doc.write(f, 4)
    }
  rescue Exception => ex
    errlog.puts "ERROR: Failed to create memory statistics document. Exception: #{ex.class.to_s}  #{ex.message.to_s}"
    exit 1
  end

  begin
    cmd = "/usr/bin/rrdtool fetch /var/iss-db/disk.rrd AVERAGE -r 3600 -e #{begin_time} -s e-24h"
    result = `#{cmd}`
    hh = modify_rrd_output(result)
    File.open("/var/iss/statistics_storage.xml", 'w') { |f|
      doc = Document.new
      doc << XMLDecl.new(1.0, "UTF-8")
      root = doc.add_element("disk")
      do_serial root
      hh.each {|key, value|
        e = root.add_element "volume", {"name"=>key}
        value.keys.sort.each {|key|
          root.add_element "used", { :time.to_s=>key, :percent.to_s=>value[key] }
        }
      }
      doc.write(f, 4)
    }
  rescue Exception => ex
    errlog.puts "ERROR: Failed to create storage statistics document. Exception: #{ex.class.to_s}  #{ex.message.to_s}"
    exit 1
  end

  begin
    cmd = "/usr/bin/rrdtool fetch /var/iss-db/ipm.rrd AVERAGE -r 3600 -e #{begin_time} -s e-24h"
    result = `#{cmd}`
    hh = modify_rrd_output(result)
    File.open("/var/iss/statistics_ipm_blocked_not_blocked.xml", 'w') { |f|
      doc = Document.new
      doc << XMLDecl.new(1.0, "UTF-8")
      root = doc.add_element("attacks")
      do_serial root
      arr = Array[ "blocked", "not_blocked" ]
      arr.each do | value |
        e = root.add_element value
        hh[value].keys.sort.each {|key|
          e.add_element "traffic", {:time.to_s=>key, "attacks"=>hh[value][key]}
        }
      end 
      doc.write(f, 4)
    }
  rescue Exception => ex
    errlog.puts "ERROR: Failed to create ipm statistics document. Exception: #{ex.class.to_s}  #{ex.message.to_s}"
    exit 1
  end

  begin
    cmd = "/usr/bin/rrdtool fetch /var/iss-db/drv.rrd AVERAGE -r 3600 -e #{begin_time} -s e-24h"
    result = `#{cmd}`
    hh = modify_rrd_output(result)
    File.open("/var/iss/statistics_network_packets_blocked_packets_in.xml", 'w') { |p|
      File.open("/var/iss/statistics_bandwidth.xml", 'w') { |b|
        pdoc = Document.new
        pdoc << XMLDecl.new(1.0, "UTF-8")
        proot = pdoc.add_element("network")
        bdoc = Document.new
        bdoc << XMLDecl.new(1.0, "UTF-8")
        broot = bdoc.add_element("bandwidth")
        do_serial proot
        do_serial broot
        arr = Array[ "packets_blocked", "packets_in" ]
        arr.each do |value|
          e = proot.add_element value
          hh[value].keys.sort.each {|key|
            e.add_element "traffic", {:time.to_s=>key, "packets"=>hh[value][key]}
          }
        end
        arr = Array[ "mbits_in", "mbits_out" ]
        arr.each do |value|
          e = broot.add_element value
          hh[value].keys.sort.each {|key|
            e.add_element "traffic", {:time.to_s=>key, "bits"=>((hh[value][key].to_f / 1048576.0 * 10000.0).round / 10000.0)}
          }
        end
        pdoc.write(p, 4)
        bdoc.write(b, 4)
      }
    }
  rescue Exception => ex
    errlog.puts "ERROR: Failed to create network statistics documents. Exception: #{ex.class.to_s}  #{ex.message.to_s}"
    exit 1
  end
end

#write health.xml out
begin
  File.open("/var/iss/health.xml", 'w') { |f|
    doc = Document.new
    doc << XMLDecl.new(1.0, "UTF-8")
    root = doc.add_element("health")
    system = root.add_element "system"
    network = root.add_element "network"
    security = root.add_element "security"
    site_protector = root.add_element "site_protector"
    db.execute("select * from SystemStatusView WHERE INDICATORID='8' or INDICATORID='9' or INDICATORID='10' or INDICATORID='11'") do |row|
      if row[3] == '8'
        e = system.add_element "message", {"name"=>row[4], "occurred"=>row[1], "state"=>row[2], "id"=>row[0]}
      elsif row[3] == '9'
        e = security.add_element "message", {"name"=>row[4], "occurred"=>row[1], "state"=>row[2], "id"=>row[0]}
      elsif row[3] == '10'
        e = site_protector.add_element "message", {"name"=>row[4], "occurred"=>row[1], "state"=>row[2], "id"=>row[0]}
      elsif row[3] == '11'
        e = network.add_element "message", {"name"=>row[4], "occurred"=>row[1], "state"=>row[2], "id"=>row[0]}
      end
      e.add_text row[5]
    end
    doc.write(f, 4)
  }
rescue Exception => ex
  errlog.puts "ERROR: Failed to create health document. Exception: #{ex.class.to_s}  #{ex.message.to_s}"
  exit 1
end
