class ApplicationController < ActionController::Base
  before_filter :get_sys_data, :load_network_state, :unless=>:ajax?
  
  filter_parameter_logging :root_password, :admin_password, :prov_m_password, :password
  helper :all # include all helpers, all the time
 
  unless RAILS_ENV == "test"
    before_filter :check_sensor_running?, :unless => [:setup?, :dev?, :sensor_down_page?]
    before_filter :check_configured, :unless => [:setup?, :dev?]
    before_filter :check_license_state, :unless => :check_exempt?
    before_filter :prime_current_page, :unless => :check_exempt?
    before_filter :single_session, :unless => :check_exempt?
    before_filter :check_auth, :unless => :check_exempt?
    before_filter :check_fips, :unless => :check_exempt?
    before_filter :prime_navigation, :unless => :check_exempt?
    before_filter :check_management, :unless => :check_exempt?
  end

  layout :lmilayout, :unless =>:ajax_request?

  def check_auth
    check_is_admin
    if @is_admin.nil?
      RAILS_DEFAULT_LOGGER.error("#{Time.now.to_s} ERROR: User: #{user} does not exist in the db, redirecting to Sessions")
      redirect_to :controller=>'/sessions'
    elsif !authorized_user?
      redirect_to :controller=>'/main/dashboard'
    end
  end

  def check_is_admin
    @is_admin = nil
    current_user = User.find_by_username(user)
    @is_admin = current_user.access_level == "Admin" unless current_user.nil?
  end

  def check_management
    @management = Appliance.get_management
  end

  #Safefy precaution to protect against links missing from the link.yml file
  def lmilayout
    minimal_layout? ? 'minimal' : 'application'
  end

  def check_configured
    unless kontroller =~ /setup/
      redirect_to :controller => "/setup/welcome" unless Appliance.configured?
    end
  end

  def fips_configure?
    acction == "configuring_fips" || \
    acction == "dev_reset_fips" || \
    acction ==  "dev_complete_fips"
  end

  def cpe_create?
    kontroller =~ /settings/ && acction == "create"
  end

  def cpe_page?
    request.request_uri[1..request.request_uri.length] =~ /settings/
  end

  def remote_heartbeat?
    kontroller == "spa" || kontroller == "ha"
  end

  def sessions?
    kontroller =~ /sessions/
  end

  def setup?
    kontroller =~ /setup\/\w*/
  end

  def dev?
    RAILS_ENV == "development"
  end
  
  def test?
    RAILS_ENV == "test"
  end
  
  def service_agreement?
    params[:controller] =~ /service_agreement/ && !Appliance.sla_accepted?
  end

  def user
    request.env["REMOTE_USER"] = "admin" if dev?
    request.env["REMOTE_USER"]
  end

  def kontroller
    params[:controller]  
  end

  def acction
    params[:action]
  end

  def uri
    request.request_uri
  end

  def current_node
    session[:currentnode]
  end

  def ajax?
    request.xhr?
  end

  def admin_page?
    return false unless session[:currentnode]
    session[:currentnode].admin
  end

  def admin_logged_in?
    @is_admin
  end

  def filter_controller?
    kontroller == "statistics/network" || \
    kontroller == "statistics/ipm" || \
    kontroller == "appliance_maintenance"
  end


  def sp_managed?
    @sp_managed = Appliance.sp?
    @sp_managed 
  end

  def sp_managed_page?
     Appliance.sp? && session[:currentnode].management 
     true
  end

  def authorized_user?  
    cpe_page? || !admin_page? || admin_logged_in?  
  end

  def get_branch_root(node)
  
    return false unless node
    node.parent.nil? ? node : get_branch_root(node.parent) 
  end

  def prime_current_page
    if filter_controller?
      rng = request.request_uri[1..request.request_uri.length]
      session[:currentnode] = Link.find_by_controller_name(rng)
    elsif cpe_page?
      rng = request.request_uri[1..request.request_uri.length]
      session[:currentnode] = Link.find_by_controller_path(rng)
    else
      session[:currentnode] = Link.find_by_controller_name(kontroller)
    end
  end

  def prime_navigation
    session[:rootnodes] ||= Link.root_nodes
    @homepage = session[:rootnodes][0] 
    @branchroot = get_branch_root(current_node)     
  end

  def single_session
    request_uri = request.request_uri =~ /sessions/ ? "/main/dashboard" : request.request_uri
    
    if User.count > 0
      redirect_to :controller => "/sessions?uri=#{request_uri}" unless session[:user]
    else
      session[:user] = User.create_new_session(user, request.session_options[:id])
    end
  end

  def check_fips
    if Appliance.fips_setup? && Appliance.fips_mode?
     Appliance.clear_fips_setup_lock
    elsif Appliance.fips_setup?
      redirect_to :controller=>"/setup/welcome/configuring_fips"
    end
  end

  def config_page?
    params[:action] =~ /appliance_configuring/ || params[:controller] =~ /timezones/
  end

  def web_service?
    params[:format] == "xml" || params[:format] == "json" || params[:controller] =~ /web_services_map/
  end
  
  def check_license_state
    redirect_to :controller => "/service_agreement" if Appliance.configured? && !Appliance.sla_accepted?
  end

  def check_exempt?
    remote_heartbeat? || setup? || service_agreement? || log_page? || test? || web_service? || ajax? || config_page? || cpe_create? || sensor_down_page?
  end
  
  def check_sensor_running?
    unless sensor_down_page?
      redirect_to :action=>"sensor_down", :controller => "main" unless Appliance.sensor_running?
    end
  end
  
  def sensor_down_page?
    params[:action] =~ /sensor_down/
  end

  def log_page?
    acction =~ /sp_comm_log/
  end

  def minimal_layout?
    session[:currentnode].nil? || config_page?
  end
  
  def load_network_state
    unless RAILS_ENV=="test"
      @state = NetworkState.appliance_state(@strings)
      @network_status_counts = NetworkState.status_counts
      @network_config_counts = NetworkState.config_counts(@state) 
    end
  end
  
  
  def get_sys_data
    unless RAILS_ENV=="test"
      @strings = SYSMESSAGES.blank? ? Appliance.system_messages : SYSMESSAGES
      # WS: SYSDATA has been removed.
      #@sysdata = SYSDATA.blank? ? Appliance.system_data : SYSDATA
      @sysdata = Appliance.system_data
      session[:reload_sysdata] = nil
    end
  end
  
  def load_software_info
    @all = StatusEntry.all
    @updatelevel = {}
    @updatelevel['firmware_version'] = @all[0].version
    @updatelevel['firmware_version_date'] = @all[0].install_date
    @updatelevel['xpu_version'] = @all[1].version
    @updatelevel['xpu_version_date'] = @all[1].install_date
  end
  
  EXCEPTIONS_NOT_LOGGED = ['ActionController::UnknownAction',
                           'ActionController::RoutingError']
  protected
    def log_error(exc)
      super unless EXCEPTIONS_NOT_LOGGED.include?(exc.class.name)
    end
end
