class Setup::CompletionController < Setup::SetupController
  require "timeout"
  layout "setup"
  @@security_mode_csv = "/usr/lib/iss-pam/security_modes.csv"
  
  def index
    @iface = ManagementInterface.find(:first) unless session[:maintenance_mode]
	@xforce = Xforce.find(:first)
    @siface = SecurityInterface.find(:first)
    @datetime = TimeDate.find(:first)
    @site_protector = SiteProtector.find(:first)
	
	@xf_mode = {}
	if File.exist?(@@security_mode_csv)
      File.open(@@security_mode_csv).read.split("\n").each do |line|
        value, order, default, key = line.split(",")
        text = `cat /usr/lib/iss-pam/translations_en.xml | grep -v dtd | /usr/bin/Xalan -p pModeKey "'#{key}'" - /etc/crm/transforms/xslt/XForceSecurityName.xslt`

	    @xf_mode[value] = text
      end
	else
	  @xf_mode["moderate"] = "Moderate"
	end
  end

  def complete_setup
    session[:mgmt] = ManagementInterface.find(:first)
    remove_sessions
    session[:completion_started] = true
  end

  def setup_callback
    begin
      start_configuration if ajax?
      render :text => "true"
    rescue ApplianceExceptions::SetupException
      err = ""
      File.open("#{RAILS_ROOT}/tmp/setup_error.log", "r+") do |f|
        err = f.readlines
      end 
      render :text => err
    end
  end

  def maintenance_callback
    begin
      start_maintenance_configuration if ajax?
      render :text => "true"
    rescue ApplianceExceptions::SetupException
      err = ""
      File.open("#{RAILS_ROOT}/tmp/setup_error.log", "r+") do |f|
        err = f.readlines
      end
      render :text => err
    end
  end

  def finalize_setup
    begin
      finalize if ajax?
      render :text => "true"
    rescue ApplianceExceptions::SetupException
      err = ""
      File.open("#{RAILS_ROOT}/tmp/setup_error.log", "r+") do |f|
        err = f.readlines
      end
      render :text => err 
    end
  end

  def finalize_maintenance
    begin
      finalize_maintenance_setup if ajax?
      render :text => "true"
    rescue ApplianceExceptions::SetupException
      err = ""
      File.open("#{RAILS_ROOT}/tmp/setup_error.log", "r+") do |f|
        err = f.readlines
      end
      render :text => err 
    end
  end
  
  def navigate
    altnav = params[:altnav]
    redirect_to :controller => "/setup/#{altnav}"
  end
  
  def check_complete
    begin
      Timeout::timeout(60) {
        render :text => Appliance.configured?
      }
    rescue Timeout::Error 
        render :text => "timeout_exit"
    end
  end

  private
  def start_configuration
    Appliance.configuring
    Setup.start_configuration
  end

  def start_maintenance_configuration
    Appliance.configuring
    Setup.start_maintenance_configuration
  end

  def finalize
    Setup.finalize
  end

  def finalize_maintenance_setup
    Setup.finalize_maintenance
  end

  def remove_sessions
    session[:welcome_set] = nil
    session[:sla_set] = nil
    session[:license_upload_set] = nil
    session[:lmi_password_set] = nil
    session[:root_password_set] = nil
    session[:management_interfaces_set] = nil
	session[:xforce_set] = nil
    session[:security_interfaces_set] = nil
    session[:datetime_set] = nil
    session[:site_protector_set] = nil
    session[:updates_set] = nil
    session[:maintenance_mode] = nil
  end   
end
