class Setup::WelcomeController < Setup::SetupController 
  layout "setup"

  def index
    session[:completion_started] = nil
    
    if File.exists?("#{ROOTDIR}etc/appliance/iss-provsetup.pid") and !session[:ignore_setup_warning]
      redirect_to :action => :warn_setup_in_progress
    end

    ManagementInterface.load_from_policy if session[:management_interfaces_set].blank?
    Appliance.reconfigure? ? Appliance.maint_setup_lock : Appliance.setup_lock
  end

  def warn_setup_in_progress
    RAILS_DEFAULT_LOGGER.warn("WARNING SETUP IN PROGRESS")
  end

  def ignore_setup_warning
    RAILS_DEFAULT_LOGGER.warn("SETUP WARNING IGNORED!!! CONTINUE SETUP...")
    session[:ignore_setup_warning] = true
    redirect_to :action => :index
  end

  def next_page
    altnav = params[:altnav]
    
    unless altnav.blank?
      navigate(altnav)
      return
    end
    
    session[:welcome_set] = true
    url = {:controller=>:service_agreement, :action=>:index}

    if Appliance.maintenance_setup?
      set_maintenance_mode
      url = {:controller=>:management_interfaces, :action=>:index}
    end
    redirect_to url
  end
  
  def navigate(altnav)
    redirect_to :controller => "/setup/#{altnav}"
  end

  def fips
    render :layout => 'minimal'  
  end

  def change_to_fips_mode
    if request.post? and params[:fips] == "yes"
      begin
		tlsv10 = (params[:tlsv10] == "yes") ? "--use-tlsv10" : ""
		tlsv11 = (params[:tlsv11] == "yes") ? "--use-tlsv11" : ""
        #Lock the LMI down to the FIPS config notification page only        
        Appliance.fips_setup_lock
        configure_fips(tlsv10, tlsv11)
      rescue
        session[:error] = true
        logger.error "Encountered error while attempting to configure FIPS."
      end
    end
  end

  def configuring_fips
  end

####################### TODO REMOVE BEFORE SHIPPING ##########################
####################### TODO REMOVE BEFORE SHIPPING ##########################
####################### TODO REMOVE BEFORE SHIPPING ##########################
####################### TODO REMOVE BEFORE SHIPPING ##########################

 def dev_reset_fips
    Appliance.clear_fips_setup_lock
    `rm -f #{ROOTDIR}etc/appliance/.fipsmode`
    redirect_to :controller => "/setup/welcome", :action => "index"
  end


  def dev_complete_fips
    Appliance.clear_fips_setup_lock
    `touch #{ROOTDIR}etc/appliance/.fipsmode`
    redirect_to :controller => "/setup/welcome", :action => "index"
  end

####################### TODO REMOVE BEFORE SHIPPING ##########################
####################### TODO REMOVE BEFORE SHIPPING ##########################
####################### TODO REMOVE BEFORE SHIPPING ##########################
####################### TODO REMOVE BEFORE SHIPPING ##########################


  private
  def set_maintenance_mode
    session[:lmi_password_set] = true
  end
  
  def configure_fips(tlsv10, tlsv11)
    `#{ROOTDIR}usr/bin/sudo #{ROOTDIR}usr/bin/provgSetupCmd fips --enable #{tlsv10} #{tlsv11}`
  end
end
