module UpdatesHelper
  require "rexml/document"
  include REXML
  
  def get_module_class(status_entry)
    begin
      return  "status_ok" if status_good(status_entry)
    rescue ApplianceExceptions::FirstLoadException
      logger.warn("UpdatesHelper::get_module_class -- ApplianceExceptions::FirstLoadException.")
      return "status_error"
    rescue ApplianceExceptions::LicenseException
      logger.warn("UpdatesHelper::get_module_class -- ApplianceExceptions::LicenseException.")
      return "status_error"
    rescue ApplianceExceptions::DisabledException
      logger.warn("UpdatesHelper::get_module_class -- ApplianceExceptions::DisabledException.")
      return "status_disabled"
    rescue ApplianceExceptions::UpdateException
      logger.warn("UpdatesHelper::get_module_class -- ApplianceExceptions::UpdateException (Update is available).")
      return "status_warn"
    rescue ApplianceExceptions::FatalException
      logger.warn("UpdatesHelper::get_module_class -- ApplianceExceptions::FatalException -- Something went wrong.")
      return "status_critical"
    end
  end
  
  
  def status_good(status_entry)
    status = status_check(status_entry)

    if status_entry.name == "Web Filter" and status != 0
      status = status_check(get_spam_module)     
    end
        
        
    case status
      when 0 : true
      when 1 : raise ApplianceExceptions::LicenseException
      when 2 : raise ApplianceExceptions::DisabledException
      when 3 : raise ApplianceExceptions::UpdateException
      when 4 : raise ApplianceExceptions::FatalException
      when 5 : raise ApplianceExceptions::FirstLoadException
    end
  end  


  def status_check(status_entry)
    (status_entry.latest == 1 and status_entry.licensed == 1 and status_entry.license_usage_exp == 0 and status_entry.license_maint_exp == 0) ? 0 : check_first_load(status_entry)
  end 
  
  def check_first_load(status_entry)
    status_entry.licensed == 2 ? 5 : check_license_status(status_entry)
  end
  
  
  def check_license_status(status_entry)
    (status_entry.licensed == 0 or status_entry.license_usage_exp == 1 or status_entry.license_maint_exp == 1) ? 1 : check_update_status(status_entry)
  end 
  
  
  def check_update_status(status_entry)
    (status_entry.latest == 0) ? 3 : true
  end
  
  
  def check_file_read_status
    @file_read_error ? 4 : 2
  end

  
  def is_perpetual_license(date)
    return date.to_s[0, 4] == "9999"
  end
  
  def get_user_pluralization(uc)
    return "user" if uc.to_i == 1
    return "users"
  end
  
  
  def get_status(file, element, attribute, status_entry)
    begin
      doc = get_state_xml_file(file)
      root = doc.root
      status = root.elements["#{element}"].attributes["#{attribute}"]
      return status
    rescue
      error = "A serious error has occurred while attempting to read the policy xml file"
      build_error(status_entry, error)
      return "false"
    end
  end
  
  
  def get_xml_file(filepath)
    file = File.open(filepath)
    doc = Document.new(file)
    file.close
    return doc
  end
  
  
  def get_state_xml_file(filepath)
    begin
      doc = Document.new(File.open(filepath))
    rescue
      pos = filepath =~ /\/\w*.xml$/
      basename = filepath[pos+1, filepath.length]
      filepath = get_file_path(basename)
      doc = get_xml_file("#{filepath}#{basename}")
      config_file = "#{FOLDER_PUBLIC_POLICY}/#{basename}"
      File.open(config_file, "w"){|f| f.write(doc.write)}
      doc = Document.new(File.open(config_file))
    end
    return doc
  end
  
  
  def get_file_path(filename)
    case filename
      when "npavm1_0.xml"   : "#{FOLDER_SYSTEM_POLICY}/avm/"
      when "npipm1_0.xml"   : "#{FOLDER_SYSTEM_POLICY}/ipm/"
      when "npssls1_0.xml"  : "#{FOLDER_SYSTEM_POLICY}/ssls/"
      when "npspam1_0.xml"  : "#{FOLDER_SYSTEM_POLICY}/spam/"
      when "npcflts1_0.xml" : "#{FOLDER_SYSTEM_POLICY}/cflts/"
    end
  end
  
  
  def build_error(status_entry, error)
     logger.error(error)
      flash[:notice] = Message.new(:first_time_load, :error)    
      render :partial => 'includes/message', :locals => {:msg => flash[:notice].text, :css => flash[:notice].css}
  end
  
    
  def module_shortname(selected_module)
    case selected_module.name
      when "SSL VPN"              : "sslvpn_module"
      when "Antivirus"            : "antivirus_module"
      when "Intrusion Prevention" : "ip_module"
      when "Antispam"             : "antispam_module"
      when "Web Filter"           : "filter_module"
      else "firmware_module"
    end
  end
  
  
  def get_license_info(license)
    uc = license.license_user_count
    return render(:partial => 'license_info', :locals => {:uc => uc, :license => license})
  end
  
  def get_spam_module
    return StatusEntry.find_by_name("Antispam")
  end
  
end
