class Adapter < ActiveRecord::Base
  belongs_to :segment
  require "rexml/document"
  include REXML
  
  def self.init
    if !defined?(@@speed_duplex_choices)
      @@speed_duplex_choices = {}
      populate
    end
  end
  
  def self.speeds
    init
    @@speed_duplex_choices
  end
  
  # Return array of speed/duplexes corresponding to alphanumeric port 'A' .. 'H'
  # Note:  port A,B correspond to card 1; port C,D correspond to card 2, etc.
  def self.speeds_by_port(adapter_port)
    RAILS_DEFAULT_LOGGER.info "Adapter::speeds_by_port-- #{adapter_port}"
    init
    empty_result = {} 
    int_equiv_port = adapter_port.capitalize[0] - 64  # 65 Ascii corresponds to 'A'
    RAILS_DEFAULT_LOGGER.debug "Adapter::speeds_by_port-- int_equiv_port=#{int_equiv_port}"
    if (1..@@number_of_adapters).include?int_equiv_port 
      RAILS_DEFAULT_LOGGER.debug "Adapter::speeds_by_port-- Inside 1..#{@@number_of_cards}"
      @@speed_duplex_choices[:ports][int_equiv_port]
    else
      empty_result
    RAILS_DEFAULT_LOGGER.error "Adapter::speeds_by_port-- Error initializing array of speed/duplexes for adapter_port #{adapter_port}"
    end
  end

  private
  def self.populate
    #Parse from current version of sensorCapabilities (defined in SensorPolicyInfoG.xml)
    sensor_info_g_index = Policy::SensorInfo.index
    sensor_cap_namespace = "http://www.iss.net/cml/NetworkDefender/sensorCapabilities"
    policyname = sensor_info_g_index.filename_by_namespace(sensor_cap_namespace)
    relativepath = sensor_info_g_index.relative_path_by_namespace(sensor_cap_namespace)
    fullPathToPolicy = "#{ROOTDIR}etc/crm/policies/#{relativepath}/#{policyname}" 
    RAILS_DEFAULT_LOGGER.debug " ** Adapter::populate - sensorCapabilities policy:#{fullPathToPolicy}  "
    doc = Document.new(File.new(fullPathToPolicy))
    if doc != nil
      @@number_of_adapters = 16 #TODO - parse from sensorCapabilities
      @@number_of_cards = @@number_of_adapters / 2
      @@speed_duplex_choices[:mgmt]  = get_choices(doc, "mgmtPortDuplexes")
      @@speed_duplex_choices[:kill]  = get_choices(doc, "killPortDuplexes")
      ports = []
      (1..@@number_of_cards).each do |card|
        card_key = "duplexesCard" + card.to_s
        ports[2*card-1] =  ports[2*card] = get_choices(doc, card_key)
    RAILS_DEFAULT_LOGGER.debug " ** Adapter::populate - card=#{card}, ports[2*card-1]=#{ports[2*card-1]}, ports[2*card]=#{ports[2*card]}  "
      end
      @@speed_duplex_choices[:ports] = ports 
    RAILS_DEFAULT_LOGGER.debug " ** Adapter::populate - #{@@speed_duplex_choices[:ports]}  "
    
    else
      RAILS_DEFAULT_LOGGER.error " ** Adapter::populate - Error reading policy:#{fullPathToPolicy}  "
    end 
    @@speed_duplex_choices
  end
  
  def self.get_choices(doc, speed_duplex_elem)
    choices = []
    doc.root.elements.each("//#{speed_duplex_elem}") do |elem|
      choices << elem.attributes["speedDuplexMode"]
    end
    choices
  end
  
#  SPEEDS_DEPRECATED=[["Auto", 'Auto'], 
#          ["10 Mb Full Duplex", "10 Mb Full Duplex"], 
#          ["10 Mb Half Duplex", "10 Mb Half Duplex"], 
#          ["100 Mb Full Duplex", "100 Mb Full Duplex"], 
#          ["100 Mb Half Duplex", "100 Mb Half Duplex"], 
#          ["1000 Mb Full Duplex", "1000 Mb Full Duplex"]].freeze

end
