class Appliance < ActiveRecord::Base
 attr_accessor :device_data

  require 'rexml/document'
  include REXML

  
  def self.sensor_running?
    pid = `#{ROOTDIR}sbin/pidof issDaemon`
    !pid.blank?
  end
 
  def self.ipv4_addr
    addr = ""
    policy = Document.new File.new("#{Setup.policy_transforms[:network][:policy]}")
    mode = policy.elements['//Config/MgmtInterface/IPv4/DHCP'].nil? ? "static" : "dhcp"
    
    if mode == "static"
      unless policy.elements['//Config/MgmtInterface/IPv4/Static/attribute::IpAddr'].blank?
        addr = policy.elements['//Config/MgmtInterface/IPv4/Static/attribute::IpAddr'].value
      else
        addr = "uknown"
      end
    else
      addr = "dhcp"
    end
    addr
  end
  
  def self.ipv6_addr
    addr = ""
    policy = Document.new File.new("#{Setup.policy_transforms[:network][:policy]}")
    mode = policy.elements['//Config/MgmtInterface/IPv6/Auto'].nil? ? "static" : "auto"

    
    if mode == "static"
      unless policy.elements['//Config/MgmtInterface/IPv6/Static/attribute::IpAddr'].blank?
        addr = policy.elements['//Config/MgmtInterface/IPv6/Static/attribute::IpAddr'].value
      else
        addr = "uknown"
      end
    else
      addr = "dhcp"
    end
    addr
  end
  
  def self.set_management(arg)
    p = CpeProperty.find_by_namespace("http://www.iss.net/cml/NetworkDefender/mgmt")
    Policy::Server.publicize_policy(p)
    policy = Document.new(File.new(FOLDER_PUBLIC_POLICY + p.policy))
    policy.elements.to_a("//Config")[0].attributes["Enabled"] = arg
    result = Policy::Server.save_policy(p.namespace, p.schema_version, policy.to_s)
    arg == "true" ? sp_register_msg(result) : sp_unregister_msg(result)
  end
  
  def self.get_management
    p = CpeProperty.find_by_namespace("http://www.iss.net/cml/NetworkDefender/mgmt")
    Policy::Server.publicize_policy(p)
    policy = Document.new(File.new(FOLDER_PUBLIC_POLICY + p.policy))
    sp = policy.elements.to_a("//Config")[0].attributes["Enabled"]
    sp == "true" ? "SiteProtector" : "Local Management Interface"
  end

  def self.sp?
    p = CpeProperty.find_by_namespace("http://www.iss.net/cml/NetworkDefender/mgmt")
    Policy::Server.publicize_policy(p)
    policy = Document.new(File.new(FOLDER_PUBLIC_POLICY + p.policy))
    sp = policy.elements.to_a("//Config")[0].attributes["Enabled"]
    sp == "true" ? true : false
  end
  
  def self.snort_running?
    pid = `#{ROOTDIR}sbin/pidof snort-plain`
    !pid.blank?
  end
  
  def self.snort_enabled?
    query = "select * from systemstatus where indicatorid = '24' and name like 'Snort status'"
    dbpath = Dbmap.crm
    db = SqliteSource.initialize_database(dbpath, true)
    results = SqliteSource.query_database(db, dbpath, query)
    if results && results.length > 0
      (results[0]["Msg"].downcase.match("enabled") == nil) ? false : true
    else
      false
    end
  end
  
  def self.snort_profiling_enabled?
    query = "select * from systemstatus where indicatorid = '24' and name like 'Snort rule profiling status'"
    dbpath = Dbmap.crm
    db = SqliteSource.initialize_database(dbpath, true)
    results = SqliteSource.query_database(db, dbpath, query)
    if results && results.length > 0
      (results[0]["Msg"].downcase.match("enabled") == nil) ? false : true
    else
      false
    end
  end
  
  def self.snort_health
    query = "select * from systemstatus where indicatorid = '24'"
    dbpath = Dbmap.crm
    db = SqliteSource.initialize_database(dbpath, true)
    rows = SqliteSource.query_database(db, dbpath, query)
    return [] if rows == nil or rows.empty?
    return rows
  end

  def self.sp_unregister_msg(result)
    if result == "OK"
      return "Successfully configured appliance for local management.", false
    else
      return "An error occurred while attempting to configure the appliance for local management.", true
    end
  end

  def self.sp_register_msg(result)
    if result == "OK"
      return "Successfully registered with SiteProtector.", false
    else
      return "An error occurred while attempting to register with SiteProtector.", true
    end
  end

  def self.site_protector_configured?
    configured = false
    begin
      p = CpeProperty.find_by_namespace("http://www.iss.net/cml/NetworkDefender/mgmt")
      Policy::Server.publicize_policy(p)
      policy = Document.new(File.new(FOLDER_PUBLIC_POLICY + p.policy))
      var = policy.elements.to_a("//AgentManager")
    rescue
      return configured
    end
    
    return configured if var.blank?

    begin
      configured = true unless var[0].attributes["EventServerIPorDNS"].blank?
    rescue
      configured = false
    end
    configured
  end


  def self.test_sp_connection
    msg = `#{ROOTDIR}usr/bin/testSPComm -logfile #{RAILS_ROOT}/log/testSPComm.log`
    if $?.success?
      return "Successfully connected to SiteProtector. Please consult the <a onclick=\"#{popup('/appliance_maintenance/sp_comm_log')}\">log file</a> for further details.", "false"
    else
      return sp_connection_error(msg), "true"
    end
  end

  def self.sp_connection_error(msg)
    if msg =~ /due\sto\sbad\sinput/
      return "SiteProtector is not properly configured. Please consult the <a onclick=\"#{popup('/appliance_maintenance/sp_comm_log')}\">log file</a> for further details."
    elsif msg =~ /communication\sfailure/
      return "Failed to reach the SiteProtector server over the network. Please consult the <a onclick=\"#{popup('/appliance_maintenance/sp_comm_log')}\">log file</a> for further details."
    else
      return "An uknown error has occurred while attempting to contact the SiteProtector server.  Please consult the <a onclick=\"#{popup('/appliance_maintenance/sp_comm_log')}\">log file</a> for further details."
    end
  end

   def self.managed_read_only?(namespace)
     begin
       ReadOnlyMap::MAP[namespace] == "true" && sp?
     rescue
       false
     end
   end

  def self.fips_mode?
    File.exists?("#{ROOTDIR}etc/appliance/.fipsmode")
  end

  def self.fips_setup?
    File.exists?("#{RAILS_ROOT}/tmp/fips_setup_in_progress")
  end
  
  def self.sla_accepted?
    File.exists?("#{ROOTDIR}etc/lmi/sla/lmi")
  end

  def self.reboot
    RAILS_DEFAULT_LOGGER.warn "Appliance is going down for reboot"
    Issasapache.execute(:a => "ct", :pns => "#{NAMESPACEPREFIX}/ctreboot")
  end

  def self.shutdown
    RAILS_DEFAULT_LOGGER.warn "Appliance is going down for shutdown"
    Issasapache.execute(:a => "ct", :pns => "#{NAMESPACEPREFIX}/ctshutdown")
  end

  def self.fips_setup_lock
    `touch #{RAILS_ROOT}/tmp/fips_setup_in_progress`
  end 

  def self.clear_fips_setup_lock
    `rm -f #{RAILS_ROOT}/tmp/fips_setup_in_progress`
  end 

  def self.setup_lock
    `touch #{RAILS_ROOT}/tmp/setup_in_progress`
    `touch #{ROOTDIR}etc/appliance/iss-provsetup.pid`
  end 

  def self.clear_setup_lock
    `rm -f #{RAILS_ROOT}/tmp/setup_in_progress`
    `rm -f #{RAILS_ROOT}/tmp/maint_setup_in_progress`
    `rm -f #{ROOTDIR}etc/appliance/iss-provsetup.pid`
  end

  def self.setup?
    File.exists?("#{RAILS_ROOT}/tmp/setup_in_progress") || File.exists?("#{RAILS_ROOT}/tmp/maint_setup_in_progress")
  end   

  def self.maintenance_setup?
    File.exists?("#{ROOTDIR}etc/appliance/.reconf") && File.exists?("#{RAILS_ROOT}/tmp/maint_setup_in_progress")
  end

  def self.lcd_configured?
    File.exists?("#{ROOTDIR}etc/appliance/.lcddone")
  end

  def self.maint_setup_lock
    `touch #{RAILS_ROOT}/tmp/maint_setup_in_progress`
    `touch #{ROOTDIR}etc/appliance/iss-provsetup.pid`
  end 

   def self.reconfigure?
      File.exists?("#{ROOTDIR}etc/appliance/.reconf")      
   end

   def self.clear_reconfigure
      file = "#{ROOTDIR}etc/appliance/.reconf"
      File.delete(file) if File.exists?(file)
   end

   def self.configured?
      File.exists?("#{ROOTDIR}etc/appliance/.confdone")      
   end

   def self.configuring
     `touch #{RAILS_ROOT}/tmp/.setup-configuring`
   end

   def self.clear_configuring
     file = "#{RAILS_ROOT}/tmp/.setup-configuring"
     File.delete(file) if File.exists?(file)
   end

   def self.configuring?
     File.exists?("#{RAILS_ROOT}/tmp/.setup-configuring") 
   end
   
   def self.setup_type
    reconfigure? ? "reconfigure" : "normal"
   end

  #System information methods
  def uptime
    t = difference
    "#{t[:w].to_i} weeks #{t[:d].to_i} days #{t[:h].to_i} hrs #{t[:m].to_i} mins #{t[:s].to_i} secs"
  end
  def self.initial_xpu_version
    ver = ""
    begin
      doc = Document.new(File.new("#{ROOTDIR}etc/lum/update-status.xml"))

      REXML::XPath.match(doc.root, "//updstat/packages/package").each do |p|
        ver = p.attributes["display_version"] if p.attributes["id"] =~ /XPU_PROV_PAM/
      end
    rescue
      ver = "Unknown"
    end
    ver
  end
   
  def self.initial_xpu_version
    ver = ""
    begin
      doc = Document.new(File.new("#{ROOTDIR}etc/lum/update-status.xml"))

      REXML::XPath.match(doc.root, "//updstat/packages/package").each do |p|
        ver = p.attributes["display_version"] if p.attributes["id"] =~ /XPU_PROV_PAM/
      end
    rescue
      ver = "Unknown"
    end
    ver
  end

 def self.interface_count
    gather_data("numberOfPorts").to_i
  end

  def self.segment_count
    begin
      gather_data("numberOfPorts").to_i / 2
    rescue
      return 0
    end
  end

  def self.model
    gather_data("model")
  end

  def self.display_name
    gather_data("displayName")
  end

  def self.family
    gather_data("family")
  end

  def self.catalog_name
    gather_data("catalogName")
  end
  
  def self.sensor_name
    sname = ""
    info = %x[#{ROOTDIR}usr/bin/sudo #{ROOTDIR}usr/bin/provgSetupCmd sensor --get]

    begin
      sname = info.map{|v| v if v =~ /Sensor name/}.compact.pop.split(":").pop.strip
    rescue
      sname = ""
    end
    sname
  end

  def self.npu_model
    npu = "No"
    info = %x[#{ROOTDIR}usr/bin/sudo #{ROOTDIR}usr/bin/provgSetupCmd sensor --get]

    begin
      npu = info.map{|v| v if v =~ /NPU Model/}.compact.pop.split(":").pop.strip
    rescue
      npu = "No"
    end
    npu == "Yes"
  end

  def self.gather_data(arg)
    begin
      sensor_data.elements["sensorIdentity"].attributes[arg]
    rescue
      RAILS_DEFAULT_LOGGER.error "Appliance.gather_data -- Error parsing the policy for #{arg}"
      return nil
    end
  end

  def self.virtual_appliance
    result = false
    begin
      File.open("/etc/proventia-release", "r") do |f|
        result = true if !f.grep(/GV/).blank?
      end
    rescue
      RAILS_DEFAULT_LOGGER.error "#{Time.now} Error while atempting to read the file /etc/provential-release"
    end
    result
  end

  def self.sensor_data
    p = CpeProperty.find_by_namespace("http://www.iss.net/cml/NetworkDefender/sensorCapabilities")
    file = "#{FOLDER_SYSTEM_POLICY}/sensorCapabilities/#{p.policy}"
    policy = nil
    begin
      policy = Document.new File.new(file) 
      return policy.root
    rescue
      RAILS_DEFAULT_LOGGER.error "Appliance.gather_data -- Error opening the policy #{file}"
      return nil
    end
  end

  def self.system_data
    data = {}
    query = "select * from systeminfoview"
    dbpath = Dbmap.crm
    
    db = SqliteSource.initialize_database(dbpath, true)
    results = SqliteSource.query_database(db, dbpath, query)
    
    begin
      results.each{|e| data[e["Param"].split(" ").join("_").downcase] = e["Value"]}
    rescue
      RAILS_DEFAULT_LOGGER.error("#{Time.now} ERROR: Retrieving systeminfoview results")      
      return {}
    end

    data
  end
  
  def self.system_messages
    result = []
    message_hash = {}
    query = "select * from strings"
    dbpath = Dbmap.crm
    db = SqliteSource.initialize_database(dbpath, true)
    results = SqliteSource.query_database(db, dbpath, query)
    begin
      results.each do |r|
        message_hash[r["ID"]] = r["StringVal"]
      end
    rescue
      RAILS_DEFAULT_LOGGER.error("#{Time.now} ERROR: Retrieving strings results") 
      return {}
    end
    message_hash
  end

  def self.popup(href)
    str = ""
    str << "window.open('#{href}', 'mywindow', 'toolbar=0, width=660, "
    str << "height=600, menubar=0, scrollbars=1, resizable=1');"
    str
  end
  
  def self.uptime
    u = `#{ROOTDIR}usr/bin/uptime`
    uptime = ""
    begin
      uptime = u[u.index("up")..u.index(",")].gsub(/up\s|,/, "")
    rescue
      uptime = "0:00"
    end
    uptime
  end
  
  def self.last_restart
    time = nil
    time = `#{ROOTDIR}usr/bin/utmpdump /var/run/utmp 2>/dev/null | grep reboot | head -1 | awk -F[ '{print $NF}' | awk '{print $3" "$2" "$5" "$4}'`
    RAILS_DEFAULT_LOGGER.info "Last reboot time from utmpdump is #{time}"
    if time.blank?
      time = Time.now.strftime("%d %b %Y %H:%M:%S")
    end
    time
  end
  
  def self.group_health_nodes(health)
    container_arr = [["Network health", [], "/dashboard/network", ["11"]],["Security health", [], "/dashboard/security", ["9","24"]],[ "System health", [], "/dashboard/system", ["8"]],["SiteProtector health", [], "", ["10"]]]
    container_arr.each do |container|
      container[1] = health.select{|h| container[3].include?(h.indicatorid)}
    end
    container_arr
  end
end

