class LogDb
  attr_reader :start_date, :end_date, :zoom_start_date, :zoom_end_date
  
  def initialize(filter)
    @filter=filter
  end
  
  # Regular Cache
  def find_current(result_size, zoom_result_size)
    @cache = cache.new(@filter, result_size)
    @zoom_cache = cache.new(LmiFilter.blank, zoom_result_size)
    log_split(log_module.find(@cache))
  end
  
  def find_newer
    @cache.page_newer
    log_split(log_module.find(@cache))
  end
  
  def find_older
    @cache.page_older
    log_split(log_module.find(@cache))
  end

  def find_oldest
    @cache.page_end
    log_split(log_module.find(@cache))
  end
  
  def find_newest
    @cache.page_begin
    log_split(log_module.find(@cache))
  end  
  
  def at_oldest?
    @cache.at_end?
  end
  
  def at_newest?
    @cache.at_begin?
  end
 
  # Zoom cache 
  def find_zoom_current(index)
    log_split(log_module.find_by_index(@cache, @zoom_cache, index))
  end
  
  def find_zoom_newer
    @zoom_cache.page_newer
    log_split(log_module.find(@zoom_cache))
  end
  
  def find_zoom_older
    @zoom_cache.page_older
    log_split(log_module.find(@zoom_cache))
  end

  def find_zoom_oldest
    @zoom_cache.page_end
    log_split(log_module.find(@zoom_cache))
  end
  
  def find_zoom_newest
    @zoom_cache.page_begin
    log_split(log_module.find(@zoom_cache))
  end  
    
  def at_oldest_zoom?
    @zoom_cache.at_end?
  end
  
  def at_newest_zoom?
    @zoom_cache.at_begin?
  end
  
  def has_filter?
    ! @filter.empty?
  end

  def zoom_index
    return 0 if ! @zoom_cache.on_zoom_page?
    @zoom_cache.relative_zoom_index
  end
  
  protected
  def cache
    # attn subclasses: implement this
  end
  
  def log_module
    # attn subclasses: implement this
  end
  
  def log_split
    # attn subclasses: implement this
  end

end
