class LogEvidence
  attr_accessor :filebasename, :type, :ext, :file, :timestamp, :filesize, :filename
  include ActionView::Helpers::NumberHelper
  
  def initialize(file)
    @file = file
    tokmap = tokenize(file)
    @filebasename = tokmap[:filebasename]
    @type = tokmap[:type]
    @ext = tokmap[:ext]
    @timestamp = File.mtime(file).strftime("%a %b %d %Y %H:%M:%S")
    @filesize = number_to_human_size(File.size(file))
    @filename = tokmap[:filename]
  end
  
  def self.all
    logmap = []
    
    logs = Dir.glob("#{ROOTDIR}cache/packetlogger/logevidence/*").grep /\.(pcap|enc|live)$/
    raise ApplianceExceptions::LogreadException if logs.blank?

    logs.sort.each do |l|
      logmap << new( l )
    end
    
    logmap
  end
 
  def self.fullpath(type,arg)
    all.each do |log|
      return log.file if log.filename == arg and log.type == type
    end
    return false
  end
  
#  def self.packet_captures?
#    files = Dir.glob("#{ROOTDIR}cache/packetlogger/rollingpacketcapture/*").grep /\.(pcap|enc|live)$/
#    files.size > 0
#  end
  
  def self.log_evidence?
    files = Dir.glob("#{ROOTDIR}cache/packetlogger/logevidence/*").grep /\.(pcap|enc|live)$/
    files.size > 0
  end
    
  def tokenize(str)
    tokmap = {}
    
    begin
      type_index = @file.index(/logevidence/)
      tokens = @file[type_index..@file.length].split("/")
      basename = tokens[1]
      dotindex = basename.rindex(".")
      tokmap[:type] = tokens[0]
      if(!dotindex) then
        tokmap[:filebasename] = basename
        tokmap[:ext] = ""
        tokmap[:filename] = basename
      else
        tokmap[:filebasename] = basename[0..dotindex-1]
        tokmap[:ext] = basename[dotindex+1..basename.length]
        tokmap[:filename] = tokmap[:filebasename] + '.' + tokmap[:ext]
      end
    rescue
      RAILS_DEFAULT_LOGGER.error "#{Time.now} [ERROR] While attempting to tokenize #{str}"
      return {}
    end
    tokmap
  end
end
