class LogManager
  attr_accessor :filebasename, :type, :ext, :file, :timestamp, :filesize, :filename
  include ActionView::Helpers::NumberHelper
  
  def initialize(file)
    @file = file
    tokmap = tokenize(file)
    @filebasename = tokmap[:filebasename]
    @type = tokmap[:type]
    @ext = tokmap[:ext]
    @timestamp = File.mtime(file).strftime("%a %b %d %Y %H:%M:%S")
    @filesize = number_to_human_size(File.size(file))
    @filename = tokmap[:filename]
  end


  def self.download(name)
    `cd #{ROOTDIR}var/iss && find -L ./ -type f -name '#{name}*' | xargs tar -hczf #{ROOTDIR}/tmp/#{name}.tgz`
    $?.exitstatus
  end

  def self.clean(name)
    `rm -rf #{ROOTDIR}tmp/#{name}.tgz`
    $?.exitstatus
  end


  def self.all
    logmap = []
    
    logs = Dir.glob("#{ROOTDIR}var/iss/**/*")
    raise ApplianceExceptions::LogreadException if logs.blank?

    logs.sort.each do |l|
      logmap << new( l ) if File.exists?( l )
    end
    
    logmap
  end
  
  
  def self.unique_entries(logobj)
    objs = {}
    
    logobj.each do |k, v|
      if (!objs.key?(v[:category]))
        objs[v[:category]] = v[:timestamp]
      elsif (objs[v[:category]] < v[:timestamp])
        objs[v[:category]] =  v[:timestamp]
      end       
    end
    objs.each{|k, v| objs[k] = v.strftime("%a %b %d %Y %H:%M:%S")}
    objs
  end

  def self.valid_name?(arg)
    all.each do |log|
      return true if log.filename == arg
 #     logfile = log.filebasename
 #     return true if logfile == arg
    end
    return false
  end
  
  def tokenize(str)
    tokmap = {}
    
    begin
      type_index = @file.index(/iss/)
      tokens = @file[type_index..@file.length].split("/")
      basename = tokens[1]
      dotindex = basename.rindex(".")
      tokmap[:type] = tokens[0]
      if(!dotindex) then
        tokmap[:filebasename] = basename
        tokmap[:ext] = ""
        tokmap[:filename] = basename
      else
        tokmap[:filebasename] = basename[0..dotindex-1]
        tokmap[:ext] = basename[dotindex+1..basename.length]
        tokmap[:filename] = tokmap[:filebasename] + '.' + tokmap[:ext]
      end
    rescue
      RAILS_DEFAULT_LOGGER.error "#{Time.now} [ERROR] While attempting to tokenize #{str}"
      return {}
    end
    tokmap
  end
end
