class SyslogLive  < SystemLogDb
  def self.get_current_logs(params=nil, type="syslog")

    lines = []
    params.symbolize_keys! unless params.nil?
    
    if params[:filter].nil?
      lines = get_unfiltered_lines(type)
    else
      lines = get_filtered_lines(params, type)
    end

    log_split(lines.flatten, type)
  end
  
  #private
  def self.get_filtered_lines(params, type)
    lines = log_lines(type)
    filters = get_filters(params)
    begin
      filters.each do |f|
        lines = lines.grep(/#{f}/i)
      end
    rescue ApplianceExceptions::LogreadException
      return []
    end
    lines[0, 50]
  end
  
  
  def self.get_unfiltered_lines(type)
    lines = []
    
    begin
      lines = log_lines(type)
    rescue ApplianceExceptions::LogreadException
      return []
    end
    
    return lines[0, 50]
  end
  
  def self.get_filters(params)
    params[:filter].map{|k, v| v}#.join("|")
  end

  def self.log_lines(type)
    file = nil
    begin
      if type == "syslog"
        file = File.open("#{LOGS_MESSAGES}", "r")
      else
        file = File.open("#{LOGS_FIREWALL}", "r")
      end
    rescue
      raise ApplianceExceptions::LogreadException
    end
    file_lines = file.readlines.reverse
    file.close
    return file_lines
  end

  def self.log_split(lines, type)
    case type
      when "syslog" then return lines.map {|l| l.split(/\s+/,7)}
      when "firewall" then return lines.map {|l| l.split(",")}   
    end
  end
end
