class Tool
  attr_reader :results, :file, :tool, :block, :need_results
  
  def initialize(tool,block=false,need_results=true)
    @tool = tool
    @block = block
    @need_results = need_results
    @results = Array.new
    name = tool.split(/\//)[-1]
    @file = "/tmp/#{name}.#{$$}"
  end
   
  def execute(args="",tool=@tool)
    if (@block)
      execute_block(args,tool)
    else
      execute_noblock(args,tool)
    end    
  end
  
  def fail_msg(msg)
    input = File.open(@file,"w")
    input << msg + "\n"
    input << "1"
    input.close
  end
    
  def results 
    if File.exists? @file
      input = File.open(@file,"r")
      @results = input.readlines  
      input.close

      if @results[-1] == "1"
        File.delete(@file)
      end
    end
          
    @results
  end 

  def destroy 
    if File.exists? @file
      File.delete(@file)
    end
  end
  
  private
  def determine_cmd(args,tool)
    "#{tool} #{args}"
  end

  def execute_block(args,tool)
    @results = Array.new   
    cmd = determine_cmd(args,tool)   
    execute_cmd(cmd)
  end
  
  def execute_noblock(args,tool)
    @results = Array.new   
    cmd = determine_cmd(args,tool)   
    Thread.fork {
      execute_cmd(cmd)
    }
  end

  def execute_cmd(cmd)
    if @need_results
      need_results(cmd)
    else
      no_results(cmd)
    end
  end
  
  def no_results(cmd)
    %x{#{cmd}}
  end
  
  def need_results(cmd)
    output = File.open(@file,"w")
    open("|#{cmd}").each {|l| 
        output.puts l
      output.flush
    }
    output << "1"
    output.close
  end
end
