class Top10 < ActiveRecord::Base
  
  ISSUES_COL = "IssueID"
  SRC_IP_COL = "SourceIP"
  DEST_IP_COL = "DestIP"

  def self.db_preffix
    Dbmap.ips
  end

  def self.issues_db
    Dbmap.issues
  end
  
  def self.sanitize_time(time) 
    if time !~ /^(all|hour|day|week)$/
      time = "all"  
    end
    
    return time
  end

  def self.sanitize_priority(priority)
    if priority !~ /^(all|low|medium|high)$/
      priority = "all"  
    end
    
    return priority
  end
  
  def self.determine_priority(priority)
    if priority == 'high'
      return "1"
    elsif priority == 'medium'
      return "2"
    elsif priority == 'low'
      return "3"
    else
      return nil
    end
  end

  ###################
  # grab_files 
  ###################
  def self.grab_files
    filelist = Array.new
    log = db_preffix

    i = 1
    while FileTest.exists?(log) do
      filelist.push(log)
      suffix = log_suffix(i)
      log = "#{db_preffix}.#{suffix}"
      i += 1
    end

    filelist
  end

  ###################
  # log_suffix 
  ###################
  def self.log_suffix(i)
    if i < 10
      suffix = "00#{i}"
    elsif i < 100
      suffix = "0#{i}"
    else
      suffix = i
    end
    
    suffix
  end
  
  
  def self.get_top10(col, time, priority)
    data = {}
    filelist = grab_files
    attachvals = attachdbs(col,filelist)
    priority_int = determine_priority(priority)
    
    query = create_statement(col, attachvals[1], time, priority_int)
    db = SqliteSource.initialize_database(db_preffix, false, attachvals[0])
    results = SqliteSource.query_database(db, db_preffix, query)
    results
  end
  
  def self.determine_datasource(graphtype,time,priority,href)
    href = "/statistics/#{graphtype}"

    if graphtype == 'top10attacks'
      primary_column = ISSUES_COL
    elsif graphtype == 'top10victims'
      primary_column = DEST_IP_COL
    else
      primary_column = SRC_IP_COL
    end

    if time !~ /^(hour|day|week)$/
      time = "all"
    end

    data = get_top10(primary_column,time,priority)
        
    href += "/#{time}"

    return href,data
  end

  def self.create_y_axis_link(data,filter_name)
    data.each_with_index do |item,i|
      if item[0].nil?
        text = "Unknown"
      elsif filter_name != "event_name"
        text =   HostInfo.find_name_by_address(item[0])
      else
        text = item[0]
      end
      
      text = text.match(/\s*(.*)\s*/)[1]
      text = "#{text[0..15]}..." if text.length > 15
      
      data[i][0] = "<a href=\"/alert_logs/link_filter?filter[criteria_1][coltype]=#{filter_name}&filter[criteria_1][text]=#{item[0]}\" title=\"#{item[0]}\">#{text}</a>&nbsp;&nbsp;"      
    end  
  end

  def self.format_data(data)
    fmt_data = Array.new
    data.each do |item|
      tmp = Array.new
      item.fields.each_with_index do |f, j|
        tmp.push(item[j])
      end
      fmt_data.push tmp
    end
    fmt_data.reverse!
  end

  #private
  def self.create_statement(primary_column,keys, time, priority)
    stmt = ''

    stmt += stmt_header(primary_column,time, priority)
    keys.each do |key|
      stmt << sum_sql(primary_column, key, time, priority)
    end
    stmt << stmt_tail(primary_column,priority)
    stmt    
  end
  
  def self.attachdb_key(file)
    file.match(/\.0*(\d+)$/)[1]
  end 
  
  def self.attachdbs(primary_column,files)
    ret = []    
    attached_dbs = []
    attach_keys = []
    
    files.sort_by {|f| File.mtime(f).to_i}.reverse.each do |file|
      next if file == db_preffix
      key = attachdb_key(file)
      attach_keys << "ia#{key}"
      attached_dbs << "attach \"#{file}\" as ia#{key};"
    end
    
    attached_dbs << "attach \"#{issues_db}\" as issues;" if primary_column == ISSUES_COL
    ret << attached_dbs
    ret << attach_keys
    ret
  end
  
  def self.attach_issues(db)
    db.execute("attach \"#{issues_db}\" as issues;") 
  end
  
  def self.determine_column(primary_column)
    s = ''
    if primary_column == ISSUES_COL
      s += "cd.CheckName as CheckName, "
    else
      s += "av.#{primary_column} as #{primary_column}, "
    end
    s
  end
  
  def self.time_filter(time)
    s = 'where '
    unless time == "all"
      s+= "Occurred > (datetime('now',"
      if time == "week"
       s += "'-7 days')) "
      else
       s += "'-1 #{time}')) "
      end 
    end 
    s 
  end
  
  def self.stmt_header(primary_column,time,priority)
    s = "select "
    s += determine_column(primary_column)
    s += "sum(counts) as count from (select #{primary_column}, sum(AlertCount)"
    s += "as counts "
    if primary_column == ISSUES_COL and ! priority.nil?
      s += ", Priority "
    end
    s += "from AttacksView "
    unless time == "all"
      s += time_filter(time)
    end  
    s += "group by #{primary_column} "
    s
  end
  
  def self.sum_sql(primary_column,db_name,time,priority)
    s =  " union all select #{primary_column}, sum(AlertCount) as counts "
    if primary_column == ISSUES_COL and ! priority.nil?
      s+= ", Priority "
    end
    s += "from #{db_name}.AttacksView "
    unless time == "all"
      s += time_filter(time)
    end
    s += "group by #{primary_column}"
    s
  end
  
  def self.stmt_tail(primary_column, priority)
    s = ") av "
    
    if primary_column == ISSUES_COL
      s += "LEFT OUTER JOIN issues.CheckDatesView cd ON av.IssueID = cd.IssueId "
      
      unless priority.nil?
        s += "where av.Priority = #{priority} "
      end
    end
    s += "group by av.#{primary_column} order by 2 desc LIMIT 10;"
    s
  end
end
