class DataSource < Hash
  require 'logger'
  require 'matrix'
  attr_accessor :data

  def initialize(prefix, rra=nil, bandwidth=false)
    @arg = prefix
    @metadata = YAML::load(File.read("#{RAILS_ROOT}/lib/definitions/datasources.yml"))
    @ds = @metadata[prefix]
  end      

  def [](var)
    return @metadata[var]
  end  

  def self.serial_number
    SqliteSource.new("system_sql").data[4].value.chomp
  end

  def self.machine_type
    SqliteSource.new("system_sql").data[2].value.chomp
  end

  def self.hostname
    name = `hostname`
    name.chomp
  end

  def self.volume_info
    volstring = `df -lh`
    vols = volstring.split("\n")
    vols.shift
    vols.each_with_index do |line, index|
      vols[index] = line.split(" ")[0, 6]
    end
    return vols
  end

  def self.raw_volume_info
    volstring = `df -l`
    vols = volstring.split("\n")
    vols.shift
    vols.each_with_index do |line, index|
      vols[index] = line.split(" ")[0, 6]
    end
    return vols
  end

  def self.bytes_to_mbytes(bytes)
    bytes / MBIT
  end

  def self.free_space?(file)
    size_limit = bytes_to_mbytes(File.size?(file) * 2 + 5120)
    free_space = raw_volume_info[0][3].to_i
    free_space < size_limit
  end
  
  def self.memory_info
    memarr = []
    mstring = `#{ROOTDIR}usr/bin/free`
    begin
      mem = mstring.split("\n")
      memarr << mem[2].split(" ")[2].to_f
      memarr << mem[1].split(" ")[1].to_f
    rescue
      RAILS_DEFAULT_LOGGER.info "#{Time.now}[ERROR] While attempting to parse the free command ouput"
      memarr<<0<<0      
    end
    memarr
  end
  
  def self.raid_info
    raidstatus = []
    rstring = `#{ROOTDIR}usr/bin/raidcheck`
    # the output of non-raid models is '\n' instead of nothing
    if rstring.length > 10
      begin
        status = rstring.split("\n")
        # parse status and strip leading and trailing quote
        # Logical status
        raidstatus << status[0].split("=")[1].chomp('"').reverse.chomp('"').reverse
        # Raid status
        raidstatus << status[1].split("=")[1].chomp('"').reverse.chomp('"').reverse
        # Disk0 status
        raidstatus << status[2].split("=")[1].chomp('"').reverse.chomp('"').reverse
        # Disk1 status
        raidstatus << status[3].split("=")[1].chomp('"').reverse.chomp('"').reverse
      rescue
        RAILS_DEFAULT_LOGGER.info "#{Time.now}[ERROR] While attempting to parse the raidcheck command output"
      end
	end
    raidstatus
  end

  def self.memory_percent_used
    m = memory_info
    calculate_percent(m[1], m[0])
  end

  def self.calculate_percent(total, used)
    percent = nil
    begin
      percent = sprintf("%.2f", (100 * used / total))
    rescue
      RAILS_DEFAULT_LOGGER.info "#{Time.now}[ERROR] While attempting to cacluate percent"
      percent = 0
    end
    percent
  end


  private  
  def self.format_data(data)
    return {} if data.blank?
    matrix = []
    result_hash = {}

    labels = data.shift
    data = data.transpose
    dates = convert_to_js_format(data.shift)
  
    matrix = data.map{|d| (Matrix[dates] + Matrix[d]).to_a  }
    matrix.each{|arg| result_hash[Message.get_label(labels.shift.to_sym)] = arg.flatten}
  
    result_hash.each do |key, val|
      val.each_with_index do |arg, index|
        val[index] = arg.split("&")
      end 
      result_hash[key] = val
    end
    result_hash.merge({"serial_number" => serial_number})
  end


  def self.convert_to_date(dates)
    return_array = []
    dates.each{|d| return_array << Time.at(d.to_i).strftime("%Y-%m-%d")+"&" }
    return return_array
  end


  def self.convert_to_js_format(dates)
    return_array = []
    dates.each{|d| return_array << "#{offset_time(d[0, d.length].to_i) * 1000}&"}
    return return_array
  end

  def self.new_class(rows, ds)
    klass = create_class(ds['klass'], Object) do
      rows[0].fields.each do |f|
        f.gsub!(/\W/,"_")
        attr_accessor f.downcase
      end
    end
    return klass
  end

  def self.create_class(class_name, superclass, &block)
    klass = Class.new superclass, &block
    Object.const_set class_name, klass
  end


 def self.offset_time(epoch_time)
    return Time.now.utc_offset + epoch_time
  end
end
