class FileLogCache < LogCache
  attr_reader :file_cache, :filter, :cleaned, :reset
  attr_accessor :base_zoom_index

  
  def initialize(file_preffix,filter,page_size=50)
    @filter = filter    
    @file_preffix = file_preffix
    
    @file_cache = Hash.new    
    size = initialize_cache
    super(size,page_size)
  end
  
  def on_zoom_page?
    return false if @base_zoom_index.nil?
    page_max_index > @base_zoom_index and @base_zoom_index >= page_max_index(@page_number-1)
  end

  def relative_zoom_index
    page_max_index - @base_zoom_index
  end

  ####################
  # get_filter_results
  ####################
  def get_filter_results(file)
    results = retrieve_file_data(file)
    results = @filter.do_filter(results)
    results
  end

  #####################
  # retrieve_file_data
  #####################
  def retrieve_file_data(file)
    input = File.open(file,"r")
    readlines = input.readlines
    input.close
  
    readlines
  end

  def log_modified?(log, mod_time)
    mod_time != log_mtime(log)
  end 
  
  def clean_cache
    @cleaned = false
    @reset = false
    new_cache = Hash.new
    current_fileset = gather_current_logs
   
    @file_cache.sort_by {|v| LogFile.sort_files(v[0])}.reverse_each do |archfile,data|
      status = "delete"
      current_fileset.sort_by {|v| LogFile.sort_files(v[0])}.reverse_each do |currfile,mtime|
        
        next if mtime != data[:mtime]
        if archfile == currfile
          RAILS_DEFAULT_LOGGER.info "Rollover log #{archfile} synced up..."
          #puts "Rollover log #{archfile} synced up..."
          status = "sync"
          next
        end
        RAILS_DEFAULT_LOGGER.info "Rollover log #{archfile} has changed, adjusting cache."
        #puts "Rollover log #{archfile} has changed, adjusting cache."
        status = "found"
        shift_file_cache(archfile,currfile,data)
      end
      break if status == "sync"
      next if status != "delete"

      if 1 == @file_cache.length and status == "delete"
        RAILS_DEFAULT_LOGGER.info "Reached end of cached log files, all files have changed under us"
        RAILS_DEFAULT_LOGGER.info "Recreating the entire cache"
        #puts "Reached end of cached log files, all files have changed under us"
        #puts  "Recreating the entire cache"
        reset_file_cache
        @reset = true        
        break      
      elsif status == "delete"
        RAILS_DEFAULT_LOGGER.info "Rollover log #{archfile} has been removed, deleting it from cache."
        #puts "Rollover log #{archfile} has been removed, deleting it from cache."
        @cleaned = true
        remove_file(archfile,data)
        next        
      end
      break if status == "sync"
    end
  end
    
  private
  ###################
  # grab_files 
  ###################
  def grab_files
    filelist = Array.new
    log = @file_preffix

    i = 1
    while FileTest.exists?(log) do
      filelist.push(log)
      log = "#{@file_preffix}.#{i}"
      i += 1
    end

    filelist
  end

  #####################
  # refresh_line_count
  #####################
  def refresh_line_count(file)
    input = File.open(file,"r")
    readlines = input.readlines
    input.close
  
    readlines.length
  end

  #####################
  # save_cache_entry
  #####################
  def save_cache_entry(result_count,file)
    data = Hash.new
    data[:size] = result_count
    data[:mtime] = log_mtime(file)
    @file_cache[file] = data
  end

  ######################
  # set_unfiltered_cache
  ######################
  def set_unfiltered_cache(file)
    lcount = refresh_line_count(file)
    save_cache_entry(lcount,file)
  
    lcount.to_i
  end


  ###################
  # set_filterd_cache
  ###################
  def set_filtered_cache(file)
    results = retrieve_file_data(file)
    results = @filter.do_filter(results)
    save_cache_entry(results.length.to_i,file)
  
    results.length.to_i
  end

  def log_mtime(log)
    log_file = File.new(log)
    begin
      changed_time = log_file.mtime
    ensure
      log_file.close unless log_file.nil?
    end
  end
  
  #####################
  # initialize_cache
  #####################
  def initialize_cache
    total_lines = 0
    filelist = grab_files

    for file in filelist.reverse
      if @filter.empty?
        total_lines += set_unfiltered_cache(file)
      else
        total_lines += set_filtered_cache(file)
      end
    end

    total_lines
  end
  
  def gather_current_logs
    logs = Hash.new
    files = grab_files
    files.each do |file|
      logs[file] = log_mtime(file)
    end
    
    logs
  end

  def shift_file_cache(oldfile,newfile,data)
    @file_cache[newfile] = data  
    @file_cache.delete(oldfile)
  end

  def remove_file(file,data)
    @size -= data[:size]
    @file_cache.delete(file)
   
    if @page_number > max_page_number
      page_end
    end        
  end
  
  def reset_file_cache
    @file_cache = Hash.new    
    @size = initialize_cache
    page_begin
  end  
  
end
