require 'logger'

class Issasapache
  ISSASAPACHE_BIN = "#{ROOTDIR}usr/bin/issasApache"
  SEPERATOR ='!,!'

  def self.run args
    params = args.is_a?(Hash) ? Issasapache::string_args(args) : args
    cmd = "#{ISSASAPACHE_BIN} #{params}"
    RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Issasapache.run: " + cmd
    
    results = %x{#{cmd}}
    
    message = Array.new
    results.each_line do |line|
      message.push line;
      if(line !~ /^OK/) 
        if(line =~ /\[ID=0x.*\]/) 
          status = line.match(/\[ID=(0x.*)\]/)[1] rescue "oops"
        end
      end
    end    
    RAILS_DEFAULT_LOGGER.debug "Issasapache.run message: " + message.to_s
    message
  end

  #issasApache call to use for side effect and return the resulting success code
  def self.execute(args)
    params = args.is_a?(Hash) ? Issasapache::string_args(args) : args
    cmd = "#{ISSASAPACHE_BIN} #{params}"
    RAILS_DEFAULT_LOGGER.info "Issasapache.execute: " + cmd
    `#{cmd} 2>&1` =~ /^OK/
  end  

  def self.string_args hash_args
    params = ""
    hash_args.each{|key,value| params += "-#{key} #{value} " }
    params
  end
  
  def self.process_modules data
    state = ''
    mod = ''
    datamap = Hash.new
    table = Array.new
    store = Hash.new
      
    data.each {|l|
      l.chop!
      if (l =~ /StartofModule/)
        state = 'Start'
      elsif (state.eql?('Start'))
        mod,time = l.split SEPERATOR
        state = 'Table'
      elsif (l =~ /EndofModule/)
        if (! table.empty?) 
          datamap[mod] = table
        end
        table = Array.new
        state = ''
        mod = ''
      elsif (! mod.empty? && (l =~ /BeginRow/ || l =~ /BeginGroup/))
        name,value = l.split SEPERATOR
        state = 'BeginRow'
        if (! name.eql?(value))
          state << ":#{value}"
        end
      elsif (state =~ /BeginRow/ && (l =~ /EndRow/ || l =~ /EndGroup/))
        if (! store.empty?)
          table.push store
          end
        store = Hash.new
        state = "Table"
      elsif (state =~ /BeginRow/)
        name,value = l.split SEPERATOR
        if ( ! name.match(/^c\d+/))
          store[name] = value
        end
      end            
    }          
    datamap 
  end
    
  def self.process_system data
    state = ''
    modules = Array.new
    appliancedata = Hash.new
      data.each {|l|
      l.chop!
      if (l =~ /StartofModuleInfo/)
        state = 'ModuleList'
      elsif (l =~ /EndofModuleInfo/)
        state = ''
      elsif (l =~ /StartofNameValueInfo/)
        state = 'ApplianceInfo'
      elsif (l =~ /EndofNameValueInfo/)
        state = ''
      elsif (state.eql?('ModuleList'))
        name,time,version,impl = l.split SEPERATOR
        if (impl.eql?('Y'))
          modules.push Hash[:name,name, :time,time, :version,version]
        end
      elsif (state.eql?('ApplianceInfo'))
        name,value = l.split SEPERATOR
        appliancedata[name] = value
      end
    }    
    return modules,appliancedata    
  end
  
  def self.process_stats data
    stats = Array.new
    data.each do |l|
      l.chop!
      if l !~ /^OK/ then
        name,value,description = l.split SEPERATOR
        stats.push Hash[:name,name, :value,value, :description,description]
      end
    end
    stats
  end

  def self.process_and_filter_stats data, filter
    stats = Hash.new
    data.each do |l|
      l.chop!
      if l !~ /^OK/ then
        name,value,description = l.split SEPERATOR
        if filter[name]
          stats[name] = value
        end
      end
    end
    stats
  end

  def self.system_call(args)
    # EMG CR 407225 - LUM doesn't send set-license-request to CRM - prevents
    # np.license.key from being set in PAM - adding call to issasApache to
    # perform the necessary IPC - return val needed to do this
    cmd = "#{ISSASAPACHE_BIN} #{args.join(" ")}"
    RAILS_DEFAULT_LOGGER.info "#{cmd}"
    `#{cmd}`
  end
end
