class Lum
  Namespace             = "NetworkDefender"
  Configure_task_param  = "ct"
  @license_temp		= ""
 
  def self.load_data
    RAILS_DEFAULT_LOGGER.info "Lum -- load_lum_data called"
    load_db if refresh_required?
    load_history_db if history_refresh_required?
  end
  
  def self.find_updates
    RAILS_DEFAULT_LOGGER.info "Lum -- find_updates called"
    refresh_entitlements
    LumCore.find_updates
    message
  end
    
  def self.find_local_updates
    RAILS_DEFAULT_LOGGER.info "Lum -- find_local_updates called"
    LumCore.find_updates("local")
    message
  end
  
  def self.refresh_entitlements
    RAILS_DEFAULT_LOGGER.info "Lum -- refresh entitlements called"
    LumCore.refresh_entitlements
  end
  
  def self.apply_license(path)
    RAILS_DEFAULT_LOGGER.info "Lum -- apply_license called with #{path}"
    LumCore.apply_license(path)
    @license_temp = path 
    message
  end

  def self.update_firmware(version=nil)
    RAILS_DEFAULT_LOGGER.info "update_firmware called with #{version}"
    LumCore.update(:fw, version)
  end
  
  def self.update
    LumCore.update
    message
  end

  def self.rollback
    LumCore.rollback
    message
  end

  def self.db_update_in_progress?
    RAILS_DEFAULT_LOGGER.info "LUM:db_update_in_progress?"
    return (File.exists?("#{ROOTDIR}tmp/db_update_in_progress.lck") \
       or File.exists?("#{ROOTDIR}tmp/lum_task_in_progress.lck"))
  end
  
  def self.get_serial_number
    File.open("#{ROOTDIR}etc/lum/host-info-in-use", "r") do |file|
       Utility.format_file_text(file.readline).sub("<br />", "").sub("serial=", "").strip
    end
  end



  def self.create_token(arg)
    method = arg[:token][:method]
    exitcode = ""

    if method == "manual"
      exitcode = register_user_token(arg[:token][:string]) 
    else
      exitcode = register_credentials_token(arg[:token][:username], arg[:token][:password])
    end
    exitcode
  end


  def self.token
    tinfo = []
    tinfo = token_info
    if tinfo.blank?
      return ""
    else
      tinfo.flatten!
      return get_token_method(tinfo[2])
    end
  end

  def self.token_info
    tokeninfo = []
    if File.exists?("#{ROOTDIR}etc/lum/host-info")
      begin  
        File.open("#{ROOTDIR}etc/lum/host-info", "r") do |f|
          tokeninfo = f.readlines.split(" ")
        end
      rescue
        return tokeninfo
      end
    end
    tokeninfo
  end


  private
  def self.refresh_required?
    src_file_1 = "#{ROOTDIR}etc/lum/update-state.yaml"
    state_cache_file = "#{RAILS_ROOT}/tmp/update-state.cache"
    
    src_file_2 = "#{ROOTDIR}etc/lum/update-available.yaml"
    update_cache_file = "#{RAILS_ROOT}/tmp/update-available.cache"

    return true if(!File.exists?(state_cache_file) && !File.exists?(update_cache_file))
    
    if (File.exists?(state_cache_file) && File.exists?(update_cache_file) && File.exists?(src_file_1) && File.exists?(src_file_2))
      return !(File.compare("#{ROOTDIR}etc/lum/update-available.yaml", update_cache_file)) ||
             !(File.compare("#{ROOTDIR}etc/lum/update-state.yaml", state_cache_file))
    else
      return true
    end
  end
  
  def self.history_refresh_required?
    src_file = "#{ROOTDIR}etc/lum/update-history.yaml"
    cache_file = "#{RAILS_ROOT}/tmp/update-history.cache"
    
    return true if (!File.exists?(cache_file))
    
    if (File.exists?(src_file))
      return !File.compare("#{ROOTDIR}etc/lum/update-history.yaml", "#{RAILS_ROOT}/tmp/update-history.cache")
    else
      return true
    end
  end
  
  def self.get_token_method(tstring)
    return "" if tstring.blank?
    return "MyISS Credentials" if tstring =~ /USE_PORTAL/
    tstring.gsub("Serial Number:", "").strip 
  end

  def self.remove_registered_token
    RAILS_DEFAULT_LOGGER.info "Lum -- DELETING MYISS TOKEN PORTAL CREDS"
    `#{ROOTDIR}usr/bin/lumCtrl --delcredentials --wait`  
    return $?
  end

  def self.register_user_token(token)
    remove_registered_token
    params = ["-a", "cta", "-pv", "1.0", "-sv", "1.0.0"]
    params.concat(["-pns", "http://www.iss.net/cml/NetworkDefender/ctsethostinfotoken"])
    params.concat(["-atn", "token", "-atv", token])
    exitcode = Issasapache.system_call(params)
    exitcode
  end

  def self.register_credentials_token(user, pass)
    RAILS_DEFAULT_LOGGER.info "Lum -- REGISTERING TOKEN USING MYISS PORTAL CREDS"
    params = ["-a", "cta", "-pv", "1.0", "-sv", "1.0.0"]
    params.concat(["-pns", "http://www.iss.net/cml/NetworkDefender/ctsethostinfocredentials"])
    params.concat(["-atn", "user", "-atv", user, "-atn2", "pwd", "-atv2", pass])
    exitcode = Issasapache.system_call(params)
    exitcode
  end
  

  def self.message
    # EMG CR 407225 - LUM doesn't send set-license-request to CRM - prevents
    # np.license.key from being set in PAM - adding call to issasApache to
    # perform the necessary IPC
    if !@license_temp.blank? and Appliance.configured?
      RAILS_DEFAULT_LOGGER.info "Lum -- checking whether to invoke issasApache"
      retval = serialize_yaml
      if !@license_temp.blank? 
        params = ["-a", "al", "-lfn", "#{@license_temp}"]
        RAILS_DEFAULT_LOGGER.info "Lum -- invoking issasApache"
        @license_temp = Issasapache.system_call(params)
        @license_temp.chomp!
        @license_temp.strip!
        if @license_temp != "OK"
          RAILS_DEFAULT_LOGGER.info "Lum -- issasApache failure - #{@license_temp}"
          retval = nil
          retval = {:status_failure=>{:license=>"The license file is invalid and cannot be registered. #{@license_temp}"}}
        end
      end
      @license_temp = ""
      retval
    else
      serialize_yaml
    end
  end


  def self.message_orig
    msg = ""
    error = false
    results = serialize_yaml

    if results.has_key?(:state) and results[:state].has_key?(:mode) \
        and results[:state][:mode] == "no license" 
      msg = "This appliance is not licensed for protection updates. \
            Contact support for information about aquiring a new license"
      error = true
    elsif results.has_key?(:status_failure) and results[:status_failure].has_key?(:discover_updates)
      msg = results[:status_failure][:discover_updates]
      error = true
    elsif results.has_key?(:status_failure) and results[:status_failure].has_key?(:download_updates)
      msg = results[:status_failure][:download_updates]
      error = true
    elsif results.has_key?(:status_failure) and results[:status_failure].has_key?(:install_updates)
      msg = results[:status_failure][:install_updates]
      error = true
    elsif results.has_key?(:status_failure) and results[:status_failure].has_key?(:rollback_updates)
      msg = results[:status_failure][:rollback_updates]
      error = true
    elsif results.has_key?(:status_failure) and results[:status_failure].has_key?(:license)
      msg = results[:status_failure][:license]
      error = true
    elsif results.has_key?(:status_success) and results[:status_success].has_key?(:rollback_updates)
      msg = results[:status_success][:rollback_updates]
    elsif results.has_key?(:status_success) and results[:status_success].has_key?(:install_updates)
      msg = results[:status_success][:install_updates]
    elsif results.has_key?(:status_success) and results[:status_success].has_key?(:discover_updates)
      msg = results[:status_success][:discover_updates]
    elsif results.has_key?(:status_success) and results[:status_success].has_key?(:download_updates)
      msg = results[:status_success][:download_updates]
    elsif results.has_key?(:status_success) and results[:status_success].has_key?(:license)
      msg = results[:status_success][:license]
    end 
    return msg, error 
  end

  
  def self.serialize_yaml
    results = nil
    begin
      obj = YAML::load(File.read("#{ROOTDIR}etc/lum/task-result.yaml"))
    rescue
      obj = {'file_read_error'=>'File read error.'}
    end
    Utility.recursive_symbolize_keys!(obj)
    obj
  end
  
  def self.cache_state_and_update
    file = "#{ROOTDIR}etc/lum/update-state.yaml"
    begin
      File.copy(file, "#{RAILS_ROOT}/tmp/update-state.cache") if File.exists?(file)
    rescue
      #Ignore...harmless
      #RAILS_DEFAULT_LOGGER.error "Lum -- Encountered error while attempting to cache update-state.yaml"
    end
    
    begin
      file = "#{ROOTDIR}etc/lum/update-available.yaml"
      File.copy(file, "#{RAILS_ROOT}/tmp/update-available.cache") if File.exists?(file)
    rescue
      #Ignore...harmless
      #RAILS_DEFAULT_LOGGER.error "Lum -- Encountered error while attempting to cache update-available.yaml"
    end
  end
  
  def self.cache_history
    file = "#{ROOTDIR}etc/lum/update-history.yaml"
    begin
      File.copy(file, "#{RAILS_ROOT}/tmp/update-history.cache") if File.exists?(file)
    rescue
      #Ignore...harmless
      # RAILS_DEFAULT_LOGGER.error "Lum -- Encounted error while attempting to cache update-history.yaml"
    end
  end
  
  def self.load_db
    RAILS_DEFAULT_LOGGER.info "Lum -- Loading update-state.yaml and update-available.yaml"
    cache_state_and_update
    YamlToDB.load_db
  end

  def self.load_history_db
    RAILS_DEFAULT_LOGGER.info "Lum -- update-history.yaml"
    cache_history
    HistorySync.load_db
  end
end
