module Policy
  
  def Policy.refresh_from_server?(namespace)
    namespace == "http://www.iss.net/cml/NetworkDefender/dbt"
  end
  
  module Server
    require 'ftools'
    NAMESPACE_PARAM = "Namespace"
    SCHEMA_PARAM = "schemaVersion"
    CONTENT_PARAM = "content"

    def Server.publicize_each_policy()
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Begin: Policy::Server.publicize_each_policy"
      CpeProperty.find_each do |policy|
        Server.publicize_policy(policy)
      end
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Finished: Policy::Server.publicize_each_policy"
    end
    
    def Server.publicize_each_non_crm_policy()
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Begin: Policy::Server.publicize_each_non_crm_policy"
      CpeProperty.find_each do |policy|
        if(!Server.retrieve_policy_from_crm?(policy))
          Server.publicize_policy(policy)
        end
      end
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Finished: Policy::Server.publicize_each_non_crm_policy"
    end
    
    def Server.publicize_policy(policy)
      begin 
        if(Server.retrieve_policy_from_crm?(policy))
          Server.retrieve_policy_from_crm(policy)
        else
          ns_path = policy.namespace.sub("http://www.iss.net/","") + "/"
          src = FOLDER_CRM_POLICY + ns_path + policy.policy
          dst = FOLDER_PUBLIC_POLICY + policy.policy
          RAILS_DEFAULT_LOGGER.debug "[#{Time.now}] Src: " + src + "  Dest: " + dst
          
          File.copy(src, dst)
        end
      rescue => ex
        RAILS_DEFAULT_LOGGER.error("[#{Time.now}]ERROR: Unable to copy policy file. " + ex.class.to_s + ":" + ex.message.to_s)
      end
    end

    def Server.retrieve_policy_from_crm(policy)
      Issasapache::run "-a gp -pname '#{policy.policy}' -pv '#{policy.policy_version}' -pns '#{policy.namespace}'"
    end
    
    def Server.retrieve_policy_from_crm?(policy)
      policy.namespace == "http://www.iss.net/cml/NetworkDefender/dbt" or policy.namespace == "http://www.iss.net/cml/NetworkDefender/time"
    end
    
    def Server.save_from_cpe_params(params)
      policy_cnt = 0
      exitcode = ""
      until( params[NAMESPACE_PARAM+policy_cnt.to_s].nil? ) do
        exitcode += Server.save_policy( params[NAMESPACE_PARAM+policy_cnt.to_s], params[SCHEMA_PARAM+policy_cnt.to_s], params[CONTENT_PARAM+policy_cnt.to_s] )
        policy_cnt += 1
      end
      
      exitcode
    end

    def Server.save_policy(namespace, schema_version, content)
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Saving policy:  Namespace=" + namespace + ", schema version=" + schema_version
      filename = Server.policy_name(namespace)
      exitcode = ""  
      RAILS_DEFAULT_LOGGER.debug "CONTENT: " + content
      File.open(filename, "w+") do |file|
        begin
          file.puts content
          file.close
          exitcode = Server.apply_policy(filename)
        rescue => ex
          exitcode = "Error: Unable to process file." + ex.class.to_s + ":" + ex.message.to_s
          RAILS_DEFAULT_LOGGER.error("ERROR: Unable to process file. " + ex.class.to_s + ":" + ex.message.to_s)
        end
        File.delete(filename)
      end
      
      exitcode
    end

    def Server.apply_policy(namespace, schema_version, filename)
      RAILS_DEFAULT_LOGGER.info "Applying policy: #{filename}"
      Issasapache::run "-a apf -pns '#{namespace}' -sv '#{schema_version}' -pfn '#{filename}'"
    end
    
    def Server.apply_policy(full_path)
      cmd = "#{ROOTDIR}usr/bin/sudo #{ROOTDIR}usr/bin/iss-apply-policy.sh #{full_path}"
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Applying policy: #{full_path} cmd=#{cmd}"
      exitcode = `#{cmd} 2>&1`
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Applied policy: '#{full_path}'  Exit Code='#{exitcode.strip}'"
      exitcode.strip
    end
    
    def Server.policy_name(namespace)
      cpeItem = CpeProperty.find_by_namespace(namespace)
      FOLDER_LMI_SPOOL + cpeItem.policy
    end
    
  end

  module SensorInfo
    def SensorInfo.index
      $sensor_info_index ||= SensorInfoIndex.new
    end
    
    def SensorInfo.filename_by_namespace(namespace)
      SensorInfo.index.filename_by_namespace(namespace)
    end
    
    def SensorInfo.schema_version_by_namespace(namespace)
      SensorInfo.index.schema_version_by_namespace(namespace)
    end
    
    def SensorInfo.policy_version_by_namespace(namespace)
      SensorInfo.index.policy_version_by_namespace(namespace)
    end
    
    def SensorInfo.clear_index
      $sensor_info_index = nil
    end
  end

  module Routes
    URL_PREFIX = "settings/"
    def Routes.connect_settings_routes(map)
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Begin: Routes.connect_settings"
      begin
        CpeProperty.find_each do |policy|
          if !policy.url.nil?
            policy_url = URL_PREFIX+policy.url
            RAILS_DEFAULT_LOGGER.info "Mapping policy url: " + policy_url + " to id " + policy.link_id.to_s
            map.connect policy_url, :controller => 'settings', :action => "index", :id=>policy.link_id.to_s
          end
        end
      rescue => ex
       RAILS_DEFAULT_LOGGER.warn "Problem dynamically mapping settings. " + ex.class.to_s + ":" + ex.message.to_s
     end
     RAILS_DEFAULT_LOGGER.info "[#{Time.now}] Finished: Routes.connect_settings"
    end
  end
end
