class RrdSource < DataSource
  def initialize(prefix, rra=nil, bandwidth=false)
    super
    @rra = (rra.nil? ? @ds['rra'] : rra)
    @bandwidth = bandwidth
  end

  def data(resolution=60, timespan="1h")
    return {} if @ds['type'] != 'rrd'
    query_rrd("#{@arg}.#{@ds['type']}", @rra, resolution, timespan)
  end
  
  def site_protector_data
    return {} if @ds['type'] != 'rrd'
  end

  def query_rrd(datasource, rra, resolution, timespan)
    begin_time = Time.now.to_i / resolution * resolution
    str = "#{ROOTDIR}usr/bin/rrdtool fetch #{DSPATH}/#{datasource} #{rra} -r #{resolution} -e #{begin_time} -s e-#{timespan}"
    RAILS_DEFAULT_LOGGER.info "RrdStore.query_rrd: #{str}"
    
    cmd = %x[#{str}]

    arr = cmd.split("\n")
    arr = clean_rrd_data(arr)
    arr = split_into_format(arr)
    arr = convert_to_mbits(arr) if @bandwidth
  
    return {} if arr.size == 1    
    DataSource.format_data(arr)
  end

  def convert_to_mbits(arr)
    arr1 = []
    arr1 << arr.shift
    
    arr.each_with_index do |val_array, index|
      arr2 = []
      val_array.each_with_index do |value, index|
        if index == 0
          arr2 << value
        else
          arr2 << ((value.to_f / MBIT).round_to(4)).to_s
        end
      end
      arr1 << arr2
    end
    arr1
  end

  def clean_rrd_data(arr)
    arr.delete_at(1)    
    arr.delete_if{|line| line =~ /nan/ }
    arr
  end

  def split_into_format(arr)
    arr.each_with_index do |line, index|
      line.gsub!(/:/, "")
      arr[index] = line.split(" ")
    end
    arr
  end

  def self.filter_by_keys(data, fdata=nil, sn=true)    
    filter = build_filter(fdata, sn)
    data.delete_if{|k, v| eval(filter)}
    return data
  end

  def self.build_filter(arg, sn)
    fstring = ""

    if sn
      fstring = "k != 'serial_number'"
      fstring += " and " if !arg.empty?    
    end

    arg.each_with_index do |filter, index|
      fstring += "k != '#{filter}'"
      fstring += " and " unless index == arg.size - 1
    end
    fstring
  end
end
