class SensorInfoIndex
  require "rexml/document"
  include REXML
  
  def initialize
    @policies = read_policies
  end
  
  def filename_by_namespace(namespace)
    begin
      @policies[namespace][:filename]
    rescue NoMethodError
      ""
    end
  end
  
  def schema_version_by_namespace(namespace)
    begin
      @policies[namespace][:schema_version]
    rescue NoMethodError
      ""
    end
  end
  
  def policy_version_by_namespace(namespace) 
    begin
      @policies[namespace][:policy_version]
    rescue NoMethodError
      ""
    end
  end
  
   def relative_path_by_namespace(namespace) 
    begin
      @policies[namespace][:relative_path]
    rescue NoMethodError
      ""
    end
  end
  
  private
  def read_policies
    RAILS_DEFAULT_LOGGER.info "[#{Time.now}] SensorInfoIndex.read_policies"
    policies = {}
    doc = Document.new(File.new("#{ROOTDIR}etc/crm/SensorPolicyInfoG.xml"))
    elements = doc.elements.each("//sensorPolicyInfo/schemaNameSpace") do |elem|
      policy = {}
      policy[:filename] = elem.attributes["fileName"]
      policy[:schema_version] = elem.attributes["schemaVersion"]
      policy[:policy_version] = elem.attributes["policyVersion"]
      policy[:relative_path] = elem.attributes["relativePath"]
      namespace = elem.attributes["nameSpace"]
      policies[namespace] = policy
    end
    policies
  end
end