require 'cgi'

class Setup
  
  #Base configuration
  def self.start_configuration
    SecurityInterface.configure
    configure_interfaces
  end

  def self.finalize
    User.logout
    ManagementInterface.configure
	Xforce.configure
    set_sensor_name
    restart_network
    register_sensor
    restart_sensor

    if SiteProtector.register?
      # wait for sensor restart
      # sensor must be up before we can encrypt SP passwd
      sleep 10
      SiteProtector.configure
    end    

    enable_sudo_logging
    clean_policy_files
    Appliance.clear_setup_lock
    set_configuration_done
    generate_ssl_keys
  end

  #Maintenance configuration
  def self.start_maintenance_configuration
    SecurityInterface.configure
    configure_interfaces
  end

  def self.finalize_maintenance
    User.logout
    ManagementInterface.configure
	Xforce.configure
    set_sensor_name
    restart_network
    register_sensor
    restart_sensor    

    if SiteProtector.register?
      # wait for sensor restart
      # sensor must be up before we can encrypt SP passwd
      sleep 10
      SiteProtector.configure
    end    

    enable_sudo_logging
    clean_policy_files
    Appliance.clear_reconfigure
    Appliance.clear_setup_lock
    set_configuration_done
    generate_ssl_keys
  end

  #Policy configurations
  def self.configure_date_time(args)
    policy = create_policy(:time, args, true)
    Policy::Server.apply_policy(policy)
  end

  def self.configure_ntp(args)
    policy = create_policy(:ntp, args, true)
    Policy::Server.apply_policy(policy)
  end

  def self.add_security_interface(args, old_tmp_policy, version)
    create_policy(:security_interface, args, true, old_tmp_policy, version)
  end


  private
  def self.configure_security_interface(policy)
    File.rename(policy, "/tmp/adapter1_1.xml") if RAILS_ENV == "production"
    exitcode = Policy::Server.apply_policy("/tmp/adapter1_1.xml")
    raise_error(exitcode) unless exitcode == "OK"
  end

  def self.configure_password(oldpass, password, account)
    encoded_password = CGI.escape(password)
    encoded_oldpass  = CGI.escape(oldpass)
    exitmsg = `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd password --set --user #{account} --oldpass '#{encoded_oldpass}' --pass '#{encoded_password}' --encoded 2>&1`
    raise_error(exitmsg) unless $?.exitstatus == 0
  end

  def self.configure_xforce(args)
    # verbose false so we don't display encrypted passwd
    policy = create_policy(:xforce, args, false)
    exitcode = Policy::Server.apply_policy(policy)
    raise_error(exitcode) unless exitcode == "OK"
  end
  
  def self.configure_site_protector(args)
    # verbose false so we don't display encrypted passwd
    policy = create_policy(:site_protector, args, false)
    exitcode = Policy::Server.apply_policy(policy)
    raise_error(exitcode) unless exitcode == "OK"
  end

  def self.configure_management_interface(args)
    policy = create_policy(:network, args, true)
    exitcode = Policy::Server.apply_policy(policy)
    raise_error(exitcode) unless exitcode == "OK"
  end

  def self.raise_error(msg)
    File.open("#{RAILS_ROOT}/tmp/setup_error.log", "w+") { |f| f << msg }
    raise ApplianceExceptions::SetupException    
  end


  def self.create_policy(type, args, verbose=true, old_tmp_policy=nil, version=nil)
    version ||= ""
  
    path = policy_transforms[type][:policy]
  
    policy_name = path[(path.rindex("/")+1)..path.rindex(".")-1]
  
    RAILS_DEFAULT_LOGGER.info "CREATING POLICY -- #{policy_name}"
    executable = "#{ROOTDIR}usr/bin/Xalan -p "
    tmp_file = "#{ROOTDIR}tmp/#{policy_name}#{version}.xml"
    t = policy_transforms[type]

    executable << args.map{|k, v| "#{k} \"'#{v}'\""}.join(" -p ")  
    
    if old_tmp_policy.blank?
      executable << " -o '#{tmp_file}' '#{t[:policy]}' '#{t[:transform]}'"
    else
      executable << " -o '#{tmp_file}' '#{old_tmp_policy}' '#{t[:transform]}'"
    end

    if verbose == true
      RAILS_DEFAULT_LOGGER.info "[#{executable}]"
    end

    `#{executable}`
    RAILS_DEFAULT_LOGGER.info "[#{type.to_s}] POLICY CREATED EXIT[#{$?.exitstatus}]"
    tmp_file 
  end

  def self.clean_policy_files
    RAILS_DEFAULT_LOGGER.info "REMOVING POLICY TEMP FILES"
    `rm -f /tmp/*.xml`
  end



  def self.configure_interfaces
    RAILS_DEFAULT_LOGGER.info "CONFIGURING NETWORK INTERFACES"
    `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd network --config-ifc`
  end

  def self.enable_sudo_logging
    RAILS_DEFAULT_LOGGER.info "ENABLING SUDO LOGGING"
    `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd log --enable`
  end


  def self.set_sensor_name
    m = ManagementInterface.find(:first)
    unless m.sensor_name.blank?
    RAILS_DEFAULT_LOGGER.info "SETTING SENSOR NAME TO #{m.sensor_name}"
      `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd sensor --set --name '#{m.sensor_name}'`
    end
  end

  def self.register_sensor
    RAILS_DEFAULT_LOGGER.info "REGISTERING THE SENSOR"
    `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd sensor --register`
  end

  def self.restart_sensor
    RAILS_DEFAULT_LOGGER.info "RESTARTING SENSOR"
    `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd sensor --restart`
  end

  def self.remove_configuration_done
    RAILS_DEFAULT_LOGGER.info "SETUP FAILED -- REMOVING CONFDONE"
    `rm -f #{ROOTDIR}etc/appliance/.confdone`
  end

  def self.restart_network
    RAILS_DEFAULT_LOGGER.info "RESTARTING NETWORK"
    `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd network --restart`
  end

  def self.set_configuration_done
    RAILS_DEFAULT_LOGGER.info "SETTING /etc/appliance/.confdone"
    Appliance.clear_configuring
    `touch #{ROOTDIR}etc/appliance/.confdone`
  end

  def self.generate_ssl_keys
    RAILS_DEFAULT_LOGGER.info "GENERATING SSL KEYS"
    `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd lmi --gencert --restart`
  end
  
#TODO: retrieve web setup policy transform info from SensorPolicyInfoG.xml
#TODO: relocate access .xslt transform
  def self.initialize_policy_transforms
    @@POLICYTRANSFORMS[:time] =  policy_transform_hash("http://www.iss.net/cml/NetworkDefender/time", 
        "#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/time100.xslt")
    @@POLICYTRANSFORMS[:ntp] =  policy_transform_hash("http://www.iss.net/cml/NetworkDefender/ntp",
        "#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/ntp100.xslt")
    @@POLICYTRANSFORMS[:network] =  policy_transform_hash("http://www.iss.net/cml/NetworkDefender/network", 
        "#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/network100.xslt")
    @@POLICYTRANSFORMS[:access] =  policy_transform_hash("http://www.iss.net/cml/NetworkDefender/access", 
        "#{RAILS_ROOT}/lib/definitions/access.xslt")
    @@POLICYTRANSFORMS[:security_interface] =  policy_transform_hash("http://www.iss.net/cml/NetworkDefender/adapter", 
        "#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/Adapter_1.0_AddCard.xslt")
    @@POLICYTRANSFORMS[:site_protector] =  policy_transform_hash("http://www.iss.net/cml/NetworkDefender/mgmt", 
        "#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/mgmt500.xslt")
	@@POLICYTRANSFORMS[:xforce] =  policy_transform_hash("http://www.iss.net/cml/NetProtectModule/ipmConfig", 
        "#{ROOTDIR}etc/crm/schemas/cml/NetProtectModule/xsl/ipmConfig100.xslt")
  end

  def self.policy_transforms
    if !defined?(@@POLICYTRANSFORMS)
      @@POLICYTRANSFORMS = {}
      initialize_policy_transforms
    end
    @@POLICYTRANSFORMS
  end

  def self.policy_transform_hash(namespace, transformpath)
    sensor_info_g_index = Policy::SensorInfo.index
    policyname = sensor_info_g_index.filename_by_namespace(namespace)
    policypath = namespace.sub("http://www.iss.net","#{ROOTDIR}etc/crm/policies")
    {:policy=>"#{policypath}/#{policyname}",
    :transform=>"#{transformpath}"}
  end


  POLICYTRANSFORMS_DEPRECATED = {
  :time => {:policy=>"#{ROOTDIR}etc/crm/policies/cml/NetworkDefender/time/ndtime1_0.xml", 
  :transform=>"#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/time100.xslt"},
  :network => {:policy=>"#{ROOTDIR}etc/crm/policies/cml/NetworkDefender/network/ndnetwork1_1.xml", 
  :transform=>"#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/network100.xslt"},
  :access => {:policy=>"#{ROOTDIR}etc/crm/policies/cml/NetworkDefender/access/npaccess5_0.xml", 
  :transform=>"#{RAILS_ROOT}/lib/definitions/access.xslt"},  
  :security_interface => {:policy=>"#{ROOTDIR}etc/crm/policies/cml/NetworkDefender/adapter/adapter1_1.xml", 
  :transform=>"#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/Adapter_1.0_AddCard.xslt"},
  :site_protector => {:policy=>"#{ROOTDIR}etc/crm/policies/cml/NetworkDefender/mgmt/npmgmt5_0.xml", 
  :transform=>"#{ROOTDIR}etc/crm/schemas/cml/NetworkDefender/xsl/mgmt500.xslt"}}
end
