class SqliteSource < DataSource
  require 'sqlite3'
  
  def data(filter="")
     return nil if @ds['type'] != 'sqlite'
     query_sqlite(@ds, filter)
  end

  
  def query_sqlite(ds, filter="")
    properties_hash = {}
    results = []
    dbpath = Dbmap.send(ds['datasource'])
    db = SqliteSource.initialize_database(dbpath)
    rows = SqliteSource.query_database(db, dbpath, "#{ds['query']} #{filter};")
    return results if rows == nil or rows.empty?

    klass = nil

    rows.each_with_index do |r, i|
      begin
        ds_klass = eval("#{ds['klass']}.new")
      rescue
        klass = DataSource.new_class(rows, ds)
        ds_klass = klass.new
      end
      
      rows[i].fields.each_with_index do |f, j|
        f.gsub!(/\W/,"_")      
        ds_klass.send("#{f.downcase}=", r[j])
      end
      results << ds_klass
    end
    
    db.close
    return results
  end

  def self.initialize_database(dbpath, results_as_hash=false, attach_arr=[])
    db = nil
    begin
      db = SQLite3::Database.new(dbpath)
      db.results_as_hash = results_as_hash
      db.busy_handler { |data, retries|
        RAILS_DEFAULT_LOGGER.warn(Time.now.to_s + "  WARNING: database is busy.  DB: " + dbpath + "  Attempt #:" + retries.to_s)
        sleep 1
        (retries<=5)
      }
      attach_arr.each{|d| db.execute(d)}
      
    rescue Exception => ex
      RAILS_DEFAULT_LOGGER.error("#{Time.now} ERROR: Unable to access database.  DB: #{dbpath}  Exception: #{ex.class.to_s}  #{ex.message.to_s}")
    end
    db
  end
  
  def self.query_database(db, dbpath, query, *bind_vars)
    rows = nil
    begin
      rows = db.execute(query, *bind_vars)
    rescue Exception => ex
      RAILS_DEFAULT_LOGGER.error("ERROR: Unable to access database.  DB: #{dbpath}  Exception: #{ex.class.to_s}  #{ex.message.to_s}")
    ensure
      db.close if !db.nil?
    end 
    
    rows 
  end

  def self.get_first_row(db, dbpath, query, *bind_vars)
    row = nil
    begin
      row = db.get_first_row(query, *bind_vars)
    rescue Exception => ex
      RAILS_DEFAULT_LOGGER.error("ERROR: Unable to access database.  DB: #{dbpath}  Exception: #{ex.class.to_s}  #{ex.message.to_s}")
    ensure
      db.close if !db.nil?
    end 
    
    row 
  end
  
  def self.get_first_value(db, dbpath, query, *bind_vars)
    val = nil
    begin
      val = db.get_first_value(query, *bind_vars)
    rescue Exception => ex
      RAILS_DEFAULT_LOGGER.error("ERROR: Unable to access database.  DB: #{dbpath}  Exception: #{ex.class.to_s}  #{ex.message.to_s}")
    ensure
      db.close if !db.nil?
    end 
    
    val 
  end


  def self.format_sql_data data, filters=nil
    arr = Array.new
    
    data.each do |k|
      tmp = Array.new
      if filters.nil?
        k.instance_values.each do |key, val|
          tmp.push val
        end
      else        
        filters.each do |key|
          if k.instance_variable_defined?("@#{key}")
            tmp.push k.instance_variable_get("@#{key}")
          end  
        end
      end
      arr.push tmp
    end 
    
    arr
  end

end
