class TimeZone
  require 'time'
  
  def self.all
    flines = []
    zones = []
    rzones = []
    ztime = ""
    
    gmt = Time.parse(`/usr/sbin/zdump GMT`.strip)
    
    begin
      File.open("/usr/share/zoneinfo/zone.tab") do |f|
        flines = f.readlines
      end
    rescue
      return []
    end
    
    zones = build_zone_list(flines, gmt)
    
    begin
      zones.compact!
      zones.sort!{ |a, b| a[0] <=> b[0] }
      rzones = zones.map{|z| "(GMT#{z[1]})  #{z[2]}" }
    rescue
      return []
    end
    rzones
  end
  
  
  def self.load_all
    flines = []
    zones = []
    rzones = []
    ztime = ""
    cmd = `which zdump`.strip
    gmt = Time.parse(`#{cmd} GMT`.strip)
    
    begin
      File.open("/usr/share/zoneinfo/zone.tab") do |f|
        flines = f.readlines
      end
    rescue
      return []
    end
    
    zones = build_zone_list(flines, gmt)
    
    begin
      zones.compact!
      zones.sort!{ |a, b| a[0] <=> b[0] }
      rzones = zones.map{|z| [z[1], z[2]] }
    rescue
      return []
    end
    rzones
  end
  
  
  def self.build_zone_list(flines, gmt)
    cmd = `which zdump`.strip
    flines.map do |z| 
      arr = []
      tmparr = z.split("\t")

      next if (tmparr.length < 2 || tmparr[2].nil? or tmparr[0] == "TZ")

      tmp = tmparr[2]
      zone = `#{cmd} #{tmp}`
      time = zone[zone.index("\s")..zone.rindex("\s")]

      next if time.nil?

      time.strip!

      begin
        ztime = Time.parse(time)
        rescue
          next
      end

      begin
        digit_array = []
        diff = ztime - gmt
        arr = gmtoffset(diff)
        arr << tmp.strip
      rescue
        next
      end
    end
  end
  
  def self.gmtoffset(signed_diff, sign="+")
    offset = []
    sign = "-" if signed_diff < 0
    diff = signed_diff.abs
    mins = (diff-(diff % 60)) / 60 % 60
    hours = ((((diff-(diff % 60)) / 60) - ((diff-(diff % 60)) / 60 % 60)) / 60) % 24
    strmins = tzmins(mins)
    strhours = tzhours(mins, hours)
    offset[0] = signed_diff
    offset[1] = Time.parse("#{strhours.to_i}:#{strmins}").strftime("#{sign}%H:%M")
    offset
  end
  
  def self.tzhours(mins, hours)
    mins > 45 ? hours + 1 : hours 
  end
  
  def self.tzmins(mins)
    case mins
    when 30 then return 30
    when 45 then return 45
    else return 0
    end
  end
end



