class YamlToDB
  def self.load_db
    @logger = Logger.new(File.dirname(__FILE__) + '/../log/yaml_to_db.log')
    set_db_lock
    begin
      @logger.info "Opening and parsing update-available.yaml"
      updates = YAML::load(File.read("#{ROOTDIR}etc/lum/update-available.yaml"))
    rescue
      @logger.warn "Warning: update-available.yaml file not found"
    end

    begin
      @logger.info "Opening and parsing update-state.yaml"
      status_entries = YAML::load(File.read("#{ROOTDIR}etc/lum/update-state.yaml"))
    rescue
      @logger.warn "Warning: update-state.yaml file not found"
    end
    
    begin
      load_status_entry_table(status_entries)
      load_updates_table(updates)
    rescue
      @logger.error("Error while loading the database script")
    end
    release_db_lock
  end
 
  private
  def self.set_db_lock
    @logger.info("Setting update lock with /tmp/db_update_in_progress.lck")
    system("touch /tmp/db_update_in_progress.lck")
  end
  
  def self.release_db_lock
    @logger.info("Removing update lock /tmp/db_update_in_progress.lck")
    system("rm -f /tmp/db_update_in_progress.lck")
  end
  
  def self.load_status_entry_table(status_entries)
    if status_entries
      status_entries.each do |k, v|
        @logger.info "Loading data into the status_entries for module #{v['name']}."
        status_entry = StatusEntry.find_by_name(v["name"])
        adj_maint_date = "#{v['license_maint_date']}" + " 23:59:59"
        adj_usage_date = "#{v['license_usage_date']}" + " 23:59:59"
        begin
          status_entry.update_attributes({"license_ocnid" => nil, "license_type" => nil, "license_cust_name" => nil, "license_cust_company" => nil}.merge(v))
          status_entry.update_attributes({"license_maint_date" => adj_maint_date, "license_usage_date" => adj_usage_date})
          status_entry.save!
        rescue
          #pass
        end
      end
      return true
    else
      @logger.error "Error: update-state.yaml file is empty.  No data loaded."
      return false
    end
  end
 
  def self.load_updates_table(updates)
    Update.destroy_all
    if updates
      @logger.info "Loading data into the updates table."
      updates.each do |k, v|
        if v.class == Array
          v.each do |array_val|
            u = Update.new(array_val)
            s = StatusEntry.find_by_name(u.name)
            u.status_entry_id = s.id
            u.save!
          end
        else
          u = Update.new(v)
          begin
            s = StatusEntry.find_by_name(u.name)
            u.status_entry_id = s.id
            u.save!
          rescue
            begin
              s = StatusEntry.find_by_name("Antispam")
              u.status_entry_id = s.id
              u.save!
            rescue
              @logger.error "Error while inserting update for #{u.name}"
            end
          end
        end
      end
    end
    return true
  end
end

