// ==ClosureCompiler==
// @compilation_level SIMPLE_OPTIMIZATIONS
// ==/ClosureCompiler==


/*
  When the initialize function loads it searches the page for
  any element with a class 'graph'.  If any are found it grabs
  the graph elements and passes them off to the loadGraph function.
*/
$(function (){
  var graphs = $(".graph");
  $.each(graphs, function(i, elm){
    loadGraph(elm);
  });
});

/*
  Accepts an html element and uses the element's id to determine
  which   controller method to use as a callback to grab the graphing data.
*/
function loadGraph(elm){
  var filter_data = {};
  var data_source = $(elm).html();

  var url = data_source.replace(/-/g, "/");
  var renderGraph;

  if($(".filterpage").attr("value") != undefined) {
    if ($(".filterpage").attr("value") != "in_page") {
      if ($(elm).hasClass("top10") ) {
        filter_data = getParamsTop10(document.location.pathname);
      } else {
        filter_data = getParams(document.location.pathname);
      }
    }
  }

  if ($(elm).hasClass("overtime") ) {
    document.is_percentage = $(elm).hasClass("percentage");
    renderGraph = renderOvertimeGraph;
  } else if ($(elm).hasClass("top10") ) {
    renderGraph = renderTop10Graph;
  } else {
    alert(" No Graph Found ");
  }

 $.ajax({
    type: "GET",
    url: "/statistics/"+url+".json",
    data: filter_data,
    datatype: "json",
    success: function(data){ 
      json_data = eval( "(" + data + ")" );
			var empty_set = false;
			
			if(isEmpty(json_data)){
				empty_set = true;
				var $div = $(document.createElement('div'));
				var $span = $(document.createElement('span'));
				var $span2 = $(document.createElement('span'));
			
				$div.attr("class", "ui-state-highlight empty-set-msg");				
				$span.attr("class", "ui-icon ui-icon-alert");
				$span2.html("The data set for this graph is currently empty.");
		
				$div.append($span);		
				$div.append($span2);
		

 			 	$(elm).parent().append($div);
			}

			if(empty_set)
				json_data=[[[0,0], [0,0]]];
			
			
			renderGraph(elm, data_source, json_data);
			var bandwidth_range_needed = $("#render-bandwidth-range").data("val");
			var packet_range_needed = $("#render-packet-range").data("val");
			
			if(bandwidth_range_needed){
				if(empty_set){
					var empty_data = {};
					empty_data["Mbit/s in"] = [[0,0], [0,0]]; 
					empty_data["Mbit/s out"] = [[0,0], [0,0]];
					empty_data["Mbit/s secured"] = [[0,0], [0,0]];
					empty_data["Mbit/s unanalyzed"] = [[0,0], [0,0]];
					json_data = empty_data;
				}
				renderBandwidthRanges(json_data);
			}

			if(packet_range_needed){
				if(empty_set){
					var empty_data = {};
					empty_data["Packets blocked"] = [[0,0], [0,0]]; 
					empty_data["Packets injected"] = [[0,0], [0,0]];
					empty_data["Packets unanalyzed"] = [[0,0], [0,0]]; 
					empty_data["Packets forwarded"] = [[0,0], [0,0]];
					json_data = empty_data;
				}
				renderPacketRanges(json_data);
			}
      
    } //end success anonymous function
  });//end ajax
}

/*
  Converts date strings to date integers and converts NaN values to '0'
*/
function cleanSeries(data){
  var return_array = new Array();
  for(var i=0; i < data.length; i++){
    var x = parseInt(data[i][0]);

    if(data[i][1]=="nan"){data[i][1] = 0}


    var y = parseFloat(data[i][1]);
    var xy = [x,y];
    return_array[i] = xy;
  }
  return return_array;
}

function isEmpty(obj) {
    for(var prop in obj) {
        if(obj.hasOwnProperty(prop))
            return false;
    }
    return true;
}



function getMinMax(data_points){
  data_array = data_points[0].data.slice(data_points[0].data.length - 12);

  var dates = {
    min: data_array[0][0],
    max: data_array[data_array.length - 1][0]
  };

  return dates;
}


// helper for returning the weekends in a period
function weekendAreas(axes){
    var markings = [];
    var d = new Date(axes.xaxis.min);
    // go to the first Saturday
    d.setUTCDate(d.getUTCDate() - ((d.getUTCDay() + 1) % 7))
    d.setUTCSeconds(0);
    d.setUTCMinutes(0);
    d.setUTCHours(0);
    var i = d.getTime();
    do {
        // when we don't set yaxis the rectangle automatically
        // extends to infinity upwards and downwards
        markings.push({ xaxis: { from: i, to: i + 2 * 24 * 60 * 60 * 1000 } });
        i += 7 * 24 * 60 * 60 * 1000;
    } while (i < axes.xaxis.max);

    return markings;
}


function getMinMax(data_points){
  data_array = data_points[0].data.slice(data_points[0].data.length - 12);

  var dates = {
    min: data_array[0][0],
    max: data_array[data_array.length - 1][0]
  };

  return dates;
}

function getMinMaxRanges(data){
	var vals = {};
	var max = _.max(data, function(arr){return parseFloat(arr[1])});
	var min = _.min(data, function(arr){return parseFloat(arr[1])});
	vals.max = parseFloat(max[1]);
	vals.min = parseFloat(min[1]);
	return vals;
}



function formatToPercent(val, axis){
  return val.toFixed(axis.tickDecimals) + "%";
}

function getParams(url){
  var params = new Object();
  var filterpath = $(".filterpage").attr("value");

  var fstring = url.replace(filterpath,"");
  var vals = fstring.split("/");
  for(var i=0; i < vals.length; i++) {
    params["filt"+i] = vals[i];
  }
  return params;
}

function getParamsTop10(url){
  var params = new Object();
  var href = $(".href").attr("value");
  var filterpath = $(".filterpage").attr("value");
  var keys = ["id","priority"]
  var fstring = href.replace(filterpath,"");
  var vals = fstring.split("/");

  if (vals.length > 1) {
    if (vals[0] == "") {
      vals.shift();
    }
    if (vals[vals.length-1] == "") {
      vals.pop();
    }
  }

  for(var i=0; i < vals.length; i++) {
    params[keys[i]] = vals[i];
  }
  return params;
}


/*
  Removes the loading message just before plotting the graph
*/

function removeLoadingMsg(id){
  $(id).remove();
}

function renderBandwidthRanges(json_data){
	if(json_data["Mbit/s in"] !== undefined && json_data["Mbit/s out"] !== undefined && json_data["Mbit/s secured"] !== undefined && json_data["Mbit/s unanalyzed"] !== undefined){
	
		var in_ranges = getMinMaxRanges(json_data["Mbit/s in"]);
		var out_ranges = getMinMaxRanges(json_data["Mbit/s out"]);
		var secured_ranges = getMinMaxRanges(json_data["Mbit/s secured"]);
		var unsecured_ranges = getMinMaxRanges(json_data["Mbit/s unanalyzed"]);
	
		var in_avg = (in_ranges.min + in_ranges.max) / 2.0;
		var out_avg = (out_ranges.min + out_ranges.max) / 2.0;	
		var secured_avg = (secured_ranges.min + secured_ranges.max) / 2.0;
		var unsecured_avg = (unsecured_ranges.min + unsecured_ranges.max) / 2.0;

		$("#in-min").html(Math.round(in_ranges.min*1000)/1000);
		$("#in-max").html(Math.round(in_ranges.max*1000)/1000);
		$("#in-avg").html(Math.round(in_avg*1000)/1000);
		$("#out-min").html(Math.round(out_ranges.min*1000)/1000);
		$("#out-max").html(Math.round(out_ranges.max*1000)/1000);
		$("#out-avg").html(Math.round(out_avg*1000)/1000);
		$("#secured-min").html(Math.round(secured_ranges.min*1000)/1000);
		$("#secured-max").html(Math.round(secured_ranges.max*1000)/1000);
		$("#secured-avg").html(Math.round(secured_avg*1000)/1000);
		$("#unsecured-min").html(Math.round(unsecured_ranges.min*1000)/1000);
		$("#unsecured-max").html(Math.round(unsecured_ranges.max*1000)/1000);
		$("#unsecured-avg").html(Math.round(unsecured_avg*1000)/1000);

	}
}

function renderPacketRanges(json_data){
	if(json_data["Packets blocked"] !== undefined || json_data["Packets injected"] !== undefined || json_data["Packets unanalyzed"] !== undefined && json_data["Packets forwarded"] !== undefined){
	
		var blocked = getMinMaxRanges(json_data["Packets blocked"]);
		var injected = getMinMaxRanges(json_data["Packets injected"]);
		var unanalyzed = getMinMaxRanges(json_data["Packets unanalyzed"]);
		var forwarded = getMinMaxRanges(json_data["Packets forwarded"]);
		
		var blocked_avg = (blocked.min + blocked.max) / 2.0;
		var injected_avg = (injected.min + injected.max) / 2.0;	
		var unanalyzed_avg = (unanalyzed.min + unanalyzed.max) / 2.0;
		var forwarded_avg = (forwarded.min + forwarded.max) / 2.0;

		$("#blocked-min").html(Math.round(blocked.min*1000)/1000);
		$("#blocked-max").html(Math.round(blocked.max*1000)/1000);
		$("#blocked-avg").html(Math.round(blocked_avg*1000)/1000);
		
		$("#injected-min").html(Math.round(injected.min*1000)/1000);
		$("#injected-max").html(Math.round(injected.max*1000)/1000);
		$("#injected-avg").html(Math.round(injected_avg*1000)/1000);
		
		$("#unanalyzed-min").html(Math.round(unanalyzed.min*1000)/1000);
		$("#unanalyzed-max").html(Math.round(unanalyzed.max*1000)/1000);
		$("#unanalyzed-avg").html(Math.round(unanalyzed_avg*1000)/1000);
		
		$("#forwarded-min").html(Math.round(forwarded.min*1000)/1000);
		$("#forwarded-max").html(Math.round(forwarded.max*1000)/1000);
		$("#forwarded-avg").html(Math.round(forwarded_avg*1000)/1000);

	}
}
